@@ -2,6 +2,8 @@
  * hpifan.cpp
  *
  * Copyright (c) 2003,2004 by FORCE Computers
+ * (C) Copyright Nokia Siemens Networks 2010
+ * (C) Copyright Ulrich Kleber 2011
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -12,66 +14,32 @@
  *
  * Authors:
  *     Thomas Kanngieser <thomas.kanngieser@fci.com>
+ *     Ulrich Kleber <ulikleber@users.sourceforge.net>
  *
+ * Changes:
  *     10/13/2004  kouzmich   porting to HPI B
+ *     09/06/2010  ulikleber  New option -D to select domain
+ *     01/02/2011  ulikleber  Refactoring to use glib for option parsing and
+ *                            introduce common options for all clients
+ *
  */
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <unistd.h>
-#include <getopt.h>
+#include "oh_clients.h"
 
-#include <SaHpi.h>
-#include <oh_utils.h>
-#include <oh_clients.h>
+#define OH_SVN_REV "$Revision: 7291 $"
 
-#define OH_SVN_REV "$Revision: 6571 $"
+static SaHpiBoolT set_new = SAHPI_FALSE;
+static SaHpiCtrlModeT new_mode = SAHPI_CTRL_MODE_MANUAL;
+static int new_speed = -1;
+static gchar *f_speed = NULL;
+static oHpiCommonOptionsT copt;
 
-static int fan_speed = -1;
-
-
-static int
-usage( char *progname )
+static GOptionEntry my_options[] =
 {
-        fprintf( stderr, "usage: %s [-h] [-s fan_speed_level]\n", progname );
-        fprintf( stderr, "\t\t -h        help\n" );
-        fprintf( stderr, "\t\t -s speed  set fan speed for ALL fans\n" );
-
-        return 1;
-}
-
-
-static void
-display_textbuffer( SaHpiTextBufferT string )
-{
-        int i;
-        switch( string.DataType ) {
-        case SAHPI_TL_TYPE_BINARY:
-                for( i = 0; i < string.DataLength; i++ )
-                        printf( "%x", string.Data[i] );
-                break;
-        case SAHPI_TL_TYPE_BCDPLUS:
-                 for( i = 0; i < string.DataLength; i++ )
-                        printf( "%c", string.Data[i] );
-                break;
-       case SAHPI_TL_TYPE_ASCII6:
-                 for( i = 0; i < string.DataLength; i++ )
-                        printf( "%c", string.Data[i] );
-                break;
-       case SAHPI_TL_TYPE_UNICODE:
-                for( i = 0; i < string.DataLength; i++ )
-                        printf( "%c", string.Data[i] );
-                break;
-	case SAHPI_TL_TYPE_TEXT:
-                for( i = 0; i < string.DataLength; i++ )
-                        printf( "%c", string.Data[i] );
-                break;
-        default:
-                printf("Invalid string data type=%d", string.DataType );
-        }
-}
-
+  { "speed", 's', 0, G_OPTION_ARG_STRING, &f_speed, "Set fan speed for ALL fans in domain\n"
+    "                      speed is a number or \"auto\" for setting fan in auto mode", "auto|nn" },
+  { NULL }
+};
 
 static SaErrorT
 get_fan_speed( SaHpiSessionIdT session_id,
@@ -82,6 +50,8 @@ get_fan_speed( SaHpiSessionIdT session_id,
 {
         SaHpiCtrlStateT state;
 
+	if (copt.debug) DBG("get fan speed for resource %u, control %u", resource_id, ctrl_num);
+
         SaErrorT rv = saHpiControlGet( session_id, resource_id, ctrl_num, mode, &state );
 
         if ( rv != SA_OK ) {
@@ -112,6 +82,7 @@ set_fan_speed( SaHpiSessionIdT session_id,
         state.Type = SAHPI_CTRL_TYPE_ANALOG;
         state.StateUnion.Analog = speed;
 
+	if (copt.debug) DBG("set fan speed for resource %u, control %u", resource_id, ctrl_num);
         rv = saHpiControlSet( session_id, resource_id, ctrl_num, mode, &state );
 
         if ( rv != SA_OK ) {
@@ -131,8 +102,8 @@ do_fan( SaHpiSessionIdT session_id, SaHpiResourceIdT resource_id,
         SaHpiCtrlRecT *ctrl_rec = &rdr->RdrTypeUnion.CtrlRec;
 	SaHpiCtrlModeT ctrl_mode;
 
-        printf( "\tfan: num %d, id ", ctrl_rec->Num );
-        display_textbuffer( rdr->IdString );
+        printf( "\tfan: num %u, id ", ctrl_rec->Num );
+        oh_print_text ( &rdr->IdString );
         printf( "\n" );
 
         if ( ctrl_rec->Type != SAHPI_CTRL_TYPE_ANALOG ) {
@@ -151,21 +122,25 @@ do_fan( SaHpiSessionIdT session_id, SaHpiResourceIdT resource_id,
         if ( rv != SA_OK )
                 return 0;
 
+        printf( "\t\tmode      %s\n", ctrl_mode == SAHPI_CTRL_MODE_AUTO ? "auto" : "manual" );
         printf( "\t\tcurrent   %d\n", speed );
 
-        if ( fan_speed == -1 )
+        if ( set_new == SAHPI_FALSE ) {
                 return 0;
+        }
+        if ( new_mode == SAHPI_CTRL_MODE_AUTO ) {
+                new_speed = speed;
+        }
   
-        if (    fan_speed < ctrl_rec->TypeUnion.Analog.Min 
-                || fan_speed > ctrl_rec->TypeUnion.Analog.Max ) {
+        if (   new_speed < ctrl_rec->TypeUnion.Analog.Min 
+                || new_speed > ctrl_rec->TypeUnion.Analog.Max ) {
                 fprintf( stderr, "fan speed %d out of range [%d,%d] !\n",
-                         fan_speed, ctrl_rec->TypeUnion.Analog.Min,
+                        new_speed, ctrl_rec->TypeUnion.Analog.Min,
                          ctrl_rec->TypeUnion.Analog.Max );
                 return 0;
         }
 
-        speed = fan_speed;
-        rv = set_fan_speed( session_id, resource_id, ctrl_rec->Num, speed, ctrl_mode);
+        rv = set_fan_speed( session_id, resource_id, ctrl_rec->Num, new_speed, new_mode);
 
         if ( rv != SA_OK )
                 return 0;
@@ -175,6 +150,7 @@ do_fan( SaHpiSessionIdT session_id, SaHpiResourceIdT resource_id,
         if ( rv != SA_OK )
                 return 0;
   
+        printf( "\t\tnew mode  %s\n", ctrl_mode == SAHPI_CTRL_MODE_AUTO ? "auto" : "manual" );
         printf( "\t\tnew speed %d\n", speed );
 
         return 0;
@@ -250,52 +226,66 @@ discover_domain( SaHpiSessionIdT session_id )
 int
 main( int argc, char *argv[] )
 {
-        int c;
-        int help = 0;
         SaErrorT rv;
-
-        oh_prog_version(argv[0], OH_SVN_REV);
-
-        while( (c = getopt( argc, argv,"hs:") ) != -1 )
-                switch( c ) {
-                case 'h': 
-                        help = 1;
-                        break;
-
-                case 's':
-                        fan_speed = atoi( optarg );
-                        break;
-                 
-                default:
-                        fprintf( stderr, "unknown option %s !\n",
-                                 argv[optind] );
-                        help = 1;
-                }
-  
-        if ( help )
-                return usage(argv[0]);
-
         SaHpiSessionIdT sessionid;
-        rv = saHpiSessionOpen( SAHPI_UNSPECIFIED_DOMAIN_ID, &sessionid, 0 );
+        GOptionContext *context;
 
-        if ( rv != SA_OK ) {
-                printf( "saHpiSessionOpen: %s\n", oh_lookup_error( rv ) );
-                return 1;
+        /* Print version strings */
+	oh_prog_version(argv[0]);
+
+        /* Parsing options */
+        static char usetext[]="- Show \"Fan Control\" management instruments\n  "
+                              OH_SVN_REV; 
+        OHC_PREPARE_REVISION(usetext);
+        context = g_option_context_new (usetext);
+        g_option_context_add_main_entries (context, my_options, NULL);
+
+        if (!ohc_option_parse(&argc, argv, 
+                context, &copt, 
+                OHC_ALL_OPTIONS 
+                    - OHC_ENTITY_PATH_OPTION  //TODO: Feature 880127
+                    - OHC_VERBOSE_OPTION )) { // no verbose mode implemented
+                g_option_context_free (context);
+		return 1;
+	}
+        g_option_context_free (context);
+ 
+        if (f_speed) {
+           set_new = SAHPI_TRUE;
+           if ( strcmp( f_speed, "auto" ) == 0 ) {
+              new_mode = SAHPI_CTRL_MODE_AUTO;
+           } else if ( strcmp( f_speed, "0" ) == 0 ) {
+              new_speed = 0;
+           } else {
+              new_speed = atoi( f_speed );
+              if (new_speed == 0) {
+                 CRIT ("please enter a valid speed: \"auto\" or a number.\n");
+                 g_free (f_speed);
+                 return 1;
+              }
+           }
+           g_free(f_speed);
         }
 
-        rv = saHpiDiscover( sessionid );
+        rv = ohc_session_open_by_option ( &copt, &sessionid);
+	if (rv != SA_OK) return rv;
 
+	/*
+	 * Resource discovery
+	 */
+	if (copt.debug) DBG("saHpiDiscover");
+	rv = saHpiDiscover(sessionid);
         if ( rv != SA_OK ) {
-                printf( "saHpiDiscover: %s\n", oh_lookup_error( rv ) );
-                return 1;
+                CRIT( "saHpiDiscover: %s", oh_lookup_error( rv ) );
+                return rv;
         }
+	if (copt.debug) DBG("Discovery done");
 
         int rc = discover_domain( sessionid );
 
         rv = saHpiSessionClose( sessionid );
-
         if ( rv != SA_OK )
-                printf( "saHpiSessionClose: %s\n", oh_lookup_error( rv ) );
+                CRIT( "saHpiSessionClose: %s", oh_lookup_error( rv ) );
 
         return  rc;
 }
