@@ -31,7 +31,7 @@
 
 #include "oh_clients.h"
 
-#define OH_SVN_REV "$Revision: 7291 $"
+#define OH_SVN_REV "$Revision: 7343 $"
 
 /* 
  * Function prototypes
@@ -153,7 +153,7 @@ main(int argc, char **argv)
 	}
         g_option_context_free (context);
  
-	if (f_rpt || f_sensor || f_inv || f_ctrl || f_rdr || f_wdog) 
+	if (!(f_rpt || f_sensor || f_inv || f_ctrl || f_rdr || f_wdog)) 
            f_listall = TRUE;
 	if (f_resourceid != 0) f_allres = FALSE;
 
