@@ -18,9 +18,10 @@
 #ifndef _INC_HPI_CMD_H
 #define _INC_HPI_CMD_H
 #include <SaHpi.h>
-#include <hpi_ui.h>
 #include <glib.h>
 
+#include "hpi_ui.h"
+
 #define KUZ_DEBUG0
 
 #define READ_BUF_SIZE	1024
@@ -107,7 +108,6 @@ extern ret_code_t	ctrl_block_setst(void);
 extern ret_code_t	ctrl_block_show(void);
 extern ret_code_t	ctrl_block_state(void);
 extern void		delete_progress(void);
-extern int		do_discover(Domain_t *domain);
 extern void		do_progress(char *mes);
 extern ret_code_t	domain_proc(void);
 extern char		*get_command_line(int new_cmd, int type);
@@ -119,7 +119,6 @@ extern char		*get_last_history(void);
 extern int		get_new_command(char *mes);
 extern int		get_string_param(char *mes, char *string, int len);
 extern term_def_t	*get_next_term(void);
-extern int		get_sessionId(Domain_t *domain);
 extern void		help(int as);
 extern ret_code_t	history_cmd(void);
 extern ret_code_t	hs_block(void);
