@@ -17,10 +17,16 @@
 #ifndef __OH_SESSION_H
 #define __OH_SESSION_H
 
-#include <SaHpi.h>
-#include <oh_event.h>
 #include <glib.h>
 
+#include <SaHpi.h>
+
+#include <oh_utils.h>
+
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 /*
  *  Global table of all active sessions (oh_session).  This table is
  *  populated and depopulated by calls to saHpiSessionOpen() and
@@ -30,7 +36,11 @@
 struct oh_session_table {
         GHashTable *table;
         GSList *list;
+#if GLIB_CHECK_VERSION (2, 32, 0)
+        GRecMutex lock;
+#else
         GStaticRecMutex lock;
+#endif
 };
 
 extern struct oh_session_table oh_sessions;
@@ -76,7 +86,10 @@ SaErrorT oh_dequeue_session_event(SaHpiSessionIdT sid,
                                   struct oh_event *event,
                                   SaHpiEvtQueueStatusT *eventq_status);
 SaErrorT oh_destroy_session(SaHpiSessionIdT sid);
-SaErrorT oh_destroy_domain_sessions(SaHpiDomainIdT did);
+
+#ifdef __cplusplus
+} /* extern "C" */
+#endif
 
 #endif /* __OH_SESSION_H */
 
