@@ -12,6 +12,7 @@
  *     Chris Rinaldo <chris.rinaldo@sun.com>
  */
 
+#include <glib.h>
 #include "marshal.h"
 #include <glib.h>
 #include <string.h>
@@ -26,7 +27,7 @@ main( int argc, char *argv[] )
   memcpy( &swap, &value, sizeof( tUint64 ) );
   swap = GUINT64_SWAP_LE_BE( swap );
 
-  unsigned int s = Demarshal( MarshalByteOrder() ? 0 : 1,
+  unsigned int s = Demarshal( G_BYTE_ORDER == G_LITTLE_ENDIAN ? G_BIG_ENDIAN : G_LITTLE_ENDIAN,
                               &Marshal_Float64Type, &result, &swap );
 
   if ( s != sizeof( tFloat64 ) )
