@@ -2,8 +2,8 @@
 #define __OPENHPI_CONFIG_H
 
 
-#define OH_CLIENT_DEFAULT_CONF ""
-#define OH_DEFAULT_CONF ""
+#define OH_CLIENT_DEFAULT_CONF "%APPDATA%\\openhpi\\openhpiclient.conf"
+#define OH_DEFAULT_CONF "%APPDATA%\\openhpi\\openhpi.conf"
 #define OH_DEFAULT_UID_MAP ""
 #define OH_PLUGIN_PATH ""
 #define VARPATH ""
