@@ -1,6 +1,6 @@
 /*      -*- linux-c -*-
  *
- * (C) Copyright IBM Corp. 2004-2006
+ * (C) Copyright IBM Corp. 2004-2008
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -10,32 +10,25 @@
  * full licensing terms.
  *
  * Author(s):
- *      Renier Morales <renierm@users.sf.net>
+ *      Renier Morales <renier@openhpi.org>
  *
  */
 
-#include <sys/time.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <fcntl.h>
-#include <unistd.h>
+#include <stdio.h>
 #include <string.h>
 
-#include <oh_alarm.h>
-#include <oh_config.h>
 #include <oh_error.h>
 #include <oh_utils.h>
 
+#include "alarm.h"
+#include "conf.h"
+
 static void __update_dat(struct oh_domain *d)
 {
-        struct timeval tv;
-
         if (!d) return;
 
-        gettimeofday(&tv, NULL);
-
         d->dat.update_count++;
-        d->dat.update_timestamp = (SaHpiTimeT) tv.tv_sec * 1000000000 + tv.tv_usec * 1000;
+        oh_gettimeofday(&d->dat.update_timestamp);
 }
 
 static GSList *__get_alarm_node(struct oh_domain *d,
@@ -78,7 +71,7 @@ static GSList *__get_alarm_node(struct oh_domain *d,
                     (num ? alarm->AlarmCond.SensorNum == *num : 1) &&
                     (state ? alarm->AlarmCond.EventState == *state : 1) &&
                     (unacknowledged ? !alarm->Acknowledged : 1)) {
-			return alarms;
+                        return alarms;
                 }
         }
 
@@ -123,12 +116,10 @@ static SaHpiUint32T __count_alarms(struct oh_domain *d,
  **/
 SaHpiAlarmT *oh_add_alarm(struct oh_domain *d, SaHpiAlarmT *alarm, int fromfile)
 {
-        struct timeval tv1;
         SaHpiAlarmT *a = NULL;
         struct oh_global_param param = { .type = OPENHPI_DAT_SIZE_LIMIT };
 
         if (!d) {
-                dbg("NULL domain pointer passed.");
                 return NULL;
         }
 
@@ -137,7 +128,7 @@ SaHpiAlarmT *oh_add_alarm(struct oh_domain *d, SaHpiAlarmT *alarm, int fromfile)
 
         if (param.u.dat_size_limit != OH_MAX_DAT_SIZE_LIMIT &&
             g_slist_length(d->dat.list) >= param.u.dat_size_limit) {
-                dbg("DAT for domain %d is overflowed", d->id);
+                CRIT("DAT for domain %d is overflowed", d->id);
                 d->dat.overflow = SAHPI_TRUE;
                 return NULL;
         } else if (alarm && alarm->AlarmCond.Type == SAHPI_STATUS_COND_TYPE_USER) {
@@ -149,7 +140,7 @@ SaHpiAlarmT *oh_add_alarm(struct oh_domain *d, SaHpiAlarmT *alarm, int fromfile)
                     __count_alarms(d,
                                    &alarm->AlarmCond.Type,
                                    SAHPI_ALL_SEVERITIES) >= param.u.dat_user_limit) {
-                        dbg("DAT for domain %d has reached its user alarms limit", d->id);
+                        CRIT("DAT for domain %d has reached its user alarms limit", d->id);
                         return NULL;
                 }
         }
@@ -157,21 +148,19 @@ SaHpiAlarmT *oh_add_alarm(struct oh_domain *d, SaHpiAlarmT *alarm, int fromfile)
         a = g_new0(SaHpiAlarmT, 1);
         if (alarm) { /* Copy contents of optional alarm reference */
                 memcpy(a, alarm, sizeof(SaHpiAlarmT));
-	}
+        }
 
-	if (fromfile) {
-		if (a->AlarmId > d->dat.next_id) {
-			d->dat.next_id = a->AlarmId;
-		}
-	} else {
-		a->AlarmId = ++(d->dat.next_id);
-        	gettimeofday(&tv1, NULL);
-        	a->Timestamp =
-			(SaHpiTimeT) tv1.tv_sec * 1000000000 + tv1.tv_usec * 1000;
-		a->Acknowledged = SAHPI_FALSE;
-	}
-	a->AlarmCond.DomainId = d->id;
-	d->dat.list = g_slist_append(d->dat.list, a);
+        if (fromfile) {
+                if (a->AlarmId > d->dat.next_id) {
+                        d->dat.next_id = a->AlarmId;
+                }
+        } else {
+                a->AlarmId = ++(d->dat.next_id);
+                oh_gettimeofday(&a->Timestamp);
+                a->Acknowledged = SAHPI_FALSE;
+        }
+        a->AlarmCond.DomainId = d->id;
+        d->dat.list = g_slist_append(d->dat.list, a);
 
         /* Set alarm id and timestamp info in alarm reference */
         if (alarm) {
@@ -179,19 +168,19 @@ SaHpiAlarmT *oh_add_alarm(struct oh_domain *d, SaHpiAlarmT *alarm, int fromfile)
                 alarm->Timestamp = a->Timestamp;
         }
 
-	if (!fromfile) {
-		__update_dat(d);
-		param.type = OPENHPI_DAT_SAVE;
-		oh_get_global_param(&param);
-		if (param.u.dat_save) {
-			char dat_filepath[SAHPI_MAX_TEXT_BUFFER_LENGTH*2];
-			param.type = OPENHPI_VARPATH;
-			oh_get_global_param(&param);
-			snprintf(dat_filepath, SAHPI_MAX_TEXT_BUFFER_LENGTH*2,
-					"%s/dat.%u", param.u.varpath, d->id);
-			oh_alarms_to_file(&d->dat, dat_filepath);
-		}
-	}
+        if (!fromfile) {
+                __update_dat(d);
+                param.type = OPENHPI_DAT_SAVE;
+                oh_get_global_param(&param);
+                if (param.u.dat_save) {
+                        char dat_filepath[SAHPI_MAX_TEXT_BUFFER_LENGTH*2];
+                        param.type = OPENHPI_VARPATH;
+                        oh_get_global_param(&param);
+                        snprintf(dat_filepath, SAHPI_MAX_TEXT_BUFFER_LENGTH*2,
+                                        "%s/dat.%u", param.u.varpath, d->id);
+                        oh_alarms_to_file(&d->dat, dat_filepath);
+                }
+        }
 
         return a;
 }
@@ -261,7 +250,7 @@ SaErrorT oh_remove_alarm(struct oh_domain *d,
 {
         GSList *alarm_node = NULL;
         SaHpiAlarmT *alarm = NULL;
-	SaHpiAlarmIdT aid = SAHPI_FIRST_ENTRY; /* Set to zero */
+        SaHpiAlarmIdT aid = SAHPI_FIRST_ENTRY; /* Set to zero */
         struct oh_global_param param = { .type = OPENHPI_DAT_SIZE_LIMIT };
 
         if (!d) return SA_ERR_HPI_INVALID_PARAMS;
@@ -270,9 +259,9 @@ SaErrorT oh_remove_alarm(struct oh_domain *d,
                 alarm_node = __get_alarm_node(d, &aid, severity, type, rid, mid,
                                               num, state, 0, 1);
                 if (alarm_node) alarm = alarm_node->data;
-		else break;
+                else break;
 
-		aid = alarm->AlarmId;
+                aid = alarm->AlarmId;
                 if (deassert_mask ? *deassert_mask & alarm->AlarmCond.EventState : 1) {
                         d->dat.list = g_slist_delete_link(d->dat.list, alarm_node);
                         g_free(alarm);
@@ -335,7 +324,7 @@ SaHpiUint32T oh_count_alarms(struct oh_domain *d, SaHpiSeverityT sev)
 
 static void oh_detect_oem_event_alarm(struct oh_domain *d, SaHpiEventT *event)
 {
-        SaHpiAlarmT *a = NULL;
+        SaHpiAlarmT a;
         SaHpiStatusCondTypeT type = SAHPI_STATUS_COND_TYPE_OEM;
 
         if (!d || !event) return;
@@ -349,24 +338,25 @@ static void oh_detect_oem_event_alarm(struct oh_domain *d, SaHpiEventT *event)
         }
 
         /* Severity is "alarming". Add/Create OEM alarm */
-        a = oh_add_alarm(d, NULL, 0);
-        if (!a) goto done;
-        a->Severity = event->Severity;
-        a->AlarmCond.Type = SAHPI_STATUS_COND_TYPE_OEM;
-        oh_entity_path_lookup(event->Source, &a->AlarmCond.Entity);
-        a->AlarmCond.ResourceId = event->Source;
-        a->AlarmCond.Mid = event->EventDataUnion.OemEvent.MId;
-        memcpy(&a->AlarmCond.Data,
+        memset( &a, 0, sizeof( a ) );	/* Make sure alarm has valid fields */
+        a.Severity = event->Severity;
+        a.AlarmCond.Type = type;
+        oh_entity_path_lookup(event->Source, &a.AlarmCond.Entity);
+        a.AlarmCond.ResourceId = event->Source;
+        a.AlarmCond.Mid = event->EventDataUnion.OemEvent.MId;
+        memcpy(&a.AlarmCond.Data,
                &event->EventDataUnion.OemEvent.OemEventData,
                sizeof(SaHpiTextBufferT));
-done:
-        return;
+        
+	oh_add_alarm(d, &a, 0);
+        
+	return;
 }
 
 static void oh_detect_resource_event_alarm(struct oh_domain *d, SaHpiEventT *event)
 {
         SaHpiStatusCondTypeT type = SAHPI_STATUS_COND_TYPE_RESOURCE;
-        SaHpiAlarmT *a = NULL;
+        SaHpiAlarmT a;
 
         if (!d || !event) return;
 
@@ -384,24 +374,33 @@ static void oh_detect_resource_event_alarm(struct oh_domain *d, SaHpiEventT *eve
         /* Failed resource.
            Add/Create resource alarm if severity is "alarming" */
         if (event->Severity <= SAHPI_MINOR) {
-                a = oh_add_alarm(d, NULL, 0);
-                if (!a) goto done;
-                a->Severity = event->Severity;
-                a->AlarmCond.Type = SAHPI_STATUS_COND_TYPE_RESOURCE;
-                oh_entity_path_lookup(event->Source, &a->AlarmCond.Entity);
-                a->AlarmCond.ResourceId = event->Source;
+                memset( &a, 0, sizeof( a ) ); /* Make sure alarm has valid
+					       * fields
+					       */
+                a.Severity = event->Severity;
+                a.AlarmCond.Type = type;
+                oh_entity_path_lookup(event->Source, &a.AlarmCond.Entity);
+                a.AlarmCond.ResourceId = event->Source;
+                oh_add_alarm(d, &a, 0);
         }
-done:
-        return;
+        
+	return;
 }
 
 static void oh_detect_sensor_event_alarm(struct oh_domain *d, SaHpiEventT *event)
 {
         SaHpiStatusCondTypeT type = SAHPI_STATUS_COND_TYPE_SENSOR;
-        SaHpiAlarmT *a = NULL;
+        SaHpiAlarmT a;
 
         if (!d || !event) return;
 
+        if ( ( event->EventDataUnion.SensorEvent.OptionalDataPresent & SAHPI_SOD_CURRENT_STATE ) != 0 ) {
+                SaHpiEventStateT deasserted = ~ ( event->EventDataUnion.SensorEvent.CurrentState );
+                oh_remove_alarm(d, NULL, &type, &event->Source, NULL,
+                                &event->EventDataUnion.SensorEvent.SensorNum,
+                                NULL,
+                                &deasserted, 1);
+        }
         if (!event->EventDataUnion.SensorEvent.Assertion) {
                 /* Check for possible sensor alarm removals,
                    since sensor is not asserted. */
@@ -413,17 +412,35 @@ static void oh_detect_sensor_event_alarm(struct oh_domain *d, SaHpiEventT *event
                    event->EventDataUnion.SensorEvent.Assertion) {
                 /* Add sensor alarm to dat, since event is severe
                    enough and is asserted. */
-                a = oh_add_alarm(d, NULL, 0);
-                if (!a) goto done;
-                a->Severity = event->Severity;
-                a->AlarmCond.Type = SAHPI_STATUS_COND_TYPE_SENSOR;
-                oh_entity_path_lookup(event->Source, &a->AlarmCond.Entity);
-                a->AlarmCond.ResourceId = event->Source;
-                a->AlarmCond.SensorNum = event->EventDataUnion.SensorEvent.SensorNum;
-                a->AlarmCond.EventState = event->EventDataUnion.SensorEvent.EventState;
+                memset( &a, 0, sizeof( a ) ); /* Make sure alarm has valid
+					       * fields
+					       */
+                a.Severity = event->Severity;
+                a.AlarmCond.Type = type;
+                oh_entity_path_lookup(event->Source, &a.AlarmCond.Entity);
+                a.AlarmCond.ResourceId = event->Source;
+                a.AlarmCond.SensorNum = event->EventDataUnion.SensorEvent.SensorNum;
+                a.AlarmCond.EventState = event->EventDataUnion.SensorEvent.EventState;
+                oh_add_alarm(d, &a, 0);
         }
-done:
-        return;
+        
+	return;
+}
+
+static void oh_detect_sensor_enable_change_alarm(struct oh_domain *d,
+                                                 SaHpiEventT *event)
+{
+        SaHpiStatusCondTypeT type = SAHPI_STATUS_COND_TYPE_SENSOR;
+
+        if (!d || !event) return;
+
+        if (!event->EventDataUnion.SensorEnableChangeEvent.SensorEnable ||
+            !event->EventDataUnion.SensorEnableChangeEvent.SensorEventEnable) {
+                oh_remove_alarm(d, NULL, &type, &event->Source, NULL,
+                                &event->EventDataUnion.SensorEnableChangeEvent.SensorNum,
+                                NULL, NULL, 1);
+        }
+
 }
 
 static void oh_remove_resource_alarms(struct oh_domain *d, SaHpiResourceIdT rid, int all)
@@ -460,6 +477,9 @@ static void oh_detect_hpi_alarm(struct oh_domain *d, SaHpiEventT *event)
                 case SAHPI_ET_SENSOR:
                         oh_detect_sensor_event_alarm(d, event);
                         break;
+                case SAHPI_ET_SENSOR_ENABLE_CHANGE:
+                        oh_detect_sensor_enable_change_alarm(d, event);
+                        break;
                 default:;
         }
 
@@ -468,8 +488,8 @@ static void oh_detect_hpi_alarm(struct oh_domain *d, SaHpiEventT *event)
 
 static void oh_detect_resource_alarm(struct oh_domain *d, SaHpiRptEntryT *res)
 {
-        SaHpiAlarmT *a = NULL;
-        SaHpiStatusCondTypeT type = SAHPI_STATUS_COND_TYPE_SENSOR;
+        SaHpiAlarmT a;
+        SaHpiStatusCondTypeT type = SAHPI_STATUS_COND_TYPE_RESOURCE;
 
         if (!d || !res) return;
 
@@ -479,17 +499,19 @@ static void oh_detect_resource_alarm(struct oh_domain *d, SaHpiRptEntryT *res)
                                 NULL, NULL, NULL, 1);
         } else if (res->ResourceSeverity <= SAHPI_MINOR && res->ResourceFailed) {
                 /* Otherwise, if sev is "alarming" and resource failed, create alarm. */
-                a = oh_add_alarm(d, NULL, 0);
-                if (!a) goto done;
-                a->Severity = res->ResourceSeverity;
-                a->AlarmCond.Type = SAHPI_STATUS_COND_TYPE_RESOURCE;
-                oh_entity_path_lookup(res->ResourceId, &a->AlarmCond.Entity);
-                a->AlarmCond.ResourceId = res->ResourceId;
-                a->AlarmCond.Mid = res->ResourceInfo.ManufacturerId;
-                memcpy(&a->AlarmCond.Data, &res->ResourceTag, sizeof(SaHpiTextBufferT));
+                memset( &a, 0, sizeof( a ) ); /* Make sure alarm has valid
+					       * fields
+					       */
+                a.Severity = res->ResourceSeverity;
+                a.AlarmCond.Type = SAHPI_STATUS_COND_TYPE_RESOURCE;
+                oh_entity_path_lookup(res->ResourceId, &a.AlarmCond.Entity);
+                a.AlarmCond.ResourceId = res->ResourceId;
+                a.AlarmCond.Mid = res->ResourceInfo.ManufacturerId;
+                memcpy(&a.AlarmCond.Data, &res->ResourceTag, sizeof(SaHpiTextBufferT));
+                oh_add_alarm(d, &a, 0);
         }
-done:
-        return;
+        
+	return;
 }
 
 /**
@@ -510,20 +532,20 @@ SaErrorT oh_detect_event_alarm(struct oh_domain *d,
 
         etype = e->event.EventType;
         if (etype == SAHPI_ET_RESOURCE) {
-		if (e->resource.ResourceId) {
-	        	oh_detect_resource_alarm(d, &e->resource);
-		} else {
-			oh_detect_resource_event_alarm(d, &e->event);
-		}
+                if (e->resource.ResourceId) {
+                        oh_detect_resource_alarm(d, &e->resource);
+                } else {
+                        oh_detect_resource_event_alarm(d, &e->event);
+                }
         } else if (etype == SAHPI_ET_HOTSWAP) {
-        	if (e->event.EventDataUnion.HotSwapEvent.HotSwapState ==
-		    SAHPI_HS_STATE_NOT_PRESENT) {
-		    	SaHpiResourceIdT rid = e->resource.ResourceId;
-		    	if (!rid) rid = e->event.Source;
-		    	oh_remove_resource_alarms(d, rid, 1);
-		}
+                if (e->event.EventDataUnion.HotSwapEvent.HotSwapState ==
+                    SAHPI_HS_STATE_NOT_PRESENT) {
+                            SaHpiResourceIdT rid = e->resource.ResourceId;
+                            if (!rid) rid = e->event.Source;
+                            oh_remove_resource_alarms(d, rid, 1);
+                }
         } else {
-        	oh_detect_hpi_alarm(d, &e->event);
+                oh_detect_hpi_alarm(d, &e->event);
         }
 
         return SA_OK;
@@ -547,7 +569,7 @@ SaErrorT oh_detect_res_sev_alarm(SaHpiDomainIdT did,
         struct oh_domain *d = NULL;
         SaHpiRptEntryT *res = NULL;
 
-        if (!did || !rid) return SA_ERR_HPI_INVALID_PARAMS;
+        if (!rid) return SA_ERR_HPI_INVALID_PARAMS;
 
         d = oh_get_domain(did);
         if (!d) return SA_ERR_HPI_INVALID_DOMAIN;
@@ -567,13 +589,13 @@ SaErrorT oh_detect_res_sev_alarm(SaHpiDomainIdT did,
 
 
 /**
- * oh_detect_sensor_alarm
+ * oh_detect_sensor_enable_alarm
  * @did: domain id
  * @rid: resource id
  * @num: sensor number
  * @enable: sensor enable flag
  *
- * This will detect if a sensor related alarm needs to be removed,
+ * This will detect if a sensor-enable related alarm needs to be removed,
  * and if so, will remove it accordingly.
  *
  * Return value: SA_OK on success
@@ -587,7 +609,7 @@ SaErrorT oh_detect_sensor_enable_alarm(SaHpiDomainIdT did,
         SaHpiStatusCondTypeT type = SAHPI_STATUS_COND_TYPE_SENSOR;
         SaErrorT error = SA_OK;
 
-        if (!did || !rid) return SA_ERR_HPI_INVALID_PARAMS;
+        if (!rid) return SA_ERR_HPI_INVALID_PARAMS;
 
         /* Only need to scan alarm table if enable is false */
         if (enable) return SA_OK;
@@ -626,7 +648,7 @@ SaErrorT oh_detect_sensor_mask_alarm(SaHpiDomainIdT did,
         SaHpiStatusCondTypeT type = SAHPI_STATUS_COND_TYPE_SENSOR;
         SaErrorT error = SA_OK;
 
-        if (!did || !rid) return SA_ERR_HPI_INVALID_PARAMS;
+        if (!rid) return SA_ERR_HPI_INVALID_PARAMS;
 
         if (action == SAHPI_SENS_ADD_EVENTS_TO_MASKS)
                 return SA_OK;
@@ -658,36 +680,30 @@ SaErrorT oh_detect_sensor_mask_alarm(SaHpiDomainIdT did,
  **/
 SaErrorT oh_alarms_to_file(struct oh_dat *at, char *filename)
 {
-	GSList *alarms = NULL;
-	int file;
+        GSList *alarms = NULL;
+        FILE * fp;
 
-	if (!at || !filename) {
-		dbg("Invalid Parameters");
-		return SA_ERR_HPI_INVALID_PARAMS;
-	}
+        if (!at || !filename) {
+                return SA_ERR_HPI_INVALID_PARAMS;
+        }
 
-	file = open(filename, O_WRONLY | O_CREAT | O_TRUNC, 0660 );
-	if (file < 0) {
-		dbg("File '%s' could not be opened", filename);
-		return SA_ERR_HPI_ERROR;
-	}
+        fp = fopen(filename, "wb");
+        if (!fp) {
+                CRIT("File '%s' could not be opened", filename);
+                return SA_ERR_HPI_ERROR;
+        }
 
-	for (alarms = at->list; alarms; alarms = alarms->next) {
-		int bytes_written = 0;
-		bytes_written = write(file, (void *)alarms->data, sizeof(SaHpiAlarmT));
-		if (bytes_written != sizeof(SaHpiAlarmT)) {
-			dbg("Couldn't write to file '%s'.", filename);
-                        close(file);
+        for (alarms = at->list; alarms; alarms = alarms->next) {
+                if (fwrite(alarms->data, sizeof(SaHpiAlarmT), 1, fp) != 1) {
+                        CRIT("Couldn't write to file '%s'.", filename);
+                        fclose(fp);
                         return SA_ERR_HPI_ERROR;
-		}
-	}
+                }
+        }
 
-	if (close(file) != 0) {
-        	dbg("Couldn't close file '%s'.", filename);
-		return SA_ERR_HPI_ERROR;
-	}
+        fclose(fp);
 
-	return SA_OK;
+        return SA_OK;
 }
 
 /**
@@ -701,34 +717,30 @@ SaErrorT oh_alarms_to_file(struct oh_dat *at, char *filename)
  **/
 SaErrorT oh_alarms_from_file(struct oh_domain *d, char *filename)
 {
-	int file;
-	SaHpiAlarmT alarm;
+        FILE *fp;
+        SaHpiAlarmT alarm;
 
-	if (!d || !filename) {
-		dbg("Invalid Parameters");
-		return SA_ERR_HPI_ERROR;
-	}
-
-	file = open(filename, O_RDONLY);
-        if (file < 0) {
-                dbg("File '%s' could not be opened", filename);
+        if (!d || !filename) {
                 return SA_ERR_HPI_ERROR;
         }
 
-	while (read(file, &alarm, sizeof(SaHpiAlarmT)) == sizeof(SaHpiAlarmT)) {
-		SaHpiAlarmT *a = oh_add_alarm(d, &alarm, 1);
-		if (!a) {
-			close(file);
-			dbg("Error adding alarm read from file.");
-			return SA_ERR_HPI_ERROR;
-		}
-	}
+        fp = fopen(filename, "rb");
+        if (!fp) {
+                CRIT("File '%s' could not be opened", filename);
+                return SA_ERR_HPI_ERROR;
+        }
 
-	if (close(file) != 0) {
-        	dbg("Couldn't close file '%s'.", filename);
-        	return SA_ERR_HPI_ERROR;
-	}
+        while (fread(&alarm, sizeof(SaHpiAlarmT), 1, fp) == 1) {
+                SaHpiAlarmT *a = oh_add_alarm(d, &alarm, 1);
+                if (!a) {
+                        fclose(fp);
+                        CRIT("Error adding alarm read from file.");
+                        return SA_ERR_HPI_ERROR;
+                }
+        }
 
-	return SA_OK;
+        fclose(fp);
+
+        return SA_OK;
 }
 
