@@ -19,22 +19,32 @@
  *     Bryan Sutula <sutula@users.sourceforge.net>
  */
 
+#include <inttypes.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <limits.h>
 
+#ifndef _WIN32
+#include <sys/stat.h>
+#include <sys/types.h>
+#include <unistd.h>
+#include <libgen.h>
+#include <errno.h>
+#endif // _WIN32
+ 
 #include <config.h>
 #include <oh_plugin.h>
 #include <oh_error.h>
 
 #include "conf.h"
 #include "lock.h"
+#include "sahpi_wrappers.h"
 
 /*
  * Global Parameters
  */
 static const char *known_globals[] = {
-        "OPENHPI_ON_EP",
         "OPENHPI_LOG_ON_SEV",
         "OPENHPI_EVT_QUEUE_LIMIT",
         "OPENHPI_DEL_SIZE_LIMIT",
@@ -53,7 +63,6 @@ static const char *known_globals[] = {
 };
 
 static struct {
-        SaHpiEntityPathT on_ep;
         SaHpiSeverityT log_on_sev;
         SaHpiUint32T evt_queue_limit;
         SaHpiUint32T del_size_limit;
@@ -71,7 +80,6 @@ static struct {
         unsigned char read_env;
         GStaticRecMutex lock;
 } global_params = { /* Defaults for global params are set here */
-        .on_ep = { .Entry[0] = { .EntityType = SAHPI_ENT_ROOT, .EntityLocation = 0 } },
         .log_on_sev = SAHPI_MINOR,
         .evt_queue_limit = 10000,
         .del_size_limit = 10000, /* 0 is unlimited size */
@@ -166,15 +174,14 @@ static GScannerConfig oh_scanner_config =
                 TRUE                    /* char_2_token */,
                 TRUE                    /* symbol_2_token */,
                 FALSE                   /* scope_0_fallback */,
+                TRUE                    /* store_int64 */,
         };
 
 static void process_global_param(const char *name, char *value)
 {
-        g_static_rec_mutex_lock(&global_params.lock);
+        wrap_g_static_rec_mutex_lock((void *)&global_params.lock);
 
-        if (!strcmp("OPENHPI_ON_EP", name)) {
-                oh_encode_entitypath(value, &global_params.on_ep);
-        } else if (!strcmp("OPENHPI_LOG_ON_SEV", name)) {
+        if (!strcmp("OPENHPI_LOG_ON_SEV", name)) {
                 SaHpiTextBufferT buffer;
                 strncpy((char *)buffer.Data, value, SAHPI_MAX_TEXT_BUFFER_LENGTH);
                 oh_encode_severity(&buffer, &global_params.log_on_sev);
@@ -214,7 +221,16 @@ static void process_global_param(const char *name, char *value)
                         global_params.unconfigured = SAHPI_FALSE;
                 }
         } else if (!strcmp("OPENHPI_AUTOINSERT_TIMEOUT", name)) {
-                global_params.ai_timeout = strtoll(value, 0, 10);
+                if (!strcmp(value, "BLOCK")) {
+                    global_params.ai_timeout = SAHPI_TIMEOUT_BLOCK;
+                } else if (!strcmp(value, "IMMEDIATE")) {
+                    global_params.ai_timeout = SAHPI_TIMEOUT_IMMEDIATE;
+                } else {
+                    global_params.ai_timeout = strtoll(value, 0, 10);
+                    if (global_params.ai_timeout < 0) {
+                        global_params.ai_timeout = SAHPI_TIMEOUT_BLOCK;
+                    }
+                }
         } else if (!strcmp("OPENHPI_AUTOINSERT_TIMEOUT_READONLY", name)) {
                 if (!strcmp("YES", value)) {
                         global_params.ai_timeout_readonly = SAHPI_TRUE;
@@ -225,7 +241,7 @@ static void process_global_param(const char *name, char *value)
                 CRIT("Invalid global parameter %s in config file.", name);
         }
 
-        g_static_rec_mutex_unlock(&global_params.lock);
+        wrap_g_static_rec_mutex_unlock(&global_params.lock);
 }
 
 static void read_globals_from_env(int force)
@@ -235,7 +251,7 @@ static void read_globals_from_env(int force)
 
         if (!force && global_params.read_env) return;
 
-        g_static_rec_mutex_lock(&global_params.lock);
+        wrap_g_static_rec_mutex_lock(&global_params.lock);
 
         for (i = 0; known_globals[i]; i++) {
                 if ((tmp_env_str = getenv(known_globals[i])) != NULL) {
@@ -245,7 +261,7 @@ static void read_globals_from_env(int force)
         }
 
         global_params.read_env = 1;
-        g_static_rec_mutex_unlock(&global_params.lock);
+        wrap_g_static_rec_mutex_unlock(&global_params.lock);
 }
 
 /**
@@ -321,10 +337,18 @@ static int process_handler_token (GScanner* oh_scanner)
                         int current_token = g_scanner_get_next_token(oh_scanner);
 
                         if (current_token == G_TOKEN_INT) {
+                                // TODO seems everyone now relies that 
+                                // value shall be string.
+                                // So this code may break a plug-in expectations.
+                                // Investigate
                                 gulong *value_int = g_new0(gulong, 1);
-                                *value_int = oh_scanner->value.v_int;
+                                *value_int = (gulong)oh_scanner->value.v_int64;
                                 value = (gpointer)value_int;
                         } else if (current_token == G_TOKEN_FLOAT) {
+                                // TODO seems everyone now relies that 
+                                // value shall be string.
+                                // So this code may break a plug-in expectations.
+                                // Investigate
                                 gdouble *value_float = g_new0(gdouble, 1);
                                 *value_float = oh_scanner->value.v_float;
                                 value = (gpointer)value_float;
@@ -413,15 +437,9 @@ static int process_global_token(GScanner *scanner)
         }
 
         if (current_token == G_TOKEN_INT) {
-                guint num_chars = 0, result;
-                result = scanner->value.v_int;
-                while (result) {
-                        result = result / 10;
-                        num_chars++;
-                }
-                value = (char *)g_malloc0(++num_chars);
-                result = scanner->value.v_int;
-                snprintf(value, num_chars, "%u", result);
+                const guint max_digits = 32; // More than enough for uint64.
+                value = (char *)g_malloc0(max_digits);
+                snprintf(value, max_digits, "%" PRIu64, scanner->value.v_int64);
         } else {
                 value = g_strdup(scanner->value.v_string);
         }
@@ -475,10 +493,20 @@ static void scanner_msg_handler (GScanner *scanner, gchar *message, gboolean is_
  **/
 int oh_load_config (char *filename, struct oh_parsed_config *config)
 {
-        FILE * fp;
-        int i;
+        FILE * fp = NULL;
+#ifndef _WIN32
+        struct stat fst, dst; 
+        char *dir_name = NULL;
+        char dup_filename[PATH_MAX];
+#ifdef HAVE_ENCRYPT
+        SaHpiUint32T type = OHPI_DECRYPT;
+        gchar *confile_txt = NULL;
+#endif /* HAVE_ENCRYPT */
+#endif /* _WIN32 */
+        gchar * gcrypt_str = NULL;
+        gboolean g_decrypt = SAHPI_FALSE;
         GScanner *oh_scanner;
-        int done = 0;
+        int i, done = 0;
         int num_tokens = sizeof(oh_conf_tokens) / sizeof(oh_conf_tokens[0]);
 
         if (!filename || !config) {
@@ -496,17 +524,114 @@ int oh_load_config (char *filename, struct oh_parsed_config *config)
         oh_scanner->msg_handler = scanner_msg_handler;
         oh_scanner->input_name = filename;
 
-        fp = fopen(filename, "r");
-        if (!fp) {
-                CRIT("Configuration file '%s' could not be opened.", filename);
-                g_scanner_destroy(oh_scanner);
+#ifndef _WIN32
+
+        errno=0;
+        if (stat (filename, &fst) == -1) {
+                if (errno != ENOENT) {
+                        CRIT("stat of %s failed.", filename);
+                        g_scanner_destroy(oh_scanner);
+                        return -3;
+                }
+        } 
+       	if (errno != ENOENT) { 
+                if (fst.st_uid != geteuid()) {
+                        if (fst.st_uid == 0) {
+                             CRIT("%s owner is root (0)!", filename);
+                             CRIT("Run as sudo or create a config with UID=%d.", (int)geteuid());
+                             g_scanner_destroy(oh_scanner);
+                             return -3;
+                       } else  {
+                             CRIT("%s owner(%d) is insecure!", filename, fst.st_uid);
+                             CRIT("Owner UID shall be %d.", (int)geteuid());
+                             g_scanner_destroy(oh_scanner);
+                             return -3;
+                       }
+                }
+        
+                if (((fst.st_mode & (S_IRWXG | S_IRWXO)) != 0)) {
+                        CRIT("%s permissions are insecure!", filename);
+                        CRIT("Shall not contain bits for group/others.");
+                        g_scanner_destroy(oh_scanner);
+                        return -3;
+                }
+
+                if ((fst.st_mode & S_IFMT) != S_IFREG) {
+                        CRIT("%s permissions are insecure!", filename);
+                        CRIT("It needs to be a regular file");
+                        g_scanner_destroy(oh_scanner);
+                        return -3;
+                }
+
+                /* Now check the directory permissions */ 
+                if (strlen(filename) >= PATH_MAX) {
+                        CRIT("%s is too long",filename);
+                        g_scanner_destroy(oh_scanner);
+                        return -3;
+                } 
+                strcpy(dup_filename, filename);
+                dir_name=dirname(dup_filename);
+                if (stat(dir_name, &dst) == -1) {
+                        CRIT("stat of %s failed.", dir_name);
+                        g_scanner_destroy(oh_scanner);
+                        return -3;
+                }
+
+                if ((fst.st_uid != dst.st_uid)) {
+                        CRIT("%s directory is insecure", dir_name);
+                        CRIT("Owner UID shall be %d",fst.st_uid);
+                        g_scanner_destroy(oh_scanner);
+                        return -3;
+                }
+                if ((dst.st_mode & (S_IWOTH | S_IWGRP)) != 0 ) {
+                        CRIT("%s directory is insecure",dir_name);
+                        CRIT("Shall not be writable by group or others");
+                        g_scanner_destroy(oh_scanner);
+                        return -3;
+                }
+	}
+
+#endif // _WIN32
+         
+        gcrypt_str = getenv("OPENHPI_GCRYPT");
+        if(gcrypt_str)
+               g_decrypt = atoi((const char *)gcrypt_str);
+        if(g_decrypt) {
+#ifndef _WIN32
+#ifdef HAVE_ENCRYPT
+                confile_txt = oh_crypt(filename, type);
+                if(!confile_txt) {
+                        CRIT("Unable to decrypt %s\n",filename);
+                        g_scanner_destroy(oh_scanner);
+                        return -3;
+                }
+
+                g_scanner_input_text(oh_scanner, confile_txt, fst.st_size);
+#else
+                CRIT("gcrypt asked for but not compiled with. Internal Error");
                 return -4;
+#endif /* HAVE_ENCRYPT */
+
+
+#else
+                WARN("Encrypting %s not supported",filename);
+                WARN("Assuming plain file");
+#endif
+        } else {
+               fp = fopen(filename, "r");
+               if (!fp) {
+                       CRIT("Configuration file '%s' could not be opened.", filename);
+                       g_scanner_destroy(oh_scanner);
+                       return -4;
+               }
         }
 
 #ifdef _WIN32
         g_scanner_input_file(oh_scanner, _fileno(fp));
 #else
-        g_scanner_input_file(oh_scanner, fileno(fp));
+        if(!g_decrypt) {
+                 g_scanner_input_file(oh_scanner, fileno(fp));
+        }
 #endif
 
         for (i = 0; i < num_tokens; i++) {
@@ -542,16 +667,22 @@ int oh_load_config (char *filename, struct oh_parsed_config *config)
 
         read_globals_from_env(1);
 
-        fclose(fp);
+        if (fp)
+                fclose(fp);
 
         done = oh_scanner->parse_errors;
 
         g_scanner_destroy(oh_scanner);
 
+
         DBG("Done processing conf file. Parse errors: %d", done);
 
         config->handler_configs = handler_configs;
 
+#ifdef HAVE_ENCRYPT
+        free(confile_txt);
+#endif
+
         handler_configs = NULL;
 
         return 0;
@@ -613,22 +744,20 @@ int oh_get_global_param(struct oh_global_param *param)
 
             if (!param) {
                 CRIT("Invalid parameters param NULL.");
+                return -1;
             }
 
             if (!param->type) {
                 CRIT("Invalid parameters param->type NULL.");
+                return -1;
             }
 
-                return -1;
         }
 
         read_globals_from_env(0);
 
-        g_static_rec_mutex_lock(&global_params.lock);
+        wrap_g_static_rec_mutex_lock(&global_params.lock);
         switch (param->type) {
-                case OPENHPI_ON_EP:
-                        param->u.on_ep = global_params.on_ep;
-                        break;
                 case OPENHPI_LOG_ON_SEV:
                         param->u.log_on_sev = global_params.log_on_sev;
                         break;
@@ -675,11 +804,11 @@ int oh_get_global_param(struct oh_global_param *param)
                         param->u.ai_timeout_readonly = global_params.ai_timeout_readonly;
                         break;
                 default:
-                        g_static_rec_mutex_unlock(&global_params.lock);
+                        wrap_g_static_rec_mutex_unlock(&global_params.lock);
                         CRIT("Invalid global parameter %d!", param->type);
                         return -2;
         }
-        g_static_rec_mutex_unlock(&global_params.lock);
+        wrap_g_static_rec_mutex_unlock(&global_params.lock);
 
         return 0;
 }
@@ -717,11 +846,8 @@ int oh_set_global_param(const struct oh_global_param *param)
 
         read_globals_from_env(0);
 
-        g_static_rec_mutex_lock(&global_params.lock);
+        wrap_g_static_rec_mutex_lock(&global_params.lock);
         switch (param->type) {
-                case OPENHPI_ON_EP:
-                        global_params.on_ep = param->u.on_ep;
-                        break;
                 case OPENHPI_LOG_ON_SEV:
                         global_params.log_on_sev = param->u.log_on_sev;
                         break;
@@ -771,11 +897,11 @@ int oh_set_global_param(const struct oh_global_param *param)
                         global_params.ai_timeout_readonly = param->u.ai_timeout_readonly;
                         break;
                 default:
-                        g_static_rec_mutex_unlock(&global_params.lock);
+                        wrap_g_static_rec_mutex_unlock(&global_params.lock);
                         CRIT("Invalid global parameter %d!", param->type);
                         return -2;
         }
-        g_static_rec_mutex_unlock(&global_params.lock);
+        wrap_g_static_rec_mutex_unlock(&global_params.lock);
 
         return 0;
 }
