@@ -14,6 +14,11 @@
  *      Bryan Sutula <sutula@users.sourceforge.net>
  *
  */
+#include <inttypes.h>
+#include <stdint.h>
+#ifdef _WIN32
+#include <windows.h>
+#endif /* _WIN32 */
 
 #include <glib.h>
 
@@ -34,6 +39,7 @@
 #include "init.h"
 #include "lock.h"
 #include "threaded.h"
+#include "sahpi_wrappers.h"
 
 /**
  * oh_init
@@ -48,7 +54,7 @@ int oh_init(void)
         SaErrorT rval;
 
         if (g_thread_supported() == FALSE) {
-            g_thread_init(0);
+            wrap_g_thread_init(0);
         }
 
         data_access_lock();
@@ -70,8 +76,20 @@ int oh_init(void)
 #endif
         /* Set openhpi configuration file location */
         oh_get_global_param2(OPENHPI_CONF, &param);
+#ifdef _WIN32
+        char config_file[MAX_PATH];
+        DWORD cc = ExpandEnvironmentStrings(param.u.conf, config_file, MAX_PATH);
+        if ((cc != 0) && (cc < MAX_PATH)) {
+            INFO("Loading config file %s.", config_file);
+            rval = oh_load_config(config_file, &config);
+        } else {
+            CRIT("Failed to expand config file path: %s", param.u.conf);
+            rval = SA_ERR_HPI_ERROR;
+        }
+#else
         INFO("Loading config file %s.", param.u.conf);
         rval = oh_load_config(param.u.conf, &config);
+#endif /* _WIN32 */
         /* Don't error out if there is no conf file */
         if (rval < 0 && rval != -4) {
                 CRIT("Can not load config.");
@@ -110,7 +128,7 @@ int oh_init(void)
         INFO("Creating default domain.");
         oh_get_global_param2(OPENHPI_AUTOINSERT_TIMEOUT, &param);
         SaHpiTimeoutT ai_timeout = param.u.ai_timeout;
-        INFO("Auto-Insert Timeout is %lld nsec.", ai_timeout);
+        INFO("Auto-Insert Timeout is %" PRId64 " nsec.", (int64_t)ai_timeout);
         oh_get_global_param2(OPENHPI_AUTOINSERT_TIMEOUT_READONLY, &param);
         SaHpiDomainCapabilitiesT caps = 0;
         if ( param.u.ai_timeout_readonly != SAHPI_FALSE ) {
