@@ -18,6 +18,7 @@
  *     Anton Pak <anton.pak@pigeonpoint.com>
  */
 
+#include <inttypes.h>
 #include <stddef.h>
 #include <string.h>
 
@@ -29,26 +30,32 @@
 #include <oh_domain.h>
 #include <oh_error.h>
 #include <oh_plugin.h>
+#include <oh_utils.h>
 
 #include "conf.h"
 #include "event.h"
 #include "lock.h"
+#include "sahpi_wrappers.h"
 
+extern volatile int signal_stop;
 /*
  * Structure containing global list of plugins (oh_plugin).
  */
 struct oh_plugins oh_plugins = {
         .list = NULL,
-        .lock = G_STATIC_REC_MUTEX_INIT
+#if !GLIB_CHECK_VERSION (2, 32, 0)
+        .lock = G_STATIC_REC_MUTEX_INIT 
+#endif
 };
-
 /*
  * Structure containing global table of handlers (oh_handler).
  */
 struct oh_handlers oh_handlers = {
         .table = NULL,
         .list = NULL,
+#if !GLIB_CHECK_VERSION (2, 32, 0)
         .lock = G_STATIC_REC_MUTEX_INIT
+#endif
 };
 
 /**
@@ -66,33 +73,35 @@ void oh_close_handlers()
         struct oh_handler *h = NULL;
         GSList *node = NULL;
 
-        g_static_rec_mutex_lock(&oh_handlers.lock);
+        wrap_g_static_rec_mutex_lock(&oh_handlers.lock);
         if (oh_handlers.list == NULL) {
-                g_static_rec_mutex_unlock(&oh_handlers.lock);
+                wrap_g_static_rec_mutex_unlock(&oh_handlers.lock);
                 return;
         }
 
         for (node = oh_handlers.list; node; node = node->next) {
                 h = node->data;
                 if (h && h->abi && h->abi->close) {
-                        h->abi->close(h->hnd);
+                        if (h->hnd) {
+                            h->abi->close(h->hnd);
+                        }
                 }
         }
-        g_static_rec_mutex_unlock(&oh_handlers.lock);
+        wrap_g_static_rec_mutex_unlock(&oh_handlers.lock);
 }
 
 static void __inc_plugin_refcount(struct oh_plugin *p)
 {
-        g_static_rec_mutex_lock(&p->refcount_lock);
+        wrap_g_static_rec_mutex_lock(&p->refcount_lock);
         p->refcount++;
-        g_static_rec_mutex_unlock(&p->refcount_lock);
+        wrap_g_static_rec_mutex_unlock(&p->refcount_lock);
 }
 
 static void __dec_plugin_refcount(struct oh_plugin *p)
 {
-        g_static_rec_mutex_lock(&p->refcount_lock);
+        wrap_g_static_rec_mutex_lock(&p->refcount_lock);
         p->refcount--;
-        g_static_rec_mutex_unlock(&p->refcount_lock);
+        wrap_g_static_rec_mutex_unlock(&p->refcount_lock);
 }
 
 static void __delete_plugin(struct oh_plugin *p)
@@ -100,8 +109,8 @@ static void __delete_plugin(struct oh_plugin *p)
         if (!p) return;
 
         g_free(p->name);
-        g_static_rec_mutex_free(&p->lock);
-        g_static_rec_mutex_free(&p->refcount_lock);
+        wrap_g_static_rec_mutex_free_clear(&p->lock);
+        wrap_g_static_rec_mutex_free_clear(&p->refcount_lock);
         g_free(p->abi);
         if (p->dl_handle) {
                 g_module_close(p->dl_handle);
@@ -129,18 +138,18 @@ struct oh_plugin *oh_get_plugin(char *plugin_name)
                 return NULL;
         }
 
-        g_static_rec_mutex_lock(&oh_plugins.lock);
+        wrap_g_static_rec_mutex_lock(&oh_plugins.lock);
         for (node = oh_plugins.list; node; node = node->next) {
                 struct oh_plugin *p = (struct oh_plugin *)(node->data);
                 if (strcmp(p->name, plugin_name) == 0) {
                         __inc_plugin_refcount(p);
-                        g_static_rec_mutex_unlock(&oh_plugins.lock);
-                        g_static_rec_mutex_lock(&p->lock);
+                        wrap_g_static_rec_mutex_unlock(&oh_plugins.lock);
+                        wrap_g_static_rec_mutex_lock(&p->lock);
                         plugin = p;
                         return plugin;
                 }
         }
-        g_static_rec_mutex_unlock(&oh_plugins.lock);
+        wrap_g_static_rec_mutex_unlock(&oh_plugins.lock);
 
         return plugin;
 }
@@ -164,7 +173,7 @@ void oh_release_plugin(struct oh_plugin *plugin)
         if (plugin->refcount < 0)
                 __delete_plugin(plugin);
         else
-                g_static_rec_mutex_unlock(&plugin->lock);
+                wrap_g_static_rec_mutex_unlock(&plugin->lock);
 }
 
 /**
@@ -188,33 +197,33 @@ int oh_getnext_plugin_name(char *plugin_name,
         memset(next_plugin_name, '\0', size);
 
         if (!plugin_name) {
-                g_static_rec_mutex_lock(&oh_plugins.lock);
+                wrap_g_static_rec_mutex_lock(&oh_plugins.lock);
                 if (oh_plugins.list) {
                         struct oh_plugin *plugin = oh_plugins.list->data;
                         strncpy(next_plugin_name, plugin->name, size);
-                        g_static_rec_mutex_unlock(&oh_plugins.lock);
+                        wrap_g_static_rec_mutex_unlock(&oh_plugins.lock);
                         return 0;
                 } else {
-                        g_static_rec_mutex_unlock(&oh_plugins.lock);
+                        wrap_g_static_rec_mutex_unlock(&oh_plugins.lock);
                         DBG("No plugins have been loaded yet.");
                         return -1;
                 }
         } else {
-                g_static_rec_mutex_lock(&oh_plugins.lock);
+                wrap_g_static_rec_mutex_lock(&oh_plugins.lock);
                 for (node = oh_plugins.list; node; node = node->next) {
                         struct oh_plugin *p = node->data;
                         if (strcmp(p->name, plugin_name) == 0) {
                                 if (node->next) {
                                         p = node->next->data;
                                         strncpy(next_plugin_name, p->name, size);
-                                        g_static_rec_mutex_unlock(&oh_plugins.lock);
+                                        wrap_g_static_rec_mutex_unlock(&oh_plugins.lock);
                                         return 0;
                                 } else {
                                         break;
                                 }
                         }
                 }
-                g_static_rec_mutex_unlock(&oh_plugins.lock);
+                wrap_g_static_rec_mutex_unlock(&oh_plugins.lock);
         }
 
         return -1;
@@ -259,8 +268,8 @@ int oh_load_plugin(char *plugin_name)
         plugin->name = g_strdup(plugin_name);
         plugin->handler_count = 0;
         plugin->refcount = 0;
-        g_static_rec_mutex_init(&plugin->lock);
-        g_static_rec_mutex_init(&plugin->refcount_lock);
+        wrap_g_static_rec_mutex_init(&plugin->lock);
+        wrap_g_static_rec_mutex_init(&plugin->refcount_lock);
 
 #ifdef _WIN32
         plugin->dl_handle = g_module_open(plugin->name, G_MODULE_BIND_LOCAL);
@@ -295,9 +304,9 @@ int oh_load_plugin(char *plugin_name)
                 CRIT("Can not get ABI");
                 goto cleanup_and_quit;
         }
-        g_static_rec_mutex_lock(&oh_plugins.lock);
+        wrap_g_static_rec_mutex_lock(&oh_plugins.lock);
         oh_plugins.list = g_slist_append(oh_plugins.list, plugin);
-        g_static_rec_mutex_unlock(&oh_plugins.lock);
+        wrap_g_static_rec_mutex_unlock(&oh_plugins.lock);
 
         return 0;
 cleanup_and_quit:
@@ -332,9 +341,9 @@ int oh_unload_plugin(char *plugin_name)
                 return -3;
         }
 
-        g_static_rec_mutex_lock(&oh_plugins.lock);
+        wrap_g_static_rec_mutex_lock(&oh_plugins.lock);
         oh_plugins.list = g_slist_remove(oh_plugins.list, plugin);
-        g_static_rec_mutex_unlock(&oh_plugins.lock);
+        wrap_g_static_rec_mutex_unlock(&oh_plugins.lock);
 
         __dec_plugin_refcount(plugin);
         if (plugin->refcount < 1)
@@ -347,16 +356,16 @@ int oh_unload_plugin(char *plugin_name)
 
 static void __inc_handler_refcount(struct oh_handler *h)
 {
-        g_static_rec_mutex_lock(&h->refcount_lock);
+        wrap_g_static_rec_mutex_lock(&h->refcount_lock);
         h->refcount++;
-        g_static_rec_mutex_unlock(&h->refcount_lock);
+        wrap_g_static_rec_mutex_unlock(&h->refcount_lock);
 }
 
 static void __dec_handler_refcount(struct oh_handler *h)
 {
-        g_static_rec_mutex_lock(&h->refcount_lock);
+        wrap_g_static_rec_mutex_lock(&h->refcount_lock);
         h->refcount--;
-        g_static_rec_mutex_unlock(&h->refcount_lock);
+        wrap_g_static_rec_mutex_unlock(&h->refcount_lock);
 }
 
 static void __delete_handler(struct oh_handler *h)
@@ -377,8 +386,8 @@ static void __delete_handler(struct oh_handler *h)
         /* Free the oh_handler members first, then the handler. */
         g_hash_table_destroy(h->config);
 
-        g_static_rec_mutex_free(&h->lock);
-        g_static_rec_mutex_free(&h->refcount_lock);
+        wrap_g_static_rec_mutex_free_clear(&h->lock);
+        wrap_g_static_rec_mutex_free_clear(&h->refcount_lock);
         g_free(h);
 }
 
@@ -393,17 +402,17 @@ struct oh_handler *oh_get_handler(unsigned int hid)
         GSList *node = NULL;
         struct oh_handler *handler = NULL;
 
-        g_static_rec_mutex_lock(&oh_handlers.lock);
+        wrap_g_static_rec_mutex_lock(&oh_handlers.lock);
         node = g_hash_table_lookup(oh_handlers.table, &hid);
         handler = node ? node->data : NULL;
         if (!handler) {
-                g_static_rec_mutex_unlock(&oh_handlers.lock);
+                wrap_g_static_rec_mutex_unlock(&oh_handlers.lock);
                 CRIT("Error - Handler %d was not found", hid);
                 return NULL;
         }
         __inc_handler_refcount(handler);
-        g_static_rec_mutex_unlock(&oh_handlers.lock);
-        g_static_rec_mutex_lock(&handler->lock);
+        wrap_g_static_rec_mutex_unlock(&oh_handlers.lock);
+        wrap_g_static_rec_mutex_lock(&handler->lock);
 
         return handler;
 }
@@ -426,7 +435,7 @@ void oh_release_handler(struct oh_handler *handler)
         if (handler->refcount < 0)
                 __delete_handler(handler);
         else
-                g_static_rec_mutex_unlock(&handler->lock);
+                wrap_g_static_rec_mutex_unlock(&handler->lock);
 }
 
 /**
@@ -450,27 +459,27 @@ int oh_getnext_handler_id(unsigned int hid, unsigned int *next_hid)
         *next_hid = 0;
 
         if (!hid) { /* Return first handler id in the list */
-                g_static_rec_mutex_lock(&oh_handlers.lock);
+                wrap_g_static_rec_mutex_lock(&oh_handlers.lock);
                 if (oh_handlers.list) {
                         h = oh_handlers.list->data;
                         *next_hid = h->id;
-                        g_static_rec_mutex_unlock(&oh_handlers.lock);
+                        wrap_g_static_rec_mutex_unlock(&oh_handlers.lock);
                         return 0;
                 } else {
-                        g_static_rec_mutex_unlock(&oh_handlers.lock);
+                        wrap_g_static_rec_mutex_unlock(&oh_handlers.lock);
                         CRIT("Warning - no handlers");
                         return -1;
                 }
         } else { /* Return handler id coming after hid in the list */
-                g_static_rec_mutex_lock(&oh_handlers.lock);
+                wrap_g_static_rec_mutex_lock(&oh_handlers.lock);
                 node = g_hash_table_lookup(oh_handlers.table, &hid);
                 if (node && node->next && node->next->data) {
                         h = node->next->data;
                         *next_hid = h->id;
-                        g_static_rec_mutex_unlock(&oh_handlers.lock);
+                        wrap_g_static_rec_mutex_unlock(&oh_handlers.lock);
                         return 0;
                 }
-                g_static_rec_mutex_unlock(&oh_handlers.lock);
+                wrap_g_static_rec_mutex_unlock(&oh_handlers.lock);
         }
 
         return -1;
@@ -522,9 +531,9 @@ static struct oh_handler *new_handler(GHashTable *handler_config)
         handler->abi = plugin->abi;
         plugin->handler_count++; /* Increment # of handlers using the plugin */
         oh_release_plugin(plugin);
-        g_static_rec_mutex_lock(&oh_handlers.lock);
+        wrap_g_static_rec_mutex_lock(&oh_handlers.lock);
         handler->id = handler_id++;
-        g_static_rec_mutex_unlock(&oh_handlers.lock);
+        wrap_g_static_rec_mutex_unlock(&oh_handlers.lock);
         handler->plugin_name = g_strdup(g_hash_table_lookup(handler_config, "plugin"));
         //copy config in a new hash table
         newconfig = g_hash_table_new_full (
@@ -532,8 +541,8 @@ static struct oh_handler *new_handler(GHashTable *handler_config)
         g_hash_table_foreach(handler_config,copy_hashed_new_config,newconfig);
         handler->config = newconfig;
         handler->refcount = 0;
-        g_static_rec_mutex_init(&handler->lock);
-        g_static_rec_mutex_init(&handler->refcount_lock);
+        wrap_g_static_rec_mutex_init(&handler->lock);
+        wrap_g_static_rec_mutex_init(&handler->refcount_lock);
 
         return handler;
 cleanexit:
@@ -566,7 +575,7 @@ SaErrorT oh_create_handler (GHashTable *handler_config, unsigned int *hid)
         if (!handler) return SA_ERR_HPI_ERROR;
 
         *hid = handler->id;
-        g_static_rec_mutex_lock(&oh_handlers.lock);
+        wrap_g_static_rec_mutex_lock(&oh_handlers.lock);
         oh_handlers.list = g_slist_append(oh_handlers.list, handler);
         g_hash_table_insert(oh_handlers.table,
                             &(handler->id),
@@ -578,7 +587,7 @@ SaErrorT oh_create_handler (GHashTable *handler_config, unsigned int *hid)
         if (!handler->hnd) {
                 CRIT("A handler #%d on the %s plugin could not be opened.",
                     handler->id, handler->plugin_name);
-		g_static_rec_mutex_unlock(&oh_handlers.lock);
+		wrap_g_static_rec_mutex_unlock(&oh_handlers.lock);
 		return SA_ERR_HPI_INTERNAL_ERROR;
         }
 
@@ -586,15 +595,21 @@ SaErrorT oh_create_handler (GHashTable *handler_config, unsigned int *hid)
         // set auto-extract timeout
         if (handler->abi->set_autoinsert_timeout) {
                 struct oh_global_param param;
+                SaErrorT rv;
                 oh_get_global_param2(OPENHPI_AUTOINSERT_TIMEOUT, &param);
                 SaHpiTimeoutT ai_timeout = param.u.ai_timeout;
-                SaErrorT rv = handler->abi->set_autoinsert_timeout(handler->hnd, ai_timeout);
-                if (rv != SA_OK) {
-                        CRIT("Cannot propagate auto-insert timeout to handler.");
-                }
+                oh_get_global_param2(OPENHPI_AUTOINSERT_TIMEOUT_READONLY, &param);
+                DBG("auto-insert timeout readonly=%d, auto-insert timeout to set=%" PRId64,
+                       param.u.ai_timeout_readonly, (int64_t)ai_timeout);
+                if (!param.u.ai_timeout_readonly && ai_timeout) {
+                        rv = handler->abi->set_autoinsert_timeout(handler->hnd, ai_timeout);
+                        if (rv != SA_OK) {
+                                CRIT("Cannot propagate auto-insert timeout to handler.");
+                        }
+                 }
         }
 
-        g_static_rec_mutex_unlock(&oh_handlers.lock);
+        wrap_g_static_rec_mutex_unlock(&oh_handlers.lock);
 
         return SA_OK;
 }
@@ -620,13 +635,16 @@ int oh_destroy_handler(unsigned int hid)
                 return -1;
         }
 
-        if (handler->abi && handler->abi->close)
-                handler->abi->close(handler->hnd);
+        if (handler->abi && handler->abi->close) {
+                if (handler->hnd) {
+                        handler->abi->close(handler->hnd);
+                }
+        }
 
-        g_static_rec_mutex_lock(&oh_handlers.lock);
+        wrap_g_static_rec_mutex_lock(&oh_handlers.lock);
         g_hash_table_remove(oh_handlers.table, &handler->id);
         oh_handlers.list = g_slist_remove(oh_handlers.list, &(handler->id));
-        g_static_rec_mutex_unlock(&oh_handlers.lock);
+        wrap_g_static_rec_mutex_unlock(&oh_handlers.lock);
 
         __dec_handler_refcount(handler);
         if (handler->refcount < 1)
@@ -637,6 +655,59 @@ int oh_destroy_handler(unsigned int hid)
         return 0;
 }
 
+/**
+ * oh_get_handler_info
+ *
+ * Returns: SA_OK on success.
+ **/
+
+// helper function to copy hash table
+static void copy_hashed_config_info (gpointer key, gpointer value, gpointer newhash)
+{
+        g_hash_table_insert ( newhash, g_strdup(key), g_strdup(value) );
+}
+
+SaErrorT oh_get_handler_info(unsigned int hid, oHpiHandlerInfoT *info, GHashTable *conf_params)
+{
+        struct oh_handler *h = NULL;
+        GSList *node = NULL;
+
+        if ((hid == 0) || (!info) || (!conf_params)) {
+               return SA_ERR_HPI_INVALID_PARAMS;
+        }
+
+        wrap_g_static_rec_mutex_lock(&oh_handlers.lock);
+        node = g_hash_table_lookup(oh_handlers.table, &hid);
+        h = node ? (struct oh_handler *)(node->data) : NULL;
+        if (!h) {
+               wrap_g_static_rec_mutex_unlock(&oh_handlers.lock);
+                return SA_ERR_HPI_NOT_PRESENT;
+        }
+
+        info->id = hid;
+        strncpy((char*)info->plugin_name, (const char*)h->plugin_name, MAX_PLUGIN_NAME_LENGTH);
+        oh_init_ep(&info->entity_root);
+        const char * entity_root_str = (const char *)g_hash_table_lookup(h->config, "entity_root");
+        if ( entity_root_str ) {
+                oh_encode_entitypath(entity_root_str, &info->entity_root);
+        }
+
+        info->load_failed = (!h->hnd) ? 1 : 0;
+
+        // copy h->config to the output hash table
+        g_hash_table_foreach(h->config,copy_hashed_config_info,conf_params);
+
+        //Don't transmit passwords in case the handler has a password in its config
+        if (g_hash_table_lookup(conf_params,"password"))
+           g_hash_table_replace(conf_params,
+                                g_strdup("password"),
+                                g_strdup("********"));
+
+        wrap_g_static_rec_mutex_unlock(&oh_handlers.lock);
+
+        return SA_OK;
+}
+
 /**
  * oh_discover_resources
  *
@@ -652,6 +723,11 @@ SaErrorT oh_discovery(void)
         while (next_hid) {
                 hid = next_hid;
 
+                if(signal_stop == TRUE){
+                   error = SA_OK;
+                   break;
+                }
+
                 SaErrorT cur_error;
 
                 h = oh_get_handler(hid);
