@@ -69,7 +69,7 @@ NewSimulatorRdr * NewSimulatorFileAnnunciator::process_token( NewSimulatorResour
    
    if (cur_token != G_TOKEN_LEFT_CURLY) {
    	  err("Processing parse configuration: Expected left curly token.");
-      return false;
+      return NULL;
    }
    m_depth++;
    
