@@ -71,7 +71,7 @@ NewSimulatorRdr * NewSimulatorFileDimi::process_token( NewSimulatorResource *res
    
    if (cur_token != G_TOKEN_LEFT_CURLY) {
    	  err("Processing parse configuration: Expected left curly token.");
-      return false;
+      return NULL;
    }
    m_depth++;
    
