@@ -46,6 +46,7 @@
 #include <ilo2_ribcl_discover.h>
 #include <ilo2_ribcl_sensor.h>
 static SaHpiEntityPathT g_epbase; /* root entity path (from config) */
+SaHpiBoolT close_handler = SAHPI_FALSE;
 
 /*****************************
 	iLO2 RIBCL plug-in ABI Interface functions
@@ -193,6 +194,18 @@ void *ilo2_ribcl_open(GHashTable *handler_config,
 		return(NULL);
 	}
 	memset(ilo2_ribcl_handler, '\0', sizeof(*ilo2_ribcl_handler));
+
+	ilo2_ribcl_handler->ilo_thread_data =
+				g_malloc0(sizeof(iLO_info_t));
+	ilo2_ribcl_handler->ilo_thread_data->iLO_cond =
+				wrap_g_cond_new_init();
+	ilo2_ribcl_handler->ilo_thread_data->iLO_mutex =
+				wrap_g_mutex_new_init();
+
+	ilo2_ribcl_handler->ilo_thread_data->oh_handler = oh_handler;
+	ilo2_ribcl_handler->need_rediscovery = FALSE;
+	ilo2_ribcl_handler->discovery_complete = FALSE;
+
 	oh_handler->data = ilo2_ribcl_handler;
 
 	/* Save configuration in the handler */
@@ -201,7 +214,7 @@ void *ilo2_ribcl_open(GHashTable *handler_config,
 	/* build complete hostname with port string appended */
 	/* add one extra byte to account for : in the middle of hostname:port
 	   string example: 10.100.1.1:443 */
-	ilo2_ribcl_handler->ilo2_hostport = g_malloc(host_len+port_len+2);
+	ilo2_ribcl_handler->ilo2_hostport = g_malloc0(host_len+port_len+2);
 	if(ilo2_ribcl_handler->ilo2_hostport == NULL) {
 		err("ilo2 ribcl Open:unable to allocate memory");
 		free(ilo2_ribcl_handler);
@@ -218,18 +231,19 @@ void *ilo2_ribcl_open(GHashTable *handler_config,
 
 	/*initialize the ilo_type to NO_ILO*/
 	ilo2_ribcl_handler->ilo_type = NO_ILO;
+	ilo2_ribcl_handler->iml_log_time = 0;
 
 	/*hostname is needed for the HTTP 1.1 header
 	 *that will be sent to iLO3 prior to RIBCL command
 	 *submission. The max length of the hostname is 
-	 *limited by HOST_NAME_MAX, the gethostname always have a '\0'
-	 *at the end of the name, if hostname exceeds the HOST_NAME_MAX,
-	 *the string is truncated. So it is always made
-	 *sure that the last character is '\0'. Achieved by the following
-	 *statement of the gethostname.
+	 *limited by ILO2_HOST_NAME_MAX_LEN, the gethostname always have a '\0'
+	 *at the end of the name, if hostname exceeds the ILO2_HOST_NAME_MAX_LEN,,
+	 *the string is truncated. In that case truncate last charactor with '\0'; 
+         *Achieved by the following statement of the gethostname.
 	 */
-	gethostname(ilo2_ribcl_handler->ir_hostname, HOST_NAME_MAX-1);
-	ilo2_ribcl_handler->ir_hostname[HOST_NAME_MAX] = '\0';
+	gethostname(ilo2_ribcl_handler->ir_hostname, ILO2_HOST_NAME_MAX_LEN);
+	if (strlen(ilo2_ribcl_handler->ir_hostname) >= ILO2_HOST_NAME_MAX_LEN)
+		ilo2_ribcl_handler->ir_hostname[ILO2_HOST_NAME_MAX_LEN-1] = '\0';
 	
 
 	/*Initialize the test and the iLO3 header pointer to NULL*/
@@ -284,6 +298,7 @@ void *ilo2_ribcl_open(GHashTable *handler_config,
 	}
 	/* Initialize sensor data */
 	ilo2_ribcl_init_sensor_data( ilo2_ribcl_handler);
+        close_handler = SAHPI_FALSE;
 
 	return((void *)oh_handler);
 }
@@ -312,12 +327,29 @@ void ilo2_ribcl_close(void *handler)
                 return;
         }
 
+        close_handler = SAHPI_TRUE;
+        dbg("ilo2 ribcl close_handler is set");
+
+        /* Sleep so that discovery thread get this variable */
+        sleep(1);
+
         ilo2_ribcl_handler = (ilo2_ribcl_handler_t *) oh_handler->data;
 	if(ilo2_ribcl_handler == NULL) {
         	free(oh_handler);
                 return;
 	}
 
+	g_mutex_lock(ilo2_ribcl_handler->ilo_thread_data->iLO_mutex);
+	g_cond_broadcast(ilo2_ribcl_handler->ilo_thread_data->iLO_cond);
+	g_mutex_unlock(ilo2_ribcl_handler->ilo_thread_data->iLO_mutex);
+
+	if (ilo2_ribcl_handler->ilo_thread_data->hthread)
+		g_thread_join(ilo2_ribcl_handler->ilo_thread_data->hthread);
+
+	wrap_g_cond_free(ilo2_ribcl_handler->ilo_thread_data->iLO_cond);
+	wrap_g_mutex_free_clear(ilo2_ribcl_handler->ilo_thread_data->iLO_mutex);
+	g_free(ilo2_ribcl_handler->ilo_thread_data);
+
 	/* Free SSL infrastructure */
 	oh_ssl_ctx_free(ilo2_ribcl_handler->ssl_ctx);
 
@@ -366,6 +398,12 @@ SaErrorT ilo2_ribcl_get_event(void *handler)
 		(struct oh_handler_state *) handler;
         ilo2_ribcl_handler_t *ilo2_ribcl_handler;
 	
+        if( close_handler == SAHPI_TRUE ) {
+             INFO("ilo2_ribcl_handler is closed. Thread %p returning.",
+                     g_thread_self());
+             return(SA_OK);
+        }
+
         if (!handler) {
                 err("ilo2 ribcl get event: Invalid parameter");
                 return(SA_ERR_HPI_INVALID_PARAMS);
