@@ -41,7 +41,7 @@ static void init_power_on_sequence_data_cb(ipmi_entity_t *entity,
 	ohoi_atca_pwonseq_dsk_t *dscp = NULL;
 	int i;
 	int rv;
-	
+
 	g_slist_foreach(ipmi_handler->atca_pwonseq_recs, (GFunc)g_free, NULL);
 	g_slist_free(ipmi_handler->atca_pwonseq_recs);
 	g_slist_foreach(ipmi_handler->atca_pwonseq_desk, (GFunc)g_free, NULL);
@@ -49,13 +49,13 @@ static void init_power_on_sequence_data_cb(ipmi_entity_t *entity,
 	ipmi_handler->atca_pwonseq_recs = NULL;
 	ipmi_handler->atca_pwonseq_desk = NULL;
 	ipmi_handler->atca_pwonseq_updated = 0;
-	
+
 	r_num = ipmi_entity_get_num_multi_records(entity);
 	for (num = 0; num < r_num; num++) {
 		len = 256;
 		rv = ipmi_fru_get_multi_record_data(fru, num, data, &len);
 		if (rv != 0) {
-			dbg("ipmi_fru_get_multi_record_data("
+			err("ipmi_fru_get_multi_record_data("
 				"fru, %d, data, 0x%x) = 0x%x",
 				num, len, rv);
 			broken = 1;
@@ -63,18 +63,18 @@ static void init_power_on_sequence_data_cb(ipmi_entity_t *entity,
 		}
 		rv = ipmi_fru_get_multi_record_type(fru, num, &type);
 		if (rv) {
-			dbg("ipmi_entity_get_multi_record_type = %d", rv);
+			err("ipmi_entity_get_multi_record_type = %d", rv);
 			broken = 1;
 			break;
 		}
 		if (type != 0xc0) {
 			// record type. Must be OEM
-			dbg("Record type = 0x%x", data[0]);
+			err("Record type = 0x%x", data[0]);
 			continue;
 		}
 		rv = ipmi_fru_get_multi_record_format_version(fru, num, &ver);
 		if (rv) {
-			dbg("ipmi_entity_get_multi_record_format_version = %d", rv);
+			err("ipmi_entity_get_multi_record_format_version = %d", rv);
 			broken = 1;
 			break;
 		}
@@ -88,21 +88,21 @@ static void init_power_on_sequence_data_cb(ipmi_entity_t *entity,
 		}
 		if ((data[0] | (data[1] << 8) | (data[2] << 16)) !=
 						ATCAHPI_PICMG_MID) {
-			dbg("MId = 0x%x", data[0] | (data[1] << 8) | (data[2] << 16));
+			err("MId = 0x%x", data[0] | (data[1] << 8) | (data[2] << 16));
 			continue;
 		}
-		
+
 		if (data[3] != 0x12) {
 			continue;
 		}
-		
+
 		if (len < 7) {
-			dbg("Record #%d too short(%d)", num, len);
+			err("Record #%d too short(%d)", num, len);
 			broken = 1;
 			break;
 		}
 		if (len < 7 + data[6] * 5) {
-			dbg("Record #%d length(0x%x) mismatches with expected(0x%x)",
+			err("Record #%d length(0x%x) mismatches with expected(0x%x)",
 				num, len, 7 + data[6] * 5);
 			broken = 1;
 			break;
@@ -116,7 +116,7 @@ static void init_power_on_sequence_data_cb(ipmi_entity_t *entity,
 				g_slist_append(ipmi_handler->atca_pwonseq_recs,
 				               recp);
 		} else {
-			dbg("Out of memory");
+			err("Out of memory");
 			broken = 1;
 			break;
 		}
@@ -130,13 +130,13 @@ static void init_power_on_sequence_data_cb(ipmi_entity_t *entity,
 						ipmi_handler->atca_pwonseq_desk,
 						dscp);
 			} else {
-				dbg("Out of memory");
+				err("Out of memory");
 				broken = 1;
 				break;
 			}
 		}
 	}
-	
+
 	if (broken) {
 		// XXX delete all alloced memory
 	}
@@ -148,7 +148,7 @@ static void init_power_on_sequence_data_cb(ipmi_entity_t *entity,
          *      Chassis status control
 	 */
 
-	 
+
 struct atca_chassis_status_control_s {
 	SaHpiCtrlStateOemT *state;
 	int done;
@@ -176,12 +176,12 @@ static int get_atca_chassis_status_control_states_cb(
 	struct atca_chassis_status_control_s *info = rspi->data1;
 	ipmi_msg_t *msg = &rspi->msg;
 	int rv = msg->data[0];
-	
-	
+
+
 	dbg("get chassis response(%d): %02x %02x %02x %02x %02x\n",
 		msg->data_len, msg->data[0], msg->data[1], msg->data[2],
 		msg->data[3], msg->data[4]);
-		
+
 	if (domain == NULL) {
 		info->rv = SA_ERR_HPI_INVALID_PARAMS;
 		info->done = 1;
@@ -224,7 +224,7 @@ static void get_atca_chassis_status_control_states(
 		get_atca_chassis_status_control_states_cb,
 		cb_data);
 	if (rv != 0) {
-		dbg("ipmicmd_send = 0x%x", rv);
+		err("ipmicmd_send = 0x%x", rv);
 		OHOI_MAP_ERROR(info->rv, rv);
 		return;
 	}
@@ -246,7 +246,7 @@ static SaHpiRdrT *create_atca_chassis_status_control(
 	SaHpiCtrlStateOemT states;
 	SaErrorT rv;
 	struct atca_chassis_status_control_s info;
-	
+
 	info.state = &states;
 	info.done = 0;
 	info.rv = SA_OK;
@@ -254,27 +254,27 @@ static SaHpiRdrT *create_atca_chassis_status_control(
 				get_atca_chassis_status_control_states,
 				&info);
 	if (rv != 0) {
-		dbg("ipmi_domain_pointer_cb = 0x%x", rv);
+		err("ipmi_domain_pointer_cb = 0x%x", rv);
 		return NULL;
 	}
 	rv = ohoi_loop(&info.done, ipmi_handler);
 	if (rv != SA_OK) {
-		dbg("ohoi_loop = 0x%x", rv);
+		err("ohoi_loop = 0x%x", rv);
 		return NULL;
 	}
 	if (info.rv != SA_OK) {
-		dbg("info.rv = 0x%x", info.rv);
+		err("info.rv = 0x%x", info.rv);
 		return NULL;
 	}
 
 	rdr = malloc(sizeof (*rdr));
 	if (rdr == NULL) {
-		dbg("Out of memory");
+		err("Out of memory");
 		return NULL;
 	}
 	c_info = malloc(sizeof (*c_info));
 	if (rdr == NULL) {
-		dbg("Out of memory");
+		err("Out of memory");
 		free(rdr);
 		return NULL;
 	}
@@ -302,18 +302,18 @@ static SaHpiRdrT *create_atca_chassis_status_control(
 	rdr->RdrTypeUnion.CtrlRec.TypeUnion.Oem.Default.Body[1] =
 			states.Body[1];
 	rdr->RdrTypeUnion.CtrlRec.TypeUnion.Oem.Default.Body[2] =
-			states.Body[2];		
+			states.Body[2];
 	rdr->RdrTypeUnion.CtrlRec.TypeUnion.Oem.Default.Body[3] =
 			states.Body[3];
 	rdr->RdrTypeUnion.CtrlRec.TypeUnion.Oem.Default.MId =
 						ATCAHPI_PICMG_MID;
 	rdr->RdrTypeUnion.CtrlRec.TypeUnion.Oem.MId = ATCAHPI_PICMG_MID;
-	
+
 	c_info->ohoii.get_control_state = get_atca_chassis_status_control_state;
 	c_info->ohoii.set_control_state = set_atca_chassis_status_control_state;
 	c_info->mode = SAHPI_CTRL_MODE_AUTO;
 	*ctrl_info = c_info;
-		
+
 	return rdr;
 }
 
@@ -328,7 +328,7 @@ SaErrorT get_atca_chassis_status_control_state(
 	struct atca_chassis_status_control_s info;
 	struct ohoi_handler *ipmi_handler = (struct ohoi_handler *)hnd->data;
 	SaErrorT rv;
-	
+
 	if (state == NULL) {
 		goto no_state;
 	}
@@ -339,16 +339,16 @@ SaErrorT get_atca_chassis_status_control_state(
 				get_atca_chassis_status_control_states,
 				&info);
 	if (rv != 0) {
-		dbg("ipmi_domain_pointer_cb = 0x%x", rv);
+		err("ipmi_domain_pointer_cb = 0x%x", rv);
 		return SA_ERR_HPI_INVALID_CMD;
 	}
 	rv = ohoi_loop(&info.done, ipmi_handler);
 	if (rv != SA_OK) {
-		dbg("ohoi_loop = 0x%x", rv);
+		err("ohoi_loop = 0x%x", rv);
 		return rv;
 	}
 	if (info.rv != SA_OK) {
-		dbg("info.rv = 0x%x", info.rv);
+		err("info.rv = 0x%x", info.rv);
 		return rv;
 	}
 	state->Type = SAHPI_CTRL_TYPE_OEM;
@@ -409,16 +409,16 @@ static int set_shelf_address_control_msg_data(SaHpiTextTypeT type,
 		case SAHPI_TL_TYPE_BINARY:
 			data[1] |= (text->DataLength & 0x1f);
 			break;
-		} 
+		}
 		return 0;
 	}
 	if ((type != SAHPI_TL_TYPE_ASCII6) || (text->DataType != SAHPI_TL_TYPE_TEXT)) {
-		dbg("Datatype dismaych : %d & %d", type, text->DataType);
+		err("Datatype dismaych : %d & %d", type, text->DataType);
 		return 1;
 	}
 	for (i = 0; i < text->DataLength; i++) {
 		if ((text->Data[i] < 0x20) || (text->Data[i] > 0x5F)) {
-			dbg("cannot convert TEXT to ASCII6");
+			err("cannot convert TEXT to ASCII6");
 			return 1;
 		}
 	}
@@ -463,11 +463,11 @@ static int set_atca_shelf_address_control_states_cb(
 	struct atca_shelf_address_control_s *info = rspi->data1;
 	ipmi_msg_t *msg = &rspi->msg;
 	int rv = msg->data[0];
-	
-	
+
+
 	dbg("set shelf address response(%d): %02x %02x\n",
 		msg->data_len, msg->data[0], msg->data[1]);
-		
+
 	if (domain == NULL) {
 		info->rv = SA_ERR_HPI_INVALID_PARAMS;
 		info->done = 1;
@@ -502,13 +502,13 @@ static void set_atca_shelf_address_control_states(
 		return;
 	}
 	dbg("set addr control: 0x%02x 0x%02x 0x%02x 0x%02x 0x%02x 0x%02x",
-		data[0], data[1], data[2], data[3], data[4], data[5]); 
+		data[0], data[1], data[2], data[3], data[4], data[5]);
 	rv = ipmicmd_send(domain,
 		0x2c, 0x03, 0, IPMI_BMC_CHANNEL, data, 32,
 		set_atca_shelf_address_control_states_cb,
 		cb_data);
 	if (rv != 0) {
-		dbg("ipmicmd_send = 0x%x", rv);
+		err("ipmicmd_send = 0x%x", rv);
 		OHOI_MAP_ERROR(info->rv, rv);
 		info->done = 1;
 		return;
@@ -534,13 +534,13 @@ static SaErrorT set_atca_shelf_address_control_state(
 		return SA_ERR_HPI_READ_ONLY;
 	}
 	if (state->Type != SAHPI_CTRL_TYPE_TEXT) {
-		dbg("state->Type != SAHPI_CTRL_TYPE_TEXT");
+		err("state->Type != SAHPI_CTRL_TYPE_TEXT");
 		return SA_ERR_HPI_INVALID_DATA;
 	}
 	text = &state->StateUnion.Text;
 	if ((text->Line != 1) &&
 			(text->Line != SAHPI_TLN_ALL_LINES)) {
-		dbg("text->Line != 1 or SAHPI_TLN_ALL_LINES");
+		err("text->Line != 1 or SAHPI_TLN_ALL_LINES");
 		return SA_ERR_HPI_INVALID_DATA;
 	}
 
@@ -552,16 +552,16 @@ static SaErrorT set_atca_shelf_address_control_state(
 				set_atca_shelf_address_control_states,
 				&info);
 	if (rv != 0) {
-		dbg("ipmi_domain_pointer_cb = 0x%x", rv);
+		err("ipmi_domain_pointer_cb = 0x%x", rv);
 		return SA_ERR_HPI_INVALID_CMD;
 	}
 	rv = ohoi_loop(&info.done, ipmi_handler);
 	if (rv != SA_OK) {
-		dbg("ohoi_loop = 0x%x", rv);
+		err("ohoi_loop = 0x%x", rv);
 		return rv;
 	}
 	if (info.rv != SA_OK) {
-		dbg("info.rv = 0x%x", info.rv);
+		err("info.rv = 0x%x", info.rv);
 		return info.rv;
 	}
 //	c->mode = mode;
@@ -579,12 +579,12 @@ static int get_atca_shelf_address_control_states_cb(
 	int rv = msg->data[0];
 	int len;
 	int i;
-	
-	
+
+
 	dbg("get shelf address response(%d): %02x %02x %02x %02x %02x\n",
 		msg->data_len, msg->data[0], msg->data[1], msg->data[2],
 		msg->data[3], msg->data[4]);
-		
+
 	if (domain == NULL) {
 		info->rv = SA_ERR_HPI_INVALID_PARAMS;
 		info->done = 1;
@@ -601,7 +601,7 @@ static int get_atca_shelf_address_control_states_cb(
 		info->done = 1;
 		return IPMI_MSG_ITEM_NOT_USED;
 	}
-	
+
 	info->text->Line = 1;
 	info->text->Text.DataType = (msg->data[2] & 0xc0) >> 6;
 	len = (msg->data[2] & 0x0f);
@@ -643,7 +643,7 @@ static int get_atca_shelf_address_control_states_cb(
 		break;
 	}
 	info->text->Text.DataLength = len;
-		
+
 	info->done = 1;
 	return IPMI_MSG_ITEM_NOT_USED;
 };
@@ -662,13 +662,13 @@ static void get_atca_shelf_address_control_states(
 		get_atca_shelf_address_control_states_cb,
 		cb_data);
 	if (rv != 0) {
-		dbg("ipmicmd_send = 0x%x", rv);
+		err("ipmicmd_send = 0x%x", rv);
 		OHOI_MAP_ERROR(info->rv, rv);
 		return;
 	}
 	return;
 }
- 
+
 static SaErrorT get_atca_shelf_address_control_state(
                                       struct oh_handler_state *hnd,
                                       struct ohoi_control_info *c,
@@ -679,19 +679,19 @@ static SaErrorT get_atca_shelf_address_control_state(
 	struct atca_shelf_address_control_s info;
 	struct ohoi_handler *ipmi_handler = (struct ohoi_handler *)hnd->data;
 	SaErrorT rv;
-	
+
 	if (state == NULL) {
 		goto no_state;
 	}
 #if 0
 	if (state->Type != SAHPI_CTRL_TYPE_TEXT) {
-		dbg("state->Type != SAHPI_CTRL_TYPE_TEXT");
+		err("state->Type != SAHPI_CTRL_TYPE_TEXT");
 		return SA_ERR_HPI_INVALID_DATA;
 	}
 #endif
 	if ((state->StateUnion.Text.Line != 1) &&
 			(state->StateUnion.Text.Line != SAHPI_TLN_ALL_LINES)) {
-		dbg("text->Line != 1 or SAHPI_TLN_ALL_LINES");
+		err("text->Line != 1 or SAHPI_TLN_ALL_LINES");
 		return SA_ERR_HPI_INVALID_DATA;
 	}
 
@@ -702,16 +702,16 @@ static SaErrorT get_atca_shelf_address_control_state(
 				get_atca_shelf_address_control_states,
 				&info);
 	if (rv != 0) {
-		dbg("ipmi_domain_pointer_cb = 0x%x", rv);
+		err("ipmi_domain_pointer_cb = 0x%x", rv);
 		return SA_ERR_HPI_INVALID_CMD;
 	}
 	rv = ohoi_loop(&info.done, ipmi_handler);
 	if (rv != SA_OK) {
-		dbg("ohoi_loop = 0x%x", rv);
+		err("ohoi_loop = 0x%x", rv);
 		return rv;
 	}
 	if (info.rv != SA_OK) {
-		dbg("info.rv = 0x%x", info.rv);
+		err("info.rv = 0x%x", info.rv);
 		return rv;
 	}
 	state->Type = SAHPI_CTRL_TYPE_TEXT;
@@ -720,7 +720,7 @@ no_state:
 		*mode = c->mode;
 	}
 	return SA_OK;
-} 
+}
 
 
 
@@ -737,8 +737,8 @@ static SaHpiRdrT *create_atca_shelf_address_control(
 	SaHpiCtrlStateTextT text;
 	SaErrorT rv;
 	struct atca_shelf_address_control_s info;
-	
-	
+
+
 	info.text = &text;
 	info.done = 0;
 	info.rv = SA_OK;
@@ -746,34 +746,34 @@ static SaHpiRdrT *create_atca_shelf_address_control(
 				get_atca_shelf_address_control_states,
 				&info);
 	if (rv != 0) {
-		dbg("ipmi_domain_pointer_cb = 0x%x", rv);
+		err("ipmi_domain_pointer_cb = 0x%x", rv);
 		return NULL;
 	}
 	rv = ohoi_loop(&info.done, ipmi_handler);
 	if (rv != SA_OK) {
-		dbg("ohoi_loop = 0x%x", rv);
+		err("ohoi_loop = 0x%x", rv);
 		return NULL;
 	}
 	if (info.rv != SA_OK) {
-		dbg("info.rv = 0x%x", info.rv);
+		err("info.rv = 0x%x", info.rv);
 		return NULL;
 	}
 
 	rdr = malloc(sizeof (*rdr));
 	if (rdr == NULL) {
-		dbg("Out of memory");
+		err("Out of memory");
 		return NULL;
 	}
 	c_info = malloc(sizeof (*c_info));
 	if (rdr == NULL) {
-		dbg("Out of memory");
+		err("Out of memory");
 		free(rdr);
 		return NULL;
 	}
 
 	memset(rdr, 0, sizeof (*rdr));
 	memset(c_info, 0, sizeof (*c_info));
-	
+
 	rdr->RdrType = SAHPI_CTRL_RDR;
 	rdr->IsFru = SAHPI_FALSE;
 	rdr->Entity = rpt->ResourceEntity;
@@ -803,7 +803,7 @@ static SaHpiRdrT *create_atca_shelf_address_control(
 	c_info->ohoii.set_control_state = set_atca_shelf_address_control_state;
 	c_info->mode = SAHPI_CTRL_MODE_MANUAL;
 	*ctrl_info = c_info;
-		
+
 	return rdr;
 }
 
@@ -827,7 +827,7 @@ static SaErrorT set_atca_shelf_ip_address_control_state(
                                       SaHpiCtrlModeT mode,
                                       SaHpiCtrlStateT *state);
 
-   
+
 
 static SaHpiRdrT *create_atca_shelf_ip_address_control(
 			struct oh_handler_state *handler,
@@ -842,12 +842,12 @@ static SaHpiRdrT *create_atca_shelf_ip_address_control(
 
 	rdr = malloc(sizeof (*rdr));
 	if (rdr == NULL) {
-		dbg("Out of memory");
+		err("Out of memory");
 		return NULL;
 	}
 	c_info = malloc(sizeof (*c_info));
 	if (rdr == NULL) {
-		dbg("Out of memory");
+		err("Out of memory");
 		free(rdr);
 		return NULL;
 	}
@@ -887,7 +887,7 @@ static SaHpiRdrT *create_atca_shelf_ip_address_control(
 	c_info->ohoii.get_control_state = get_atca_shelf_ip_address_control_state;
 	c_info->ohoii.set_control_state = set_atca_shelf_ip_address_control_state;
 	*ctrl_info = c_info;
-	
+
 	return rdr;
 }
 
@@ -907,7 +907,7 @@ static SaErrorT get_shelf_ip_address_record(ipmi_entity_t *ent,
 		*len = orig_len;
 		rv = ipmi_entity_get_multi_record_data(ent, i, buf, len);
 		if (rv != 0) {
-			dbg("ipmi_entity_get_multi_record_data(%d) = 0x%x",
+			err("ipmi_entity_get_multi_record_data(%d) = 0x%x",
 						i, rv);
 			return SA_ERR_HPI_INVALID_DATA;
 		}
@@ -916,7 +916,7 @@ static SaErrorT get_shelf_ip_address_record(ipmi_entity_t *ent,
 		}
 		rv = ipmi_entity_get_multi_record_type(ent, i, &type);
 		if (rv) {
-			dbg("ipmi_entity_get_multi_record_type = %d", rv);
+			err("ipmi_entity_get_multi_record_type = %d", rv);
 			continue;
 		}
 		if (type != 0xc0) {
@@ -925,7 +925,7 @@ static SaErrorT get_shelf_ip_address_record(ipmi_entity_t *ent,
 		}
 		rv = ipmi_entity_get_multi_record_format_version(ent, i, &vr);
 		if (rv) {
-			dbg("ipmi_entity_get_multi_record_format_version = %d", rv);
+			err("ipmi_entity_get_multi_record_format_version = %d", rv);
 			continue;
 		}
 
@@ -947,7 +947,7 @@ static SaErrorT get_shelf_ip_address_record(ipmi_entity_t *ent,
 		break;
 	}
 	if (i == num_rec) {
-		dbg("No record for shelf IP address");
+		err("No record for shelf IP address");
 		return SA_ERR_HPI_INTERNAL_ERROR;
 	}
 	*num = i;
@@ -971,15 +971,15 @@ static void get_atca_shelf_ip_address_control_state_cb(ipmi_entity_t *ent,
 	unsigned int len = 256;
 	unsigned int num_rec;
 	unsigned char ver;
-	
-	
-	
+
+
+
 	info->rv = get_shelf_ip_address_record(ent, buf, &len, &ver, &num_rec);
 	if (info->rv != SA_OK) {
 		return;
 	}
-		
-	
+
+
 	info->text->Text.DataType = SAHPI_TL_TYPE_BINARY;
 	info->text->Text.Language = SAHPI_LANG_UNDEF;
 	switch (info->text->Line) {
@@ -1000,14 +1000,14 @@ static void get_atca_shelf_ip_address_control_state_cb(ipmi_entity_t *ent,
 		memcpy(info->text->Text.Data, buf + 5, 12);
 		break;
 	default :
-		dbg("wrong text->Line = %d", info->text->Line);
+		err("wrong text->Line = %d", info->text->Line);
 		info->rv = SA_ERR_HPI_INVALID_DATA;
 		break;
 	}
 }
 
-	
-	
+
+
 
 SaErrorT get_atca_shelf_ip_address_control_state(
                                       struct oh_handler_state *handler,
@@ -1020,24 +1020,24 @@ SaErrorT get_atca_shelf_ip_address_control_state(
 	struct ohoi_handler *ohoi_handler = handler->data;
 	int rv;
 	struct atca_shelf_ip_address_control_state info;
-	
+
 	if (state == NULL) {
 		goto no_state;
 	}
 #if 0
 	if (state->Type != SAHPI_CTRL_TYPE_TEXT) {
-		dbg("wrong state type %d", state->Type);
+		err("wrong state type %d", state->Type);
 		return SA_ERR_HPI_INVALID_DATA;
 	}
 #endif
 	res_info = oh_get_resource_data(handler->rptcache,
 					ohoi_handler->atca_shelf_id);
 	if (res_info == NULL) {
-		dbg("No shelf resource info?");
+		err("No shelf resource info?");
 		return SA_ERR_HPI_INTERNAL_ERROR;
 	}
 	if (res_info->fru == NULL) {
-		dbg("Shelf does not have IDR");
+		err("Shelf does not have IDR");
 		return SA_ERR_HPI_INVALID_DATA;
 	}
 
@@ -1048,7 +1048,7 @@ SaErrorT get_atca_shelf_ip_address_control_state(
 	rv = ipmi_entity_pointer_cb(res_info->u.entity.entity_id,
 		get_atca_shelf_ip_address_control_state_cb, &info);
 	if (rv != 0) {
-		dbg("ipmi_entity_pointer_cb = 0x%x", rv);
+		err("ipmi_entity_pointer_cb = 0x%x", rv);
 		g_mutex_unlock(res_info->fru->mutex);
 		return SA_ERR_HPI_INTERNAL_ERROR;
 	}
@@ -1065,7 +1065,7 @@ no_state:
 
 
 
- 
+
 static void set_atca_shelf_ip_address_control_state_cb(ipmi_entity_t *ent,
                                                 void *cb_data)
 {
@@ -1077,12 +1077,12 @@ static void set_atca_shelf_ip_address_control_state_cb(ipmi_entity_t *ent,
 	SaErrorT rv;
 	ipmi_fru_t *fru = ipmi_entity_get_fru(ent);
 //	struct ohoi_handler *ohoi_handler = info->hnd->data;
-	
+
 	info->rv = get_shelf_ip_address_record(ent, buf, &len, &ver, &num_rec);
 	if (info->rv != SA_OK) {
 		info->done = 1;
 		return;
-	}  
+	}
 	switch (info->text->Line) {
 	case 1:		// Shelf Manager IP Address
 		memcpy(buf + 5, info->text->Text.Data, 4);
@@ -1097,7 +1097,7 @@ static void set_atca_shelf_ip_address_control_state_cb(ipmi_entity_t *ent,
 		memcpy(buf + 5, info->text->Text.Data, 12);
 		break;
 	default :
-		dbg("wrong text->Line = %d", info->text->Line);
+		err("wrong text->Line = %d", info->text->Line);
 		info->rv = SA_ERR_HPI_INVALID_DATA;
 		info->done = 1;
 		return;
@@ -1105,7 +1105,7 @@ static void set_atca_shelf_ip_address_control_state_cb(ipmi_entity_t *ent,
 
 	rv = ipmi_fru_set_multi_record(fru, num_rec, 0xC0, ver, buf, len);
 	if (rv != 0) {
-		dbg("ipmi_fru_set_multi_record(fru, %d, 0xC0, 0x%x, buf, 0x%x",
+		err("ipmi_fru_set_multi_record(fru, %d, 0xC0, 0x%x, buf, 0x%x",
 				num_rec,  ver, len);
 		info->rv = SA_ERR_HPI_INTERNAL_ERROR;
 	}
@@ -1131,35 +1131,35 @@ SaErrorT set_atca_shelf_ip_address_control_state(
 		return SA_ERR_HPI_READ_ONLY;
 	}
 	if (state->Type != SAHPI_CTRL_TYPE_TEXT) {
-		dbg("wrong state type %d", state->Type);
+		err("wrong state type %d", state->Type);
 		return SA_ERR_HPI_INVALID_DATA;
 	}
 	res_info = oh_get_resource_data(handler->rptcache,
 					ohoi_handler->atca_shelf_id);
 	if (res_info == NULL) {
-		dbg("No shelf resource info?");
+		err("No shelf resource info?");
 		return SA_ERR_HPI_INTERNAL_ERROR;
 	}
 	if (res_info->fru == NULL) {
-		dbg("Shelf does not have IDR");
+		err("Shelf does not have IDR");
 		return SA_ERR_HPI_INVALID_DATA;
 	}
 	ctrl = &rdr->RdrTypeUnion.CtrlRec.TypeUnion.Text;
 	text = &state->StateUnion.Text;
 	if (text->Text.DataType != SAHPI_TL_TYPE_BINARY) {
-		dbg("wrong DataType = %d", text->Text.DataType);
+		err("wrong DataType = %d", text->Text.DataType);
 		return SA_ERR_HPI_INVALID_DATA;
 	}
 	if (text->Line == SAHPI_TLN_ALL_LINES) {
 		if (text->Text.DataLength != 12) {
-			dbg("wrong DataLength = %d", text->Text.DataLength);
+			err("wrong DataLength = %d", text->Text.DataLength);
 			return SA_ERR_HPI_INVALID_DATA;
 		}
 	} else if (text->Line > ctrl->MaxLines) {
-		dbg("wrong text->Line = %d", text->Line);
+		err("wrong text->Line = %d", text->Line);
 		return SA_ERR_HPI_INVALID_DATA;
 	} else if (text->Text.DataLength != 4) {
-		dbg("wrong DataLength = %d", text->Text.DataLength);
+		err("wrong DataLength = %d", text->Text.DataLength);
 		return SA_ERR_HPI_INVALID_DATA;
 	}
 
@@ -1167,12 +1167,12 @@ SaErrorT set_atca_shelf_ip_address_control_state(
 	info.text = text;
 	info.done = 0;
 	info.rv = SA_OK;
-	
+
 	g_mutex_lock(res_info->fru->mutex);
 	rv = ipmi_entity_pointer_cb(res_info->u.entity.entity_id,
 		set_atca_shelf_ip_address_control_state_cb, &info);
 	if (rv != 0) {
-		dbg("ipmi_entity_pointer_cb = 0x%x", rv);
+		err("ipmi_entity_pointer_cb = 0x%x", rv);
 		g_mutex_unlock(res_info->fru->mutex);
 		return SA_ERR_HPI_INTERNAL_ERROR;
 	}
@@ -1202,7 +1202,7 @@ SaErrorT set_atca_shelf_ip_address_control_state(
          *      FRU Power On Sequence Commit Status Sensor
 	 */
 
- 
+
 
 static void send_pwronseq_commit_status_sensor_event(
                                       struct oh_handler_state *handler,
@@ -1218,52 +1218,49 @@ static void send_pwronseq_commit_status_sensor_event(
 		SAHPI_SENSOR_RDR, ATCAHPI_SENSOR_NUM_PWRONSEQ_COMMIT_STATUS,
                 (void *)&s_info);
 	if (rv != SA_OK) {
-		dbg("could not get sensor info");
+		err("could not get sensor info");
 		return;
 	}
 
 	if (s_info == NULL) {
-		dbg("could not get sensor info");
+		err("could not get sensor info");
 		return;
 	}
 	if (s_info->sen_enabled == SAHPI_FALSE) {
-		dbg("sensor disabled");
+		err("sensor disabled");
 		return;
 	}
 	if (!s_info->info.atcamap_sensor_info.val) {
 		// sensor event disable
-		dbg("sensor event disabled");
+		err("sensor event disabled");
 		return;
 	}
 	if (updated && !(s_info->assert & SAHPI_ES_STATE_01)) {
-		dbg("SAHPI_ES_STATE_01 disabled");
+		err("SAHPI_ES_STATE_01 disabled");
 		return;
 	}
 	if (!updated && !(s_info->assert & SAHPI_ES_STATE_00)) {
-		dbg("SAHPI_ES_STATE_00 disabled");
+		err("SAHPI_ES_STATE_00 disabled");
 		return;
 	}
         e = malloc(sizeof(*e));
         if (!e) {
-                dbg("Out of space");
+                err("Out of space");
                 return;
         }
-/*
-        rdr = oh_get_rdr_by_type(handler->rptcache, id, SAHPI_SENSOR_RDR, num);
 
-        if (!rdr) {
-                dbg("no rdr");
-                return SA_ERR_HPI_NOT_PRESENT;
-        };
-*/
+        SaHpiRdrT *rdr = oh_get_rdr_by_type(handler->rptcache,
+        				    ipmi_handler->atca_shelf_id,
+        				    SAHPI_SENSOR_RDR,
+        				    ATCAHPI_SENSOR_NUM_PWRONSEQ_COMMIT_STATUS);
+
         memset(e, 0, sizeof(*e));
-        e->type = OH_ET_HPI;
-        e->u.hpi_event.event.Source = ipmi_handler->atca_shelf_id;
-        e->u.hpi_event.event.EventType = SAHPI_ET_SENSOR;
-        e->u.hpi_event.event.Severity = SAHPI_INFORMATIONAL;
-        oh_gettimeofday(&e->u.hpi_event.event.Timestamp);
+        e->event.Source = ipmi_handler->atca_shelf_id;
+        e->event.EventType = SAHPI_ET_SENSOR;
+        e->event.Severity = SAHPI_INFORMATIONAL;
+        oh_gettimeofday(&e->event.Timestamp);
 
-        sen_evt = &(e->u.hpi_event.event.EventDataUnion.SensorEvent);
+        sen_evt = &(e->event.EventDataUnion.SensorEvent);
         sen_evt->SensorNum = ATCAHPI_SENSOR_NUM_PWRONSEQ_COMMIT_STATUS;
         sen_evt->SensorType = SAHPI_OEM_SENSOR;
         sen_evt->EventCategory = SAHPI_EC_SENSOR_SPECIFIC;
@@ -1274,8 +1271,11 @@ static void send_pwronseq_commit_status_sensor_event(
         sen_evt->CurrentState = updated ? SAHPI_ES_STATE_01 : SAHPI_ES_STATE_00;
         sen_evt->PreviousState = updated ? SAHPI_ES_STATE_00 : SAHPI_ES_STATE_01;
 
-        handler->eventq = g_slist_append(handler->eventq, e);
-}          
+        if (rdr) e->rdrs = g_slist_append(e->rdrs, g_memdup(rdr, sizeof(SaHpiRdrT)));
+
+        e->hid = handler->hid;
+        oh_evt_queue_push(handler->eventq, e);
+}
 
 static SaErrorT get_pwronseq_commit_status_sensor_event_enable(
 					    struct oh_handler_state *hnd,
@@ -1302,11 +1302,11 @@ static SaErrorT set_pwronseq_commit_status_sensor_event_enable(
 {
 
 	if (deassert != 0) {
-		dbg("deassert(0x%x) != 0", deassert);
+		err("deassert(0x%x) != 0", deassert);
 		return SA_ERR_HPI_INVALID_DATA;
 	}
-	if ((assert & ~(SAHPI_ES_STATE_00 | SAHPI_ES_STATE_01))) { 
-		dbg("assert(0x%x)", assert);
+	if ((assert & ~(SAHPI_ES_STATE_00 | SAHPI_ES_STATE_01))) {
+		err("assert(0x%x)", assert);
 		return SA_ERR_HPI_INVALID_DATA;
 	}
 	sinfo->assert = assert;
@@ -1372,12 +1372,12 @@ static SaHpiRdrT *create_fru_power_on_sequence_commit_status_sensor(
 
 	rdr = malloc(sizeof (*rdr));
 	if (rdr == NULL) {
-		dbg("Out of memory");
+		err("Out of memory");
 		return NULL;
 	}
 	s_info = malloc(sizeof (*s_info));
 	if (rdr == NULL) {
-		dbg("Out of memory");
+		err("Out of memory");
 		free(rdr);
 		return NULL;
 	}
@@ -1424,7 +1424,7 @@ static SaHpiRdrT *create_fru_power_on_sequence_commit_status_sensor(
 		set_pwronseq_commit_status_sensor_thresholds;
 
 	*sensor_info = s_info;
-	
+
 	return rdr;
 }
 
@@ -1434,7 +1434,7 @@ static SaHpiRdrT *create_fru_power_on_sequence_commit_status_sensor(
 	/*
          *      FRU Power On Sequence Controls
 	 */
-	 
+
 static SaErrorT get_atca_fru_pwronseq_control_state(
                                       struct oh_handler_state *hnd,
                                       struct ohoi_control_info *c,
@@ -1451,8 +1451,8 @@ static SaErrorT set_atca_fru_pwronseq_control_state(
                                       SaHpiCtrlStateT *state);
 
 
-	
- 
+
+
 
 static SaHpiRdrT *create_fru_power_on_sequence_control(
 			struct oh_handler_state *handler,
@@ -1469,12 +1469,12 @@ static SaHpiRdrT *create_fru_power_on_sequence_control(
 
 	rdr = malloc(sizeof (*rdr));
 	if (rdr == NULL) {
-		dbg("Out of memory");
+		err("Out of memory");
 		return NULL;
 	}
 	c_info = malloc(sizeof (*c_info));
 	if (rdr == NULL) {
-		dbg("Out of memory");
+		err("Out of memory");
 		free(rdr);
 		return NULL;
 	}
@@ -1527,21 +1527,21 @@ static SaErrorT get_atca_fru_pwronseq_control_state(
 	}
 	if ((num < 0) || (num >= g_slist_length(
 				ipmi_handler->atca_pwonseq_desk))) {
-		dbg("wrong dsk number %d", num);
+		err("wrong dsk number %d", num);
 		return SA_ERR_HPI_INTERNAL_ERROR;
 	}
 
 	state->Type = SAHPI_CTRL_TYPE_DISCRETE;
-	g_static_rec_mutex_lock(&ipmi_handler->ohoih_lock);	
+	g_static_rec_mutex_lock(&ipmi_handler->ohoih_lock);
 	node = g_slist_nth(ipmi_handler->atca_pwonseq_desk, num);
 	if (node == NULL) {
 		g_static_rec_mutex_unlock(&ipmi_handler->ohoih_lock);
-		dbg("No pw on descriptor #%d", num);
+		err("No pw on descriptor #%d", num);
 		return SA_ERR_HPI_INTERNAL_ERROR;
 	}
 	dsk = (ohoi_atca_pwonseq_dsk_t *)node->data;
 	state->StateUnion.Discrete = dsk->slotid;
-	g_static_rec_mutex_unlock(&ipmi_handler->ohoih_lock);	
+	g_static_rec_mutex_unlock(&ipmi_handler->ohoih_lock);
 no_state :
 	if (mode) {
 		*mode = c->mode;
@@ -1569,14 +1569,14 @@ static SaErrorT set_atca_fru_pwronseq_control_state(
 	int minid, maxid;
 	int beg, len;
 	int i;
-	
+
 
 	if (mode == SAHPI_CTRL_MODE_AUTO) {
 		c->mode = mode;
 		return SA_OK;
 	}
 	if (state->Type != SAHPI_CTRL_TYPE_DISCRETE) {
-		dbg("wrong state type %d", state->Type);
+		err("wrong state type %d", state->Type);
 		return SA_ERR_HPI_INVALID_DATA;
 	}
 	slotid = state->StateUnion.Discrete;
@@ -1585,17 +1585,17 @@ static SaErrorT set_atca_fru_pwronseq_control_state(
 	res_info = oh_get_resource_data(handler->rptcache,
 					ipmi_handler->atca_shelf_id);
 	if (res_info == NULL) {
-		dbg("No shelf resource info?");
+		err("No shelf resource info?");
 		g_static_rec_mutex_unlock(&ipmi_handler->ohoih_lock);
 		return SA_ERR_HPI_INTERNAL_ERROR;
 	}
 	if (res_info->fru == NULL) {
 		g_static_rec_mutex_unlock(&ipmi_handler->ohoih_lock);
-		dbg("Shelf does not have IDR");
+		err("Shelf does not have IDR");
 		return SA_ERR_HPI_INVALID_DATA;
 	}
 	ctrl = &rdr->RdrTypeUnion.CtrlRec;
-	
+
 	// find out descriptor with required slotid
 	oldid = 0;
 	for (oldid = 0; oldid < g_slist_length(
@@ -1611,10 +1611,10 @@ static SaErrorT set_atca_fru_pwronseq_control_state(
 	}
 	if (dscp == NULL) {
 		g_static_rec_mutex_unlock(&ipmi_handler->ohoih_lock);
-		dbg("No descriptor for slotid %d", slotid);
+		err("No descriptor for slotid %d", slotid);
 		return SA_ERR_HPI_INVALID_PARAMS;
 	}
-	
+
 	newid = ctrl->Num - ATCAHPI_CTRL_NUM_FRU_POWER_ON_SEQUENCE;
 	c->mode = mode;
 	if (newid == oldid) {
@@ -1628,7 +1628,7 @@ static SaErrorT set_atca_fru_pwronseq_control_state(
 				ipmi_handler->atca_pwonseq_desk, dscp);
 	ipmi_handler->atca_pwonseq_desk = g_slist_insert(
 		ipmi_handler->atca_pwonseq_desk, dscp, newid);
-	
+
 	// Which records are affected and mark them as updated
 	oldid--;
 	maxid = (newid > oldid) ? newid : oldid;
@@ -1646,17 +1646,17 @@ static SaErrorT set_atca_fru_pwronseq_control_state(
 			recp->updated = 1;
 		}
 	}
-	
+
 	if (ipmi_handler->atca_pwonseq_updated) {
 		// was updated before. nothing to do more
 		g_static_rec_mutex_unlock(&ipmi_handler->ohoih_lock);
 		return SA_OK;
 	}
 	ipmi_handler->atca_pwonseq_updated = 1;
-	
+
 	send_pwronseq_commit_status_sensor_event(handler, 1);
-	
-	return SA_OK; 
+
+	return SA_OK;
 }
 
 
@@ -1696,12 +1696,12 @@ static SaHpiRdrT *create_fru_power_on_sequence_commit_control(
 
 	rdr = malloc(sizeof (*rdr));
 	if (rdr == NULL) {
-		dbg("Out of memory");
+		err("Out of memory");
 		return NULL;
 	}
 	c_info = malloc(sizeof (*c_info));
 	if (rdr == NULL) {
-		dbg("Out of memory");
+		err("Out of memory");
 		free(rdr);
 		return NULL;
 	}
@@ -1733,7 +1733,7 @@ static SaHpiRdrT *create_fru_power_on_sequence_commit_control(
 	c_info->ohoii.set_control_state =
 				set_atca_fru_pwronseq_commit_control_state;
 	*ctrl_info = c_info;
-	
+
 	return rdr;
 }
 
@@ -1771,11 +1771,11 @@ static void write_power_on_sequence_data_cb(ipmi_entity_t *ent, void *cb_data)
 	struct fru_pwronseq_commit_control_s *info = cb_data;
 	ipmi_fru_t *fru = ipmi_entity_get_fru(ent);
 	int rv;
-	
+
 	rv = ipmi_fru_set_multi_record(fru, info->num, 0xC0, 0x0,
 							info->buf, info->len);
 	if (rv != 0) {
-		dbg("ipmi_fru_set_multi_record(fru, %d, 0xC0, 0x0, buf, %d)"
+		err("ipmi_fru_set_multi_record(fru, %d, 0xC0, 0x0, buf, %d)"
 			" = %d", info->num, info->len, rv);
 		info->rv = SA_ERR_HPI_INTERNAL_ERROR;
 	}
@@ -1800,15 +1800,15 @@ static SaErrorT set_atca_fru_pwronseq_commit_control_state(
 	unsigned char buf[256];
 	unsigned int len;
 	struct fru_pwronseq_commit_control_s info;
-	
+
 	if (mode == SAHPI_CTRL_MODE_AUTO) {
 		return SA_ERR_HPI_READ_ONLY;
 	}
 
 	value = state->StateUnion.Digital;
-	
+
 	if (value != SAHPI_CTRL_STATE_PULSE_ON) {
-		dbg("wrong discrete value %d", value);
+		err("wrong discrete value %d", value);
 		return SA_ERR_HPI_INVALID_REQUEST;
 	}
 
@@ -1828,9 +1828,9 @@ static SaErrorT set_atca_fru_pwronseq_commit_control_state(
 		g_static_rec_mutex_lock(&ipmi_handler->ohoih_lock);
 		return SA_OK;
 	}
-	
+
 	// SAHPI_CTRL_STATE_PULSE_ON operation
-	
+
 		// at first check the correctness of the lists
 	num = 0;
 	for (i = 0; ; i++) {
@@ -1842,12 +1842,12 @@ static SaErrorT set_atca_fru_pwronseq_commit_control_state(
 		num += recp->head[6];
 	}
 	if (num != g_slist_length(ipmi_handler->atca_pwonseq_desk)) {
-		dbg("list length dismatched: %d != %d", num,
+		err("list length dismatched: %d != %d", num,
 				g_slist_length(ipmi_handler->atca_pwonseq_desk));
 		g_static_rec_mutex_unlock(&ipmi_handler->ohoih_lock);
 		return SA_ERR_HPI_INTERNAL_ERROR;
 	}
-	
+
 	di = 0;
 	for (i = 0; ; i++) {
 		recp = (ohoi_atca_pwonseq_rec_t *)g_slist_nth_data(
@@ -1864,7 +1864,7 @@ static SaErrorT set_atca_fru_pwronseq_commit_control_state(
 			dscp = (ohoi_atca_pwonseq_dsk_t *)g_slist_nth_data(
 				ipmi_handler->atca_pwonseq_desk, di);
 			if (dscp == NULL) {
-				dbg("No descrintor %d for record %d", j, i);
+				err("No descrintor %d for record %d", j, i);
 				g_static_rec_mutex_unlock(&ipmi_handler->ohoih_lock);
 				return SA_ERR_HPI_INTERNAL_ERROR;
 			}
@@ -1874,7 +1874,7 @@ static SaErrorT set_atca_fru_pwronseq_commit_control_state(
 		}
 #if 0
 printf("RECORD: 0x%02x%02x%02x%02x%02x%02x%02x\n", buf[0], buf[1], buf[2], buf[3], buf[4], buf[5], buf[6]);
-for (j = 0; j < recp->head[6]; j++) 
+for (j = 0; j < recp->head[6]; j++)
 printf("%02x%02x%02x%02x%02x\n", buf[7 + 5 * j + 0], buf[7 + 5 * j + 1], buf[7 + 5 * j + 2], buf[7 + 5 * j + 3], buf[7 + 5 * j + 4]);
 #endif
 		info.ipmi_handler = ipmi_handler;
@@ -1891,7 +1891,7 @@ printf("%02x%02x%02x%02x%02x\n", buf[7 + 5 * j + 0], buf[7 + 5 * j + 1], buf[7 +
 			g_static_rec_mutex_unlock(&ipmi_handler->ohoih_lock);
 			return info.rv;
 		}
-		recp->updated = 0; 
+		recp->updated = 0;
 	}
 	ipmi_handler->atca_pwonseq_updated = 0;
 	// XXX  Call real write fru
@@ -1906,7 +1906,7 @@ printf("%02x%02x%02x%02x%02x\n", buf[7 + 5 * j + 0], buf[7 + 5 * j + 1], buf[7 +
 	/*
 	 *       Creating Virtual Shelf RDRs after domain fully up
 	 */
-	 
+
 
 
 struct create_pwonseq {
@@ -1956,24 +1956,24 @@ void ohoi_atca_create_shelf_virtual_rdrs(struct oh_handler_state *hnd)
 	rpt = oh_get_resource_by_id(hnd->rptcache,
 				ipmi_handler->atca_shelf_id);
 	if (rpt == NULL) {
-		dbg("No rpt for atca chassis?");
+		err("No rpt for atca chassis?");
 		return;
 	}
 	res_info = oh_get_resource_data(hnd->rptcache,
 					ipmi_handler->atca_shelf_id);
-					
+
 
 	// init data for Power On Sequence RDRs
 	ipmi_entity_pointer_cb(res_info->u.entity.entity_id,
 				init_power_on_sequence_data_cb, ipmi_handler);
-	
-	
+
+
 	// Create Shelf Address control
 	rdr = create_atca_shelf_address_control(ipmi_handler, rpt, &c_info);
 	if (rdr != NULL && (oh_add_rdr(hnd->rptcache,
 					ipmi_handler->atca_shelf_id,
 					rdr, c_info, 1) != SA_OK)) {
-		dbg("couldn't add control rdr");
+		err("couldn't add control rdr");
 		free(rdr);
 		free(c_info);
 	} else {
@@ -1985,7 +1985,7 @@ void ohoi_atca_create_shelf_virtual_rdrs(struct oh_handler_state *hnd)
 	if (rdr != NULL && (oh_add_rdr(hnd->rptcache,
 					ipmi_handler->atca_shelf_id,
 					rdr, c_info, 1) != SA_OK)) {
-		dbg("couldn't add control rdr");
+		err("couldn't add control rdr");
 		free(rdr);
 		free(c_info);
 	} else {
@@ -1997,7 +1997,7 @@ void ohoi_atca_create_shelf_virtual_rdrs(struct oh_handler_state *hnd)
 	if (rdr != NULL && (oh_add_rdr(hnd->rptcache,
 					ipmi_handler->atca_shelf_id,
 					rdr, c_info, 1) != SA_OK)) {
-		dbg("couldn't add control rdr");
+		err("couldn't add control rdr");
 		free(rdr);
 		free(c_info);
 	} else {
@@ -2009,7 +2009,7 @@ void ohoi_atca_create_shelf_virtual_rdrs(struct oh_handler_state *hnd)
 	if (rdr != NULL && (oh_add_rdr(hnd->rptcache,
 					ipmi_handler->atca_shelf_id,
 					rdr, c_info, 1) != SA_OK)) {
-		dbg("couldn't add control rdr");
+		err("couldn't add control rdr");
 		free(rdr);
 		free(c_info);
 	} else {
@@ -2023,7 +2023,7 @@ void ohoi_atca_create_shelf_virtual_rdrs(struct oh_handler_state *hnd)
 		dsk = (ohoi_atca_pwonseq_dsk_t *)g_slist_nth_data(
 				ipmi_handler->atca_pwonseq_desk, i);
 		if (dsk == NULL) {
-			dbg("no descriptor");
+			err("no descriptor");
 			continue;
 		}
 		ohoi_iterate_rptcache(hnd, assign_slotid_to_pwonseq, dsk);
@@ -2032,7 +2032,7 @@ void ohoi_atca_create_shelf_virtual_rdrs(struct oh_handler_state *hnd)
 		if (rdr != NULL && (oh_add_rdr(hnd->rptcache,
 					ipmi_handler->atca_shelf_id,
 						    rdr, c_info, 1) != SA_OK)) {
-			dbg("couldn't add control rdr");
+			err("couldn't add control rdr");
 			free(rdr);
 			free(c_info);
 		} else {
@@ -2046,7 +2046,7 @@ void ohoi_atca_create_shelf_virtual_rdrs(struct oh_handler_state *hnd)
 	if (rdr != NULL && (oh_add_rdr(hnd->rptcache,
 					ipmi_handler->atca_shelf_id,
 					rdr, s_info, 1) != SA_OK)) {
-		dbg("couldn't add control rdr");
+		err("couldn't add control rdr");
 		free(rdr);
 		free(s_info);
 	} else {
@@ -2068,8 +2068,8 @@ void ohoi_atca_create_shelf_virtual_rdrs(struct oh_handler_state *hnd)
 	entity_rpt_set_updated(res_info, ipmi_handler);
 	g_static_rec_mutex_unlock(&ipmi_handler->ohoih_lock);
 }
-	 
-	
-	
+
+
+
 
 
