@@ -90,6 +90,7 @@
  */
 
 #include <stdio.h>
+#include "sahpi_wrappers.h"
 #include "oa_soap_control.h"
 
 /* Forward declaraction for static functions */
@@ -211,7 +212,6 @@ SaErrorT oa_soap_get_control_state(void *oh_handler,
         SaHpiCtrlTypeT type;
         SaHpiCtrlModeT ctrl_mode;
         SaHpiCtrlStateT ctrl_state;
-        SaHpiCtrlRecDigitalT *digital = NULL;
         SaHpiCtrlRecT *ctrl = NULL;
 	SaHpiCtrlStateDigitalT control_digital_state = 0;
 	SaHpiCtrlStateDiscreteT control_discrete_state = 0;
@@ -250,8 +250,6 @@ SaErrorT oa_soap_get_control_state(void *oh_handler,
         type = ctrl->Type;
         ctrl_state.Type = type;
 
-        digital = &(ctrl->TypeUnion.Digital);
-
         switch (rdr_num){
                 case OA_SOAP_PWR_CNTRL:
                         rv = oa_soap_get_pwr_cntrl(handler, resource_id, 
@@ -414,7 +412,6 @@ SaErrorT oa_soap_set_control_state(void *oh_handler,
 {
         SaErrorT rv = SA_OK;
         struct oh_handler_state *handler = NULL;
-        struct oa_soap_handler *oa_handler = NULL;
         SaHpiRptEntryT *rpt = NULL;
         SaHpiRdrT *rdr = NULL;
         SaHpiCtrlRecT *ctrl = NULL;
@@ -425,7 +422,6 @@ SaErrorT oa_soap_set_control_state(void *oh_handler,
         }
 
         handler = (struct oh_handler_state *) oh_handler;
-        oa_handler = (struct oa_soap_handler *) handler->data;
 
         rpt = oh_get_resource_by_id (handler->rptcache, resource_id);
         if (rpt == NULL) {
@@ -642,6 +638,8 @@ SaErrorT oa_soap_build_control_rdr(struct oh_handler_state *oh_handler,
                   analogLimitLow;
                 rdr->RdrTypeUnion.CtrlRec.TypeUnion.Analog.Max =
                   analogLimitHigh;
+		rdr->RdrTypeUnion.CtrlRec.TypeUnion.Analog.Default = 
+		  analogLimitLow;
         } 
         return SA_OK;
 }
@@ -927,7 +925,8 @@ static SaErrorT oa_soap_get_pwr_cntrl(struct oh_handler_state *oh_handler,
 			*control_state = SAHPI_CTRL_STATE_OFF;
 			break;
 		default:
-			err("Invalid power state");
+			err("Invalid power state %d detected for "
+				"Resource ID %d", power_state,resource_id);
 			return SA_ERR_HPI_INTERNAL_ERROR;
 	}
 
@@ -1171,11 +1170,11 @@ static SaErrorT oa_soap_get_dynamic_pwr_cntrl(
         power_config_info = &(oa_handler->power_config_info);
 	
         /* Make a soap call to get the enclosure power config info */
-        g_mutex_lock(oa_handler->mutex);
+        wrap_g_mutex_lock(oa_handler->mutex);
         rv = soap_getPowerConfigInfo(oa_handler->active_con,
                                      power_config_info,
                                      &(oa_handler->desired_static_pwr_limit));
-        g_mutex_unlock(oa_handler->mutex);
+        wrap_g_mutex_unlock(oa_handler->mutex);
         if (rv != SOAP_OK) {
                 err("Get enclosure power config info failed");
                 return SA_ERR_HPI_INTERNAL_ERROR;
@@ -1290,11 +1289,11 @@ static SaErrorT oa_soap_get_pwr_mode_cntrl(
         power_config_info = &(oa_handler->power_config_info);
 	
         /* Make a soap call to get the enclosure power config info */
-        g_mutex_lock(oa_handler->mutex);
+        wrap_g_mutex_lock(oa_handler->mutex);
         rv = soap_getPowerConfigInfo(oa_handler->active_con,
                                      power_config_info,
                                      &(oa_handler->desired_static_pwr_limit));
-        g_mutex_unlock(oa_handler->mutex);
+        wrap_g_mutex_unlock(oa_handler->mutex);
         if (rv != SOAP_OK) {
                 err("Get enclosure power config info failed");
                 return SA_ERR_HPI_INTERNAL_ERROR;
@@ -1406,11 +1405,11 @@ static SaErrorT oa_soap_get_pwr_limit_mode_cntrl(
         power_cap_config = &(oa_handler->power_cap_config);
 	
         /* Make a soap call to get the enclosure power config info */
-        g_mutex_lock(oa_handler->mutex);
+        wrap_g_mutex_lock(oa_handler->mutex);
         rv = soap_getPowerConfigInfo(oa_handler->active_con,
                                      power_config_info,
                                      &(oa_handler->desired_static_pwr_limit));
-        g_mutex_unlock(oa_handler->mutex);
+        wrap_g_mutex_unlock(oa_handler->mutex);
         if (rv != SOAP_OK) {
                 err("Get enclosure power config info failed");
                 return SA_ERR_HPI_INTERNAL_ERROR;
@@ -1418,13 +1417,13 @@ static SaErrorT oa_soap_get_pwr_limit_mode_cntrl(
 
         /* Make a soap call to get the enclosure power dynamic power */
         /* cap config                                                */
-        g_mutex_lock(oa_handler->mutex);
+        wrap_g_mutex_lock(oa_handler->mutex);
         rv = soap_getPowerCapConfig(oa_handler->active_con,
                                     power_cap_config,
                                     &(oa_handler->desired_dynamic_pwr_cap),
                                     &(oa_handler->desired_derated_circuit_cap),
                                     &(oa_handler->desired_rated_circuit_cap));
-        g_mutex_unlock(oa_handler->mutex);
+        wrap_g_mutex_unlock(oa_handler->mutex);
         if (rv != SOAP_OK) {
                 err("Get enclosure dynamic power cap config failed");
                 return SA_ERR_HPI_INTERNAL_ERROR;
@@ -1631,11 +1630,11 @@ static SaErrorT oa_soap_get_static_pwr_limit_cntrl(
         power_config_info = &(oa_handler->power_config_info);
 	
         /* Make a soap call to get the enclosure power config info */
-        g_mutex_lock(oa_handler->mutex);
+        wrap_g_mutex_lock(oa_handler->mutex);
         rv = soap_getPowerConfigInfo(oa_handler->active_con,
                                      power_config_info,
                                      &(oa_handler->desired_static_pwr_limit));
-        g_mutex_unlock(oa_handler->mutex);
+        wrap_g_mutex_unlock(oa_handler->mutex);
         if (rv != SOAP_OK) {
                 err("Get enclosure power config info failed");
                 return SA_ERR_HPI_INTERNAL_ERROR;
@@ -1738,13 +1737,13 @@ static SaErrorT oa_soap_get_dynamic_pwr_cap_cntrl(
         power_cap_config = &(oa_handler->power_cap_config);
 	
         /* Make a soap call to get the enclosure power cap config */
-        g_mutex_lock(oa_handler->mutex);
+        wrap_g_mutex_lock(oa_handler->mutex);
         rv = soap_getPowerCapConfig(oa_handler->active_con,
                                     power_cap_config,
                                     &(oa_handler->desired_dynamic_pwr_cap),
                                     &(oa_handler->desired_derated_circuit_cap),
                                     &(oa_handler->desired_rated_circuit_cap));
-        g_mutex_unlock(oa_handler->mutex);
+        wrap_g_mutex_unlock(oa_handler->mutex);
         if (rv != SOAP_OK) {
                 err("Get enclosure power cap config failed");
                 return SA_ERR_HPI_INTERNAL_ERROR;
@@ -1781,7 +1780,6 @@ static SaErrorT oa_soap_set_dynamic_pwr_cap_cntrl(
   SaHpiCtrlStateAnalogT control_state)
 {
         SaErrorT rv = SA_OK;
-        struct powerConfigInfo *power_config_info;
         struct powerCapConfig *power_cap_config;
         struct oa_soap_handler *oa_handler = NULL;
 
@@ -1791,7 +1789,6 @@ static SaErrorT oa_soap_set_dynamic_pwr_cap_cntrl(
 	}
 	
         oa_handler = (struct oa_soap_handler *) oh_handler->data;
-        power_config_info = &(oa_handler->power_config_info);
         power_cap_config = &(oa_handler->power_cap_config);
 
         oa_handler->desired_dynamic_pwr_cap = control_state;
@@ -1849,13 +1846,13 @@ static SaErrorT oa_soap_get_derated_circuit_cap_cntrl(
         power_cap_config = &(oa_handler->power_cap_config);
 	
         /* Make a soap call to get the enclosure power cap config */
-        g_mutex_lock(oa_handler->mutex);
+        wrap_g_mutex_lock(oa_handler->mutex);
         rv = soap_getPowerCapConfig(oa_handler->active_con,
                                     power_cap_config,
                                     &(oa_handler->desired_dynamic_pwr_cap),
                                     &(oa_handler->desired_derated_circuit_cap),
                                     &(oa_handler->desired_rated_circuit_cap));
-        g_mutex_unlock(oa_handler->mutex);
+        wrap_g_mutex_unlock(oa_handler->mutex);
         if (rv != SOAP_OK) {
                 err("Get enclosure derated circuit cap config failed");
                 return SA_ERR_HPI_INTERNAL_ERROR;
@@ -1892,7 +1889,6 @@ static SaErrorT oa_soap_set_derated_circuit_cap_cntrl(
   SaHpiCtrlStateAnalogT control_state)
 {
         SaErrorT rv = SA_OK;
-        struct powerConfigInfo *power_config_info;
         struct powerCapConfig *power_cap_config;
         struct oa_soap_handler *oa_handler = NULL;
 
@@ -1902,7 +1898,6 @@ static SaErrorT oa_soap_set_derated_circuit_cap_cntrl(
 	}
 	
         oa_handler = (struct oa_soap_handler *) oh_handler->data;
-        power_config_info = &(oa_handler->power_config_info);
         power_cap_config = &(oa_handler->power_cap_config);
 
         oa_handler->desired_derated_circuit_cap = control_state;
@@ -1961,13 +1956,13 @@ static SaErrorT oa_soap_get_rated_circuit_cap_cntrl(
         power_cap_config = &(oa_handler->power_cap_config);
 	
         /* Make a soap call to get the enclosure power cap config */
-        g_mutex_lock(oa_handler->mutex);
+        wrap_g_mutex_lock(oa_handler->mutex);
         rv = soap_getPowerCapConfig(oa_handler->active_con,
                                     power_cap_config,
                                     &(oa_handler->desired_dynamic_pwr_cap),
                                     &(oa_handler->desired_derated_circuit_cap),
                                     &(oa_handler->desired_rated_circuit_cap));
-        g_mutex_unlock(oa_handler->mutex);
+        wrap_g_mutex_unlock(oa_handler->mutex);
         if (rv != SOAP_OK) {
                 err("Get enclosure rated circuit cap config failed");
                 return SA_ERR_HPI_INTERNAL_ERROR;
@@ -2004,7 +1999,6 @@ static SaErrorT oa_soap_set_rated_circuit_cap_cntrl(
   SaHpiCtrlStateAnalogT control_state)
 {
         SaErrorT rv = SA_OK;
-        struct powerConfigInfo *power_config_info;
         struct powerCapConfig *power_cap_config;
         struct oa_soap_handler *oa_handler = NULL;
 
@@ -2014,7 +2008,6 @@ static SaErrorT oa_soap_set_rated_circuit_cap_cntrl(
 	}
 	
         oa_handler = (struct oa_soap_handler *) oh_handler->data;
-        power_config_info = &(oa_handler->power_config_info);
         power_cap_config = &(oa_handler->power_cap_config);
 
         oa_handler->desired_rated_circuit_cap = control_state;
