@@ -96,6 +96,7 @@ SaErrorT oa_soap_get_hotswap_state(void *oh_handler,
                 return(SA_ERR_HPI_INVALID_PARAMS);
         }
 
+ 
         handler = (struct oh_handler_state *) oh_handler;
         rpt = oh_get_resource_by_id(handler->rptcache, resource_id);
         if (rpt == NULL) {
@@ -103,28 +104,38 @@ SaErrorT oa_soap_get_hotswap_state(void *oh_handler,
                 return SA_ERR_HPI_INVALID_RESOURCE;
         }
 
-        if (! (rpt->ResourceCapabilities & SAHPI_CAPABILITY_MANAGED_HOTSWAP)) {
-                err("Resource does not have MANAGED_HOTSWAP capability");
+        if (! (rpt->ResourceCapabilities & SAHPI_CAPABILITY_FRU)) {
+                err("Resource does not have FRU capability");
                 return SA_ERR_HPI_CAPABILITY;
         }
 
-        /* Get the hotswap structure from rpt */
-        hotswap_state = (struct oa_soap_hotswap_state *)
-                oh_get_resource_data(handler->rptcache, resource_id);
-        if (hotswap_state == NULL) {
-                err("Unable to get the resource private data");
-                return SA_ERR_HPI_INVALID_RESOURCE;
+        /* For FAN, PS, OA etc give the state based on ResouceFailed 
+           The standards changed to include all FRUs */
+        if (! (rpt->ResourceCapabilities & SAHPI_CAPABILITY_MANAGED_HOTSWAP)) {
+                if(!(rpt->ResourceFailed)) {
+                          *state = SAHPI_HS_STATE_ACTIVE;
+                } else {
+                          *state = SAHPI_HS_STATE_INACTIVE;
+                } 
+         } else {
+
+                /* Get the hotswap structure of MANAGED_HOTSWAP */
+                hotswap_state = (struct oa_soap_hotswap_state *)
+                         oh_get_resource_data(handler->rptcache, resource_id);
+                if (hotswap_state == NULL) {
+                         err("Unable to get the resource private data");
+                         return SA_ERR_HPI_INVALID_RESOURCE;
+                }
+
+                *state  = hotswap_state->currentHsState;
+        }
+        if ( *state == SAHPI_HS_STATE_NOT_PRESENT) {
+                /* We can never have any resouce information in RPT 
+                    with * NOT_PRESENT hotswap state Ideally, this 
+                    code should never gets executed */
+                 return  SA_ERR_HPI_INVALID_RESOURCE;
         }
 
-        if (hotswap_state->currentHsState == SAHPI_HS_STATE_NOT_PRESENT) {
-                /* We can never have any resouce information in RPT with
-                 * NOT_PRESENT hotswap state
-                 * Ideally, this code should never gets executed
-                 */
-                return  SA_ERR_HPI_INVALID_RESOURCE;
-        }
-
-        *state  = hotswap_state->currentHsState;
         return SA_OK;
 }
 
@@ -357,7 +368,6 @@ SaErrorT oa_soap_hotswap_policy_cancel(void *oh_handler,
 /**
  * oa_soap_get_autoinsert_timeout:
  *      @oh_handler:  Handler data pointer.
- *      @resource_id: Resource ID.
  *      @timeout:     Timeout to set.
  *
  * Purpose:
@@ -367,16 +377,15 @@ SaErrorT oa_soap_hotswap_policy_cancel(void *oh_handler,
  *
  * Return values:
  *      SA_OK                     - on success
- *      SAHPI_TIMEOUT_IMMEDIATE   - autonomous handling is immediate
  *      SA_ERR_HPI_INVALID_PARAMS - Pointer parameter(s) are NULL.
  **/
 SaErrorT oa_soap_get_autoinsert_timeout(void *oh_handler,
-                                        SaHpiResourceIdT resource_id,
-                                        SaHpiTimeoutT timeout)
+                                        SaHpiTimeoutT *timeout)
 {
-        err("oa_soap_get_autoinsert_timeout is not supported");
-        err("Default auto insert timeout is IMMEDIATE and read only");
-        return SAHPI_TIMEOUT_IMMEDIATE;
+        dbg("oa_soap_get_autoinsert_timeout is not supported");
+        dbg("Default auto insert timeout is IMMEDIATE and read only");
+        *timeout=SAHPI_TIMEOUT_IMMEDIATE;
+        return SA_OK;
 }
 
 /**
@@ -397,7 +406,7 @@ SaErrorT oa_soap_get_autoinsert_timeout(void *oh_handler,
 SaErrorT oa_soap_set_autoinsert_timeout(void *oh_handler,
                                         SaHpiTimeoutT timeout)
 {
-        err("oa_soap_set_autoinsert_timeout is not supported");
+        err("oa_soap_set_autoinsert_timeout supplied is %lld",timeout);
         err("Default auto insert timeout is IMMEDIATE and read only");
         return SA_ERR_HPI_READ_ONLY;
 }
@@ -422,9 +431,10 @@ SaErrorT oa_soap_get_autoextract_timeout(void *oh_handler,
                                          SaHpiResourceIdT resource_id,
                                          SaHpiTimeoutT *timeout)
 {
-        err("oa_soap_get_autoextract_timeout is not supported");
-        err("Default auto extract timeout is IMMEDIATE and read only");
-        return SAHPI_TIMEOUT_IMMEDIATE;
+        dbg("oa_soap_get_autoextract_timeout is not supported");
+        dbg("Default auto extract timeout is IMMEDIATE and read only");
+        *timeout=SAHPI_TIMEOUT_IMMEDIATE;
+        return SA_OK;
 }
 
 /**
