@@ -44,6 +44,9 @@ SaErrorT process_oa_extraction_event(struct oh_handler_state *oh_handler,
 SaErrorT process_oa_failover_event(struct oh_handler_state *oh_handler,
                                    struct oa_info *oa);
 
+SaErrorT process_oa_reboot_event(struct oh_handler_state *oh_handler,
+                                   struct oa_info *oa);
+
 SaErrorT process_oa_info_event(struct oh_handler_state *oh_handler,
                                SOAP_CON *con,
                                struct eventInfo *oa_event);
@@ -54,4 +57,7 @@ void oa_soap_proc_oa_status(struct oh_handler_state *oh_handler,
 void oa_soap_proc_oa_network_info(struct oh_handler_state *oh_handler,
 				  struct oaNetworkInfo *nw_info);
 
+void oa_soap_proc_oa_inserted(struct oh_handler_state *oh_handler,
+          struct eventInfo *oa_event);
+
 #endif
