@@ -66,15 +66,12 @@ SaErrorT oa_soap_get_reset_state(void *oh_handler,
 {
         SaErrorT rv = SA_OK;
         SaHpiPowerStateT state;
-        struct oh_handler_state *handler = NULL;
 
         if (oh_handler == NULL || action == NULL) {
                 err("Invalid parameters");
                 return SA_ERR_HPI_INVALID_PARAMS;
         }
 
-        handler = (struct oh_handler_state *) oh_handler;
-
         /* Get the current power state of the resource */
         rv = oa_soap_get_power_state(oh_handler, resource_id, &state);
         if (rv != SA_OK) {
@@ -218,13 +215,16 @@ SaErrorT oa_soap_set_reset_state(void *oh_handler,
                                          * Reset the server blade
                                          */
                                         server_request.bayNumber = bay_number;
-                                        server_request.power = RESET;
+                                        if(action == SAHPI_COLD_RESET)
+                                                server_request.power = COLD_BOOT;
+                                        else
+                                                server_request.power = RESET;
                                         rv = soap_setBladePower(
                                                 oa_handler->active_con,
                                                 &server_request);
                                         if (rv != SOAP_OK) {
-                                                err("Set blade power to power "
-                                                    "reset failed");
+                                                err("Set power reset of blade"
+						    " %d failed", bay_number);
                                                 return SA_ERR_HPI_INTERNAL_ERROR;
                                         }
                                         return SA_OK;
