@@ -10,7 +10,7 @@
  * full licensing terms.
  *
  * Author(s):
- *        Renier Morales <renierm@users.sf.net>
+ *        Renier Morales <renier@openhpi.org>
  *        Daniel de Araujo <ddearauj@us.ibm.com>
  */
 #include <rtas_event.h> 
@@ -18,7 +18,7 @@
 SaErrorT rtas_get_event(void *hnd)
 {
         if (!hnd) {
-                dbg("Invalid parameter");
+                err("Invalid parameter");
                 return(SA_ERR_HPI_INVALID_PARAMS);
         }
 
