@@ -12,7 +12,7 @@
  * Author(s):
  *	  Christina Hernandez <hernanc@us.ibm.com>
  *        W. David Ashley <dashley@us.ibm.com>
- *	  Renier Morales <renierm@users.sourceforge.net>
+ *	  Renier Morales <renier@openhpi.org>
  */
 
 
@@ -26,6 +26,7 @@ Control Definitions
 
 struct sim_control_info {
 	SaHpiCtrlModeT mode;
+	SaHpiCtrlStateT state;
 };
 
 struct sim_control {
