@@ -202,12 +202,42 @@ SaErrorT sim_get_event(void *hnd)
 
 SaErrorT sim_close(void *hnd)
 {
-        struct oh_handler_state *state = hnd;
+    struct oh_handler_state *state = hnd;
 
-        /* TODO: we may need to do more here than just this! */
-//      g_free(state->rptcache);
-        g_free(state);
-        return 0;
+    SaHpiEntryIdT rid;
+    SaHpiRptEntryT *rpte;
+    GSList *events = 0;
+
+    rid = SAHPI_FIRST_ENTRY;
+    while ((rpte = oh_get_resource_next(state->rptcache, rid)) != 0) {
+        struct oh_event *e = g_new0(struct oh_event, 1);
+        e->hid = state->hid;
+        e->resource = *rpte;
+        e->rdrs = 0;
+        e->rdrs_to_remove = 0;
+        e->event.Source = rpte->ResourceId;
+        e->event.EventType = SAHPI_ET_RESOURCE;
+        oh_gettimeofday(&e->event.Timestamp);
+        e->event.Severity = SAHPI_MAJOR;
+        e->event.EventDataUnion.ResourceEvent.ResourceEventType = SAHPI_RESE_RESOURCE_REMOVED;
+        events = g_slist_prepend(events, e);
+
+        rid = rpte->ResourceId;
+    }
+
+    GSList *iter = events;
+    while (iter) {
+        oh_evt_queue_push(state->eventq, iter->data );
+        iter = g_slist_next(iter);
+    }
+    g_slist_free(events);
+
+    oh_el_close(state->elcache);
+    oh_flush_rpt(state->rptcache);
+    g_free(state->rptcache);
+    g_free(state);
+
+    return 0;
 }
 
 SaErrorT sim_set_resource_tag(void *hnd, SaHpiResourceIdT id, SaHpiTextBufferT *tag)
