@@ -24,6 +24,19 @@ SaErrorT snmp_bc_get_guid(struct snmp_bc_hnd *custom_handle,
 			  struct ResourceInfo *res_info_ptr);
 			  
 SaErrorT snmp_bc_extract_slot_ep(SaHpiEntityPathT *resource_ep,
-				 SaHpiEntityPathT *slot_ep);			  
+				 SaHpiEntityPathT *slot_ep);
+				 
+SaErrorT snmp_bc_extend_ep(struct oh_event *e,
+			   guint resource_index, 
+			   gchar *interposer_intalled_mask); 
+				 
+struct oh_event *snmp_bc_alloc_oh_event(void);
+
+void snmp_bc_free_oh_event(struct oh_event *e);
+
+SaErrorT snmp_bc_set_resource_add_oh_event(struct oh_event *e, 
+					struct ResourceInfo *res_info_ptr);
+
+SaErrorT snmp_bc_copy_oh_event(struct oh_event *new_event, struct oh_event *old_event);						  			  
 
 #endif
