@@ -26,12 +26,18 @@
 #include "abi.h"
 #include "annunciator.h"
 #include "area.h"
+#include "bank.h"
 #include "control.h"
+#include "dimi.h"
+#include "fumi.h"
 #include "handler.h"
 #include "inventory.h"
+#include "log.h"
 #include "resource.h"
 #include "sensor.h"
+#include "test.h"
 #include "utils.h"
+#include "watchdog.h"
 
 
 namespace TA {
@@ -73,6 +79,19 @@ static cResource * GetResource( cHandler * h, SaHpiResourceIdT rid )
     return 0;
 }
 
+static cLog * GetLog( cHandler * h, SaHpiResourceIdT rid )
+{
+    cResource * r = GetResource( h, rid );
+    if ( r ) {
+        cLog * log = r->GetLog();
+        if ( log && log->IsVisible() ) {
+            return log;
+        }
+    }
+
+    return 0;
+}
+
 static cControl * GetControl( cHandler * h,
                               SaHpiResourceIdT rid,
                               SaHpiCtrlNumT num )
@@ -134,6 +153,21 @@ static cArea * GetArea( cHandler * h,
     return 0;
 }
 
+static cWatchdog * GetWatchdog( cHandler * h,
+                                SaHpiResourceIdT rid,
+                                SaHpiWatchdogNumT num )
+{
+    cResource * r = GetResource( h, rid );
+    if ( r ) {
+        cWatchdog * wdt = r->GetWatchdog( num );
+        if ( wdt && wdt->IsVisible() ) {
+            return wdt;
+        }
+    }
+
+    return 0;
+}
+
 static cAnnunciator * GetAnnunciator( cHandler * h,
                                       SaHpiResourceIdT rid,
                                       SaHpiAnnunciatorNumT num )
@@ -149,6 +183,68 @@ static cAnnunciator * GetAnnunciator( cHandler * h,
     return 0;
 }
 
+static cDimi * GetDimi( cHandler * h,
+                        SaHpiResourceIdT rid,
+                        SaHpiDimiNumT num )
+{
+    cResource * r = GetResource( h, rid );
+    if ( r ) {
+        cDimi * dimi = r->GetDimi( num );
+        if ( dimi && dimi->IsVisible() ) {
+            return dimi;
+        }
+    }
+
+    return 0;
+}
+
+static cTest * GetTest( cHandler * h,
+                        SaHpiResourceIdT rid,
+                        SaHpiDimiNumT num,
+                        SaHpiDimiTestNumT tnum )
+{
+    cDimi * dimi = GetDimi( h, rid, num );
+    if ( dimi ) {
+        cTest * test = dimi->GetTest( tnum );
+        if ( test && test->IsVisible() ) {
+            return test;
+        }
+    }
+
+    return 0;
+}
+
+static cFumi * GetFumi( cHandler * h,
+                        SaHpiResourceIdT rid,
+                        SaHpiFumiNumT num )
+{
+    cResource * r = GetResource( h, rid );
+    if ( r ) {
+        cFumi * fumi = r->GetFumi( num );
+        if ( fumi && fumi->IsVisible() ) {
+            return fumi;
+        }
+    }
+
+    return 0;
+}
+
+static cBank * GetBank( cHandler * h,
+                        SaHpiResourceIdT rid,
+                        SaHpiFumiNumT num,
+                        SaHpiBankNumT bnum )
+{
+    cFumi * fumi = GetFumi( h, rid, num );
+    if ( fumi ) {
+        cBank * bank = fumi->GetBank( bnum );
+        if ( bank && bank->IsVisible() ) {
+            return bank;
+        }
+    }
+
+    return 0;
+}
+
 
 }; // namespace TA
 
@@ -285,7 +381,14 @@ oh_get_el_info(
     SaHpiResourceIdT rid,
     SaHpiEventLogInfoT * info )
 {
-    return SA_ERR_HPI_UNSUPPORTED_API;
+    TA::cHandler * handler = TA::GetHandler( hnd );
+    TA::cLocker<TA::cHandler> al( handler );
+    TA::cLog * log = TA::GetLog( handler, rid );
+    if ( !log ) {
+        return SA_ERR_HPI_CAPABILITY;
+    }
+
+    return log->GetInfo( *info );
 }
 
 
@@ -298,7 +401,14 @@ oh_get_el_caps(
     SaHpiResourceIdT rid,
     SaHpiEventLogCapabilitiesT * caps )
 {
-    return SA_ERR_HPI_UNSUPPORTED_API;
+    TA::cHandler * handler = TA::GetHandler( hnd );
+    TA::cLocker<TA::cHandler> al( handler );
+    TA::cLog * log = TA::GetLog( handler, rid );
+    if ( !log ) {
+        return SA_ERR_HPI_CAPABILITY;
+    }
+
+    return log->GetCapabilities( *caps );
 }
 
 
@@ -311,7 +421,14 @@ oh_set_el_time(
     SaHpiResourceIdT rid,
     SaHpiTimeT time )
 {
-    return SA_ERR_HPI_UNSUPPORTED_API;
+    TA::cHandler * handler = TA::GetHandler( hnd );
+    TA::cLocker<TA::cHandler> al( handler );
+    TA::cLog * log = TA::GetLog( handler, rid );
+    if ( !log ) {
+        return SA_ERR_HPI_CAPABILITY;
+    }
+
+    return log->SetTime( time );
 }
 
 
@@ -324,7 +441,14 @@ oh_add_el_entry(
     SaHpiResourceIdT rid,
     const SaHpiEventT * event )
 {
-    return SA_ERR_HPI_UNSUPPORTED_API;
+    TA::cHandler * handler = TA::GetHandler( hnd );
+    TA::cLocker<TA::cHandler> al( handler );
+    TA::cLog * log = TA::GetLog( handler, rid );
+    if ( !log ) {
+        return SA_ERR_HPI_CAPABILITY;
+    }
+
+    return log->AddEntry( *event );
 }
 
 
@@ -342,7 +466,14 @@ oh_get_el_entry(
     SaHpiRdrT * rdr,
     SaHpiRptEntryT * rpte )
 {
-    return SA_ERR_HPI_UNSUPPORTED_API;
+    TA::cHandler * handler = TA::GetHandler( hnd );
+    TA::cLocker<TA::cHandler> al( handler );
+    TA::cLog * log = TA::GetLog( handler, rid );
+    if ( !log ) {
+        return SA_ERR_HPI_CAPABILITY;
+    }
+
+    return log->GetEntry( current, *prev, *next, *entry, *rdr, *rpte );
 }
 
 
@@ -354,7 +485,14 @@ oh_clear_el(
     void * hnd,
     SaHpiResourceIdT rid )
 {
-    return SA_ERR_HPI_UNSUPPORTED_API;
+    TA::cHandler * handler = TA::GetHandler( hnd );
+    TA::cLocker<TA::cHandler> al( handler );
+    TA::cLog * log = TA::GetLog( handler, rid );
+    if ( !log ) {
+        return SA_ERR_HPI_CAPABILITY;
+    }
+
+    return log->Clear();
 }
 
 
@@ -367,7 +505,14 @@ oh_set_el_state(
     SaHpiResourceIdT rid,
     SaHpiBoolT e )
 {
-    return SA_ERR_HPI_UNSUPPORTED_API;
+    TA::cHandler * handler = TA::GetHandler( hnd );
+    TA::cLocker<TA::cHandler> al( handler );
+    TA::cLog * log = TA::GetLog( handler, rid );
+    if ( !log ) {
+        return SA_ERR_HPI_CAPABILITY;
+    }
+
+    return log->SetState( e );
 }
 
 
@@ -379,7 +524,14 @@ oh_reset_el_overflow(
     void * hnd,
     SaHpiResourceIdT rid )
 {
-    return SA_ERR_HPI_UNSUPPORTED_API;
+    TA::cHandler * handler = TA::GetHandler( hnd );
+    TA::cLocker<TA::cHandler> al( handler );
+    TA::cLog * log = TA::GetLog( handler, rid );
+    if ( !log ) {
+        return SA_ERR_HPI_CAPABILITY;
+    }
+
+    return log->ResetOverflow();
 }
 
 
@@ -852,7 +1004,14 @@ oh_get_watchdog_info(
     SaHpiWatchdogNumT num,
     SaHpiWatchdogT * wdt )
 {
-    return SA_ERR_HPI_UNSUPPORTED_API;
+    TA::cHandler * handler = TA::GetHandler( hnd );
+    TA::cLocker<TA::cHandler> al( handler );
+    TA::cWatchdog * w = TA::GetWatchdog( handler, rid, num );
+    if ( !w ) {
+        return SA_ERR_HPI_NOT_PRESENT;
+    }
+
+    return w->Get( *wdt );
 }
 
 
@@ -866,7 +1025,14 @@ oh_set_watchdog_info(
     SaHpiWatchdogNumT num,
     SaHpiWatchdogT * wdt )
 {
-    return SA_ERR_HPI_UNSUPPORTED_API;
+    TA::cHandler * handler = TA::GetHandler( hnd );
+    TA::cLocker<TA::cHandler> al( handler );
+    TA::cWatchdog * w = TA::GetWatchdog( handler, rid, num );
+    if ( !w ) {
+        return SA_ERR_HPI_NOT_PRESENT;
+    }
+
+    return w->Set( *wdt );
 }
 
 
@@ -879,7 +1045,14 @@ oh_reset_watchdog(
     SaHpiResourceIdT rid,
     SaHpiWatchdogNumT num )
 {
-    return SA_ERR_HPI_UNSUPPORTED_API;
+    TA::cHandler * handler = TA::GetHandler( hnd );
+    TA::cLocker<TA::cHandler> al( handler );
+    TA::cWatchdog * w = TA::GetWatchdog( handler, rid, num );
+    if ( !w ) {
+        return SA_ERR_HPI_NOT_PRESENT;
+    }
+
+    return w->Reset();
 }
 
 
@@ -1045,7 +1218,14 @@ oh_get_dimi_info(
     SaHpiDimiNumT num,
     SaHpiDimiInfoT * info )
 {
-    return SA_ERR_HPI_UNSUPPORTED_API;
+    TA::cHandler * handler = TA::GetHandler( hnd );
+    TA::cLocker<TA::cHandler> al( handler );
+    TA::cDimi * dimi = TA::GetDimi( handler, rid, num );
+    if ( !dimi ) {
+        return SA_ERR_HPI_NOT_PRESENT;
+    }
+
+    return dimi->GetInfo( *info );
 }
 
 
@@ -1060,7 +1240,14 @@ oh_get_dimi_test(
     SaHpiDimiTestNumT testnum,
     SaHpiDimiTestT * test )
 {
-    return SA_ERR_HPI_UNSUPPORTED_API;
+    TA::cHandler * handler = TA::GetHandler( hnd );
+    TA::cLocker<TA::cHandler> al( handler );
+    TA::cTest * t = TA::GetTest( handler, rid, num, testnum );
+    if ( !t ) {
+        return SA_ERR_HPI_NOT_PRESENT;
+    }
+
+    return t->GetInfo( *test );
 }
 
 
@@ -1075,7 +1262,14 @@ oh_get_dimi_test_ready(
     SaHpiDimiTestNumT testnum,
     SaHpiDimiReadyT * ready )
 {
-    return SA_ERR_HPI_UNSUPPORTED_API;
+    TA::cHandler * handler = TA::GetHandler( hnd );
+    TA::cLocker<TA::cHandler> al( handler );
+    TA::cTest * t = TA::GetTest( handler, rid, num, testnum );
+    if ( !t ) {
+        return SA_ERR_HPI_NOT_PRESENT;
+    }
+
+    return t->GetReadiness( *ready );
 }
 
 
@@ -1091,7 +1285,14 @@ oh_start_dimi_test(
     SaHpiUint8T numparams,
     SaHpiDimiTestVariableParamsT * paramslist )
 {
-    return SA_ERR_HPI_UNSUPPORTED_API;
+    TA::cHandler * handler = TA::GetHandler( hnd );
+    TA::cLocker<TA::cHandler> al( handler );
+    TA::cTest * t = TA::GetTest( handler, rid, num, testnum );
+    if ( !t ) {
+        return SA_ERR_HPI_NOT_PRESENT;
+    }
+
+    return t->Start( numparams, paramslist );
 }
 
 
@@ -1105,7 +1306,14 @@ oh_cancel_dimi_test(
     SaHpiDimiNumT num,
     SaHpiDimiTestNumT testnum )
 {
-    return SA_ERR_HPI_UNSUPPORTED_API;
+    TA::cHandler * handler = TA::GetHandler( hnd );
+    TA::cLocker<TA::cHandler> al( handler );
+    TA::cTest * t = TA::GetTest( handler, rid, num, testnum );
+    if ( !t ) {
+        return SA_ERR_HPI_NOT_PRESENT;
+    }
+
+    return t->Cancel();
 }
 
 
@@ -1121,7 +1329,14 @@ oh_get_dimi_test_status(
     SaHpiDimiTestPercentCompletedT * percentcompleted,
     SaHpiDimiTestRunStatusT * runstatus )
 {
-    return SA_ERR_HPI_UNSUPPORTED_API;
+    TA::cHandler * handler = TA::GetHandler( hnd );
+    TA::cLocker<TA::cHandler> al( handler );
+    TA::cTest * t = TA::GetTest( handler, rid, num, testnum );
+    if ( !t ) {
+        return SA_ERR_HPI_NOT_PRESENT;
+    }
+
+    return t->GetStatus( *percentcompleted, *runstatus );
 }
 
 
@@ -1136,7 +1351,14 @@ oh_get_dimi_test_results(
     SaHpiDimiTestNumT testnum,
     SaHpiDimiTestResultsT * testresults )
 {
-    return SA_ERR_HPI_UNSUPPORTED_API;
+    TA::cHandler * handler = TA::GetHandler( hnd );
+    TA::cLocker<TA::cHandler> al( handler );
+    TA::cTest * t = TA::GetTest( handler, rid, num, testnum );
+    if ( !t ) {
+        return SA_ERR_HPI_NOT_PRESENT;
+    }
+
+    return t->GetResults( *testresults );
 }
 
 
@@ -1150,7 +1372,14 @@ oh_get_fumi_spec(
     SaHpiFumiNumT num,
     SaHpiFumiSpecInfoT * specinfo  )
 {
-    return SA_ERR_HPI_UNSUPPORTED_API;
+    TA::cHandler * handler = TA::GetHandler( hnd );
+    TA::cLocker<TA::cHandler> al( handler );
+    TA::cFumi * fumi = TA::GetFumi( handler, rid, num );
+    if ( !fumi ) {
+        return SA_ERR_HPI_NOT_PRESENT;
+    }
+
+    return fumi->GetSpecInfo( *specinfo );
 }
 
 
@@ -1164,7 +1393,14 @@ oh_get_fumi_service_impact(
     SaHpiFumiNumT num,
     SaHpiFumiServiceImpactDataT * serviceimpact  )
 {
-    return SA_ERR_HPI_UNSUPPORTED_API;
+    TA::cHandler * handler = TA::GetHandler( hnd );
+    TA::cLocker<TA::cHandler> al( handler );
+    TA::cFumi * fumi = TA::GetFumi( handler, rid, num );
+    if ( !fumi ) {
+        return SA_ERR_HPI_NOT_PRESENT;
+    }
+
+    return fumi->GetServiceImpact( *serviceimpact );
 }
 
 
@@ -1179,7 +1415,14 @@ oh_set_fumi_source(
     SaHpiBankNumT banknum,
     SaHpiTextBufferT * sourceuri )
 {
-    return SA_ERR_HPI_UNSUPPORTED_API;
+    TA::cHandler * handler = TA::GetHandler( hnd );
+    TA::cLocker<TA::cHandler> al( handler );
+    TA::cBank * b = TA::GetBank( handler, rid, num, banknum );
+    if ( !b ) {
+        return SA_ERR_HPI_NOT_PRESENT;
+    }
+
+    return b->SetSource( *sourceuri );
 }
 
 
@@ -1193,7 +1436,14 @@ oh_validate_fumi_source(
     SaHpiFumiNumT num,
     SaHpiBankNumT banknum )
 {
-    return SA_ERR_HPI_UNSUPPORTED_API;
+    TA::cHandler * handler = TA::GetHandler( hnd );
+    TA::cLocker<TA::cHandler> al( handler );
+    TA::cBank * b = TA::GetBank( handler, rid, num, banknum );
+    if ( !b ) {
+        return SA_ERR_HPI_NOT_PRESENT;
+    }
+
+    return b->StartSourceValidation();
 }
 
 
@@ -1208,7 +1458,14 @@ oh_get_fumi_source(
     SaHpiBankNumT banknum,
     SaHpiFumiSourceInfoT * sourceinfo )
 {
-    return SA_ERR_HPI_UNSUPPORTED_API;
+    TA::cHandler * handler = TA::GetHandler( hnd );
+    TA::cLocker<TA::cHandler> al( handler );
+    TA::cBank * b = TA::GetBank( handler, rid, num, banknum );
+    if ( !b ) {
+        return SA_ERR_HPI_NOT_PRESENT;
+    }
+
+    return b->GetSourceInfo( *sourceinfo );
 }
 
 
@@ -1225,7 +1482,14 @@ oh_get_fumi_source_component(
     SaHpiEntryIdT * nextcompid,
     SaHpiFumiComponentInfoT * compinfo )
 {
-    return SA_ERR_HPI_UNSUPPORTED_API;
+    TA::cHandler * handler = TA::GetHandler( hnd );
+    TA::cLocker<TA::cHandler> al( handler );
+    TA::cBank * b = TA::GetBank( handler, rid, num, banknum );
+    if ( !b ) {
+        return SA_ERR_HPI_NOT_PRESENT;
+    }
+
+    return b->GetSourceComponentInfo( compid, *nextcompid, *compinfo );
 }
 
 
@@ -1240,7 +1504,14 @@ oh_get_fumi_target(
     SaHpiBankNumT banknum,
     SaHpiFumiBankInfoT * bankinfo )
 {
-    return SA_ERR_HPI_UNSUPPORTED_API;
+    TA::cHandler * handler = TA::GetHandler( hnd );
+    TA::cLocker<TA::cHandler> al( handler );
+    TA::cBank * b = TA::GetBank( handler, rid, num, banknum );
+    if ( !b ) {
+        return SA_ERR_HPI_NOT_PRESENT;
+    }
+
+    return b->GetTargetInfo( *bankinfo );
 }
 
 
@@ -1257,7 +1528,14 @@ oh_get_fumi_target_component(
     SaHpiEntryIdT * nextcompid,
     SaHpiFumiComponentInfoT * compinfo )
 {
-    return SA_ERR_HPI_UNSUPPORTED_API;
+    TA::cHandler * handler = TA::GetHandler( hnd );
+    TA::cLocker<TA::cHandler> al( handler );
+    TA::cBank * b = TA::GetBank( handler, rid, num, banknum );
+    if ( !b ) {
+        return SA_ERR_HPI_NOT_PRESENT;
+    }
+
+    return b->GetTargetComponentInfo( compid, *nextcompid, *compinfo );
 }
 
 
@@ -1271,7 +1549,14 @@ oh_get_fumi_logical_target(
     SaHpiFumiNumT num,
     SaHpiFumiLogicalBankInfoT * bankinfo )
 {
-    return SA_ERR_HPI_UNSUPPORTED_API;
+    TA::cHandler * handler = TA::GetHandler( hnd );
+    TA::cLocker<TA::cHandler> al( handler );
+    TA::cBank * b = TA::GetBank( handler, rid, num, 0 );
+    if ( !b ) {
+        return SA_ERR_HPI_NOT_PRESENT;
+    }
+
+    return b->GetLogicalTargetInfo( *bankinfo );
 }
 
 
@@ -1287,7 +1572,14 @@ oh_get_fumi_logical_target_component(
     SaHpiEntryIdT * nextcompid,
     SaHpiFumiLogicalComponentInfoT * compinfo )
 {
-    return SA_ERR_HPI_UNSUPPORTED_API;
+    TA::cHandler * handler = TA::GetHandler( hnd );
+    TA::cLocker<TA::cHandler> al( handler );
+    TA::cBank * b = TA::GetBank( handler, rid, num, 0 );
+    if ( !b ) {
+        return SA_ERR_HPI_NOT_PRESENT;
+    }
+
+    return b->GetLogicalTargetComponentInfo( compid, *nextcompid, *compinfo );
 }
 
 
@@ -1300,7 +1592,14 @@ oh_start_fumi_backup(
     SaHpiResourceIdT rid,
     SaHpiFumiNumT num )
 {
-    return SA_ERR_HPI_UNSUPPORTED_API;
+    TA::cHandler * handler = TA::GetHandler( hnd );
+    TA::cLocker<TA::cHandler> al( handler );
+    TA::cBank * b = TA::GetBank( handler, rid, num, 0 );
+    if ( !b ) {
+        return SA_ERR_HPI_NOT_PRESENT;
+    }
+
+    return b->StartBackup();
 }
 
 
@@ -1315,7 +1614,14 @@ oh_set_fumi_bank_order(
     SaHpiBankNumT banknum,
     SaHpiUint32T position )
 {
-    return SA_ERR_HPI_UNSUPPORTED_API;
+    TA::cHandler * handler = TA::GetHandler( hnd );
+    TA::cLocker<TA::cHandler> al( handler );
+    TA::cFumi * fumi = TA::GetFumi( handler, rid, num );
+    if ( !fumi ) {
+        return SA_ERR_HPI_NOT_PRESENT;
+    }
+
+    return fumi->SetBootOrder( banknum, position );
 }
 
 
@@ -1330,7 +1636,14 @@ oh_start_fumi_bank_copy(
     SaHpiBankNumT sourcebanknum,
     SaHpiBankNumT targetbanknum )
 {
-    return SA_ERR_HPI_UNSUPPORTED_API;
+    TA::cHandler * handler = TA::GetHandler( hnd );
+    TA::cLocker<TA::cHandler> al( handler );
+    TA::cBank * b = TA::GetBank( handler, rid, num, sourcebanknum );
+    if ( !b ) {
+        return SA_ERR_HPI_NOT_PRESENT;
+    }
+
+    return b->StartCopy( targetbanknum );
 }
 
 
@@ -1344,7 +1657,14 @@ oh_start_fumi_install(
     SaHpiFumiNumT num,
     SaHpiBankNumT banknum )
 {
-    return SA_ERR_HPI_UNSUPPORTED_API;
+    TA::cHandler * handler = TA::GetHandler( hnd );
+    TA::cLocker<TA::cHandler> al( handler );
+    TA::cBank * b = TA::GetBank( handler, rid, num, banknum );
+    if ( !b ) {
+        return SA_ERR_HPI_NOT_PRESENT;
+    }
+
+    return b->StartInstallation();
 }
 
 
@@ -1359,7 +1679,14 @@ oh_get_fumi_status(
     SaHpiBankNumT banknum,
     SaHpiFumiUpgradeStatusT * status )
 {
-    return SA_ERR_HPI_UNSUPPORTED_API;
+    TA::cHandler * handler = TA::GetHandler( hnd );
+    TA::cLocker<TA::cHandler> al( handler );
+    TA::cBank * b = TA::GetBank( handler, rid, num, banknum );
+    if ( !b ) {
+        return SA_ERR_HPI_NOT_PRESENT;
+    }
+
+    return b->GetUpgradeStatus( *status );
 }
 
 
@@ -1373,7 +1700,14 @@ oh_start_fumi_verify(
     SaHpiFumiNumT num,
     SaHpiBankNumT banknum )
 {
-    return SA_ERR_HPI_UNSUPPORTED_API;
+    TA::cHandler * handler = TA::GetHandler( hnd );
+    TA::cLocker<TA::cHandler> al( handler );
+    TA::cBank * b = TA::GetBank( handler, rid, num, banknum );
+    if ( !b ) {
+        return SA_ERR_HPI_NOT_PRESENT;
+    }
+
+    return b->StartTargetVerification();
 }
 
 
@@ -1386,7 +1720,14 @@ oh_start_fumi_verify_main(
     SaHpiResourceIdT rid,
     SaHpiFumiNumT num  )
 {
-    return SA_ERR_HPI_UNSUPPORTED_API;
+    TA::cHandler * handler = TA::GetHandler( hnd );
+    TA::cLocker<TA::cHandler> al( handler );
+    TA::cBank * b = TA::GetBank( handler, rid, num, 0 );
+    if ( !b ) {
+        return SA_ERR_HPI_NOT_PRESENT;
+    }
+
+    return b->StartTargetMainVerification();
 }
 
 
@@ -1400,7 +1741,14 @@ oh_cancel_fumi_upgrade(
     SaHpiFumiNumT num,
     SaHpiBankNumT banknum )
 {
-    return SA_ERR_HPI_UNSUPPORTED_API;
+    TA::cHandler * handler = TA::GetHandler( hnd );
+    TA::cLocker<TA::cHandler> al( handler );
+    TA::cBank * b = TA::GetBank( handler, rid, num, banknum );
+    if ( !b ) {
+        return SA_ERR_HPI_NOT_PRESENT;
+    }
+
+    return b->CancelUpgrade();
 }
 
 
@@ -1414,7 +1762,14 @@ oh_get_fumi_autorollback_disable(
     SaHpiFumiNumT num,
     SaHpiBoolT * disable )
 {
-    return SA_ERR_HPI_UNSUPPORTED_API;
+    TA::cHandler * handler = TA::GetHandler( hnd );
+    TA::cLocker<TA::cHandler> al( handler );
+    TA::cFumi * fumi = TA::GetFumi( handler, rid, num );
+    if ( !fumi ) {
+        return SA_ERR_HPI_NOT_PRESENT;
+    }
+
+    return fumi->GetAutoRollbackDisabled( *disable );
 }
 
 
@@ -1428,7 +1783,14 @@ oh_set_fumi_autorollback_disable(
     SaHpiFumiNumT num,
     SaHpiBoolT disable )
 {
-    return SA_ERR_HPI_UNSUPPORTED_API;
+    TA::cHandler * handler = TA::GetHandler( hnd );
+    TA::cLocker<TA::cHandler> al( handler );
+    TA::cFumi * fumi = TA::GetFumi( handler, rid, num );
+    if ( !fumi ) {
+        return SA_ERR_HPI_NOT_PRESENT;
+    }
+
+    return fumi->SetAutoRollbackDisabled( disable );
 }
 
 
@@ -1441,7 +1803,14 @@ oh_start_fumi_rollback(
     SaHpiResourceIdT rid,
     SaHpiFumiNumT num )
 {
-    return SA_ERR_HPI_UNSUPPORTED_API;
+    TA::cHandler * handler = TA::GetHandler( hnd );
+    TA::cLocker<TA::cHandler> al( handler );
+    TA::cBank * b = TA::GetBank( handler, rid, num, 0 );
+    if ( !b ) {
+        return SA_ERR_HPI_NOT_PRESENT;
+    }
+
+    return b->StartRollback();
 }
 
 
@@ -1468,7 +1837,14 @@ oh_start_fumi_activate(
     SaHpiFumiNumT num,
     SaHpiBoolT logical )
 {
-    return SA_ERR_HPI_UNSUPPORTED_API;
+    TA::cHandler * handler = TA::GetHandler( hnd );
+    TA::cLocker<TA::cHandler> al( handler );
+    TA::cFumi * fumi = TA::GetFumi( handler, rid, num );
+    if ( !fumi ) {
+        return SA_ERR_HPI_NOT_PRESENT;
+    }
+
+    return fumi->StartActivation( logical );
 }
 
 
@@ -1482,7 +1858,14 @@ oh_cleanup_fumi(
     SaHpiFumiNumT num,
     SaHpiBankNumT banknum )
 {
-    return SA_ERR_HPI_UNSUPPORTED_API;
+    TA::cHandler * handler = TA::GetHandler( hnd );
+    TA::cLocker<TA::cHandler> al( handler );
+    TA::cBank * b = TA::GetBank( handler, rid, num, banknum );
+    if ( !b ) {
+        return SA_ERR_HPI_NOT_PRESENT;
+    }
+
+    return b->Cleanup();
 }
 
 
