@@ -17,6 +17,7 @@
 #define DIMI_H_FB2B5DD5_4E7D_49F5_9397_C2FEC21B4010
 
 #include <string>
+#include <vector>
 
 #include <SaHpi.h>
 
@@ -29,20 +30,35 @@ namespace TA {
 /**************************************************************
  * class cDimi
  *************************************************************/
+class cTest;
+
 class cDimi : public cInstrument
 {
 public:
 
     static const std::string classname;
 
-    explicit cDimi( cResource& resource, SaHpiDimiNumT num );
+    explicit cDimi( cHandler& handler, cResource& resource, SaHpiDimiNumT num );
     virtual ~cDimi();
 
+public:
+
+    cTest * GetTest( SaHpiDimiTestNumT tnum ) const;
+    void PostEvent( SaHpiDimiTestNumT tnum,
+                    SaHpiDimiTestRunStatusT status,
+                    SaHpiDimiTestPercentCompletedT progress );
+
 public:  // HPI interface
 
+    SaErrorT GetInfo( SaHpiDimiInfoT& info ) const;
+
 protected: // cObject virtual functions
 
-    virtual void GetVars( cVars& vars );
+    virtual void GetNB( std::string& nb ) const;
+    virtual void GetNewNames( cObject::NewNames& names ) const;
+    virtual bool CreateChild( const std::string& name );
+    virtual bool RemoveChild( const std::string& name );
+    virtual void GetChildren( cObject::Children& children ) const;
 
 private:
 
@@ -56,9 +72,13 @@ private:
         return SAHPI_CAPABILITY_DIMI;
     }
 
+    void Update();
+
 private: // data
 
     const SaHpiDimiRecT& m_rec;
+    std::vector<cTest*> m_tests;
+    SaHpiUint32T m_update_count;
 };
 
 
