@@ -13,6 +13,9 @@
  *        Anton Pak <anton.pak@pigeonpoint.com>
  */
 
+#include <stddef.h>
+#include <stdio.h>
+
 #include "structs.h"
 #include "vars.h"
 
@@ -99,6 +102,48 @@ void GetVars( SaHpiRptEntryT& rpte, cVars& vars )
          << VAR_END();
 }
 
+void GetVars( SaHpiEventLogInfoT& info, cVars& vars )
+{
+    vars << "Info.Entries"
+         << dtSaHpiUint32T
+         << DATA( info.Entries )
+         << READONLY()
+         << VAR_END();
+    vars << "Info.Size"
+         << dtSaHpiUint32T
+         << DATA( info.Size )
+         << VAR_END();
+    vars << "Info.UserEventMaxSize"
+         << dtSaHpiUint32T
+         << DATA( info.UserEventMaxSize )
+         << VAR_END();
+    vars << "Info.UpdateTimestamp"
+         << dtSaHpiTimeT
+         << DATA( info.UpdateTimestamp )
+         << READONLY()
+         << VAR_END();
+    vars << "Info.CurrentTime"
+         << dtSaHpiTimeT
+         << DATA( info.CurrentTime )
+         << VAR_END();
+    vars << "Info.Enabled"
+         << dtSaHpiBoolT
+         << DATA( info.Enabled )
+         << VAR_END();
+    vars << "Info.OverflowFlag"
+         << dtSaHpiBoolT
+         << DATA( info.OverflowFlag )
+         << VAR_END();
+    vars << "Info.OverflowResetable"
+         << dtSaHpiBoolT
+         << DATA( info.OverflowResetable )
+         << VAR_END();
+    vars << "Info.OverflowAction"
+         << dtSaHpiEventLogOverflowActionT
+         << DATA( info.OverflowAction )
+         << VAR_END();
+}
+
 void GetVars( SaHpiLoadIdT& load_id, cVars& vars )
 {
     vars << "LoadId.LoadNumber"
@@ -442,6 +487,7 @@ static void GetVars( SaHpiFumiRecT& rec, cVars& vars )
     vars << "Rdr.FumiRec.NumBanks"
          << dtSaHpiUint8T
          << DATA( rec.NumBanks )
+         << READONLY()
          << VAR_END();
     vars << "Rdr.FumiRec.Oem"
          << dtSaHpiUint32T
@@ -606,26 +652,32 @@ void GetVars( SaHpiWatchdogT& wd, cVars& vars )
     vars << "Watchdog.Log"
          << dtSaHpiBoolT
          << DATA( wd.Log )
+         << READONLY()
          << VAR_END();
     vars << "Watchdog.Running"
          << dtSaHpiBoolT
          << DATA( wd.Running )
+         << READONLY()
          << VAR_END();
     vars << "Watchdog.TimerUse"
          << dtSaHpiWatchdogTimerUseT
          << DATA( wd.TimerUse )
+         << READONLY()
          << VAR_END();
     vars << "Watchdog.TimerAction"
          << dtSaHpiWatchdogActionT
          << DATA( wd.TimerAction )
+         << READONLY()
          << VAR_END();
     vars << "Watchdog.PretimerInterrupt"
          << dtSaHpiWatchdogPretimerInterruptT
          << DATA( wd.PretimerInterrupt )
+         << READONLY()
          << VAR_END();
     vars << "Watchdog.PreTimeoutInterval"
          << dtSaHpiUint32T
          << DATA( wd.PreTimeoutInterval )
+         << READONLY()
          << VAR_END();
     vars << "Watchdog.TimerUseExpFlags"
          << dtSaHpiWatchdogExpFlagsT
@@ -634,10 +686,12 @@ void GetVars( SaHpiWatchdogT& wd, cVars& vars )
     vars << "Watchdog.InitialCount"
          << dtSaHpiUint32T
          << DATA( wd.InitialCount )
+         << READONLY()
          << VAR_END();
     vars << "Watchdog.PresentCount"
          << dtSaHpiUint32T
          << DATA( wd.PresentCount )
+         << READONLY()
          << VAR_END();
 }
 
@@ -709,6 +763,326 @@ void GetVars( SaHpiAnnouncementT& a, cVars& vars )
          << VAR_END();
 }
 
+static void GetVars( const std::string& name,
+                     SaHpiDimiTestParamsDefinitionT& pd,
+                     cVars& vars )
+{
+    vars << name + ".ParamName"
+         << dtDimiTestParamName
+         << DATA( pd.ParamName )
+         << VAR_END();
+    vars << name + ".ParamInfo"
+         << dtSaHpiTextBufferT
+         << DATA( pd.ParamInfo )
+         << VAR_END();
+    vars << name + ".ParamType"
+         << dtSaHpiDimiTestParamTypeT
+         << DATA( pd.ParamType )
+         << VAR_END();
+    if ( pd.ParamType == SAHPI_DIMITEST_PARAM_TYPE_INT32 ) {
+        vars << name + ".MinValue.IntValue"
+             << dtSaHpiInt32T
+             << DATA( pd.MinValue.IntValue )
+             << VAR_END();
+        vars << name + ".MaxValue.IntValue"
+             << dtSaHpiInt32T
+             << DATA( pd.MaxValue.IntValue )
+             << VAR_END();
+    } else if ( pd.ParamType == SAHPI_DIMITEST_PARAM_TYPE_FLOAT64 ) {
+        vars << name + ".MinValue.FloatValue"
+             << dtSaHpiFloat64T
+             << DATA( pd.MinValue.FloatValue )
+             << VAR_END();
+        vars << name + ".MaxValue.FloatValue"
+             << dtSaHpiFloat64T
+             << DATA( pd.MaxValue.FloatValue )
+             << VAR_END();
+    }
+    if ( pd.ParamType == SAHPI_DIMITEST_PARAM_TYPE_BOOLEAN ) {
+        vars << name + ".DefaultParam.parambool"
+             << dtSaHpiBoolT
+             << DATA( pd.DefaultParam.parambool )
+             << VAR_END();
+    } else if ( pd.ParamType == SAHPI_DIMITEST_PARAM_TYPE_INT32 ) {
+        vars << name + ".DefaultParam.paramint"
+             << dtSaHpiInt32T
+             << DATA( pd.DefaultParam.paramint )
+             << VAR_END();
+    } else if ( pd.ParamType == SAHPI_DIMITEST_PARAM_TYPE_FLOAT64 ) {
+        vars << name + ".DefaultParam.paramfloat"
+             << dtSaHpiFloat64T
+             << DATA( pd.DefaultParam.paramfloat )
+             << VAR_END();
+    } else if ( pd.ParamType == SAHPI_DIMITEST_PARAM_TYPE_TEXT ) {
+        vars << name + ".DefaultParam.paramtext"
+             << dtSaHpiTextBufferT
+             << DATA( pd.DefaultParam.paramtext )
+             << VAR_END();
+    }
+}
+
+void GetVars( SaHpiDimiTestT& info, cVars& vars )
+{
+    char prefix[256];
+
+    vars << "TestInfo.TestName"
+         << dtSaHpiTextBufferT
+         << DATA( info.TestName )
+         << VAR_END();
+    vars << "TestInfo.ServiceImpact"
+         << dtSaHpiDimiTestServiceImpactT
+         << DATA( info.ServiceImpact )
+         << VAR_END();
+    for ( size_t i = 0; i < SAHPI_DIMITEST_MAX_ENTITIESIMPACTED; ++i ) {
+        snprintf( &prefix[0], sizeof(prefix), "TestInfo.EntitiesImpacted[%u]", (unsigned int)i );
+        vars << std::string( prefix ) + ".EntityImpacted"
+             << dtSaHpiEntityPathT
+             << DATA( info.EntitiesImpacted[i].EntityImpacted )
+             << VAR_END();
+        vars << std::string( prefix ) + ".ServiceImpact"
+             << dtSaHpiDimiTestServiceImpactT
+             << DATA( info.EntitiesImpacted[i].ServiceImpact )
+             << VAR_END();
+    }
+    vars << "TestInfo.NeedServiceOS"
+         << dtSaHpiBoolT
+         << DATA( info.NeedServiceOS )
+         << VAR_END();
+    vars << "TestInfo.ServiceOS"
+         << dtSaHpiTextBufferT
+         << DATA( info.ServiceOS )
+         << VAR_END();
+    vars << "TestInfo.ExpectedRunDuration"
+         << dtSaHpiTimeT
+         << DATA( info.ExpectedRunDuration )
+         << VAR_END();
+    vars << "TestInfo.TestCapabilities"
+         << dtSaHpiDimiTestCapabilityT
+         << DATA( info.TestCapabilities )
+         << VAR_END();
+    for ( size_t i = 0; i < SAHPI_DIMITEST_MAX_PARAMETERS; ++i ) {
+        snprintf( &prefix[0], sizeof(prefix), "TestInfo.TestParameters[%u]", (unsigned int)i );
+        GetVars( prefix, info.TestParameters[i], vars );
+    }
+}
+
+void GetVars( SaHpiFumiSpecInfoT& info, cVars& vars )
+{
+    vars << "SpecInfo.SpecInfoType"
+         << dtSaHpiFumiSpecInfoTypeT
+         << DATA( info.SpecInfoType )
+         << VAR_END();
+
+    vars << IF( info.SpecInfoType == SAHPI_FUMI_SPEC_INFO_SAF_DEFINED )
+         << "SpecInfo.SafDefined.SpecID"
+         << dtSaHpiFumiSafDefinedSpecIdT
+         << DATA( info.SpecInfoTypeUnion.SafDefined.SpecID )
+         << VAR_END();
+    vars << IF( info.SpecInfoType == SAHPI_FUMI_SPEC_INFO_SAF_DEFINED )
+         << "SpecInfo.SafDefined.RevisionID"
+         << dtSaHpiUint32T
+         << DATA( info.SpecInfoTypeUnion.SafDefined.RevisionID )
+         << VAR_END();
+
+    vars << IF( info.SpecInfoType == SAHPI_FUMI_SPEC_INFO_OEM_DEFINED )
+         << "SpecInfo.OemDefined.Mid"
+         << dtSaHpiManufacturerIdT
+         << DATA( info.SpecInfoTypeUnion.OemDefined.Mid )
+         << VAR_END();
+    vars << IF( info.SpecInfoType == SAHPI_FUMI_SPEC_INFO_OEM_DEFINED )
+         << "SpecInfo.OemDefined.Body"
+         << dtSaHpiFumiOemDefinedSpecInfoTWithoutMid
+         << DATA( info.SpecInfoTypeUnion.OemDefined )
+         << VAR_END();
+}
+
+void GetVars( SaHpiFumiServiceImpactDataT& data, cVars& vars )
+{
+    char prefix[256];
+
+    vars << "ServiceImpact.NumEntities"
+         << dtSaHpiUint32T
+         << DATA( data.NumEntities )
+         << VAR_END();
+
+    for ( size_t i = 0; i < data.NumEntities; ++i ) {
+        snprintf( &prefix[0], sizeof(prefix), "ServiceImpact.ImpactedEntities[%u]", (unsigned int)i );
+        vars << std::string( prefix ) + ".ImpactedEntity"
+             << dtSaHpiEntityPathT
+             << DATA( data.ImpactedEntities[i].ImpactedEntity )
+             << VAR_END();
+        vars << std::string( prefix ) + ".ServiceImpact"
+             << dtSaHpiFumiServiceImpactT
+             << DATA( data.ImpactedEntities[i].ServiceImpact )
+             << VAR_END();
+    }
+}
+
+void GetVars( SaHpiFumiBankInfoT& info, cVars& vars )
+{
+    vars << "BankInfo.BankId"
+         << dtSaHpiUint8T
+         << DATA( info.BankId )
+         << READONLY()
+         << VAR_END();
+    vars << "BankInfo.BankSize"
+         << dtSaHpiUint32T
+         << DATA( info.BankSize )
+         << VAR_END();
+    vars << "BankInfo.Position"
+         << dtSaHpiUint32T
+         << DATA( info.Position )
+         << READONLY()
+         << VAR_END();
+    vars << "BankInfo.BankState"
+         << dtSaHpiFumiBankStateT
+         << DATA( info.BankState )
+         << VAR_END();
+    vars << "BankInfo.Identifier"
+         << dtSaHpiTextBufferT
+         << DATA( info.Identifier )
+         << VAR_END();
+    vars << "BankInfo.Description"
+         << dtSaHpiTextBufferT
+         << DATA( info.Description )
+         << VAR_END();
+    vars << "BankInfo.DateTime"
+         << dtSaHpiTextBufferT
+         << DATA( info.DateTime )
+         << VAR_END();
+    vars << "BankInfo.MajorVersion"
+         << dtSaHpiUint32T
+         << DATA( info.MajorVersion )
+         << VAR_END();
+    vars << "BankInfo.MinorVersion"
+         << dtSaHpiUint32T
+         << DATA( info.MinorVersion )
+         << VAR_END();
+    vars << "BankInfo.AuxVersion"
+         << dtSaHpiUint32T
+         << DATA( info.AuxVersion )
+         << VAR_END();
+}
+
+void GetVars( const std::string& name, SaHpiFumiSourceInfoT& info, bool uri_and_status, cVars& vars )
+{
+    // This function does provide Source URI and Status.
+    vars << IF( uri_and_status )
+         << name + ".SourceUri"
+         << dtSaHpiTextBufferT
+         << DATA( info.SourceUri )
+         << VAR_END();
+    vars << IF( uri_and_status )
+         << name + ".SourceStatus"
+         << dtSaHpiFumiSourceStatusT
+         << DATA( info.SourceStatus )
+         << VAR_END();
+    vars << name + ".Identifier"
+         << dtSaHpiTextBufferT
+         << DATA( info.Identifier )
+         << VAR_END();
+    vars << name + ".Description"
+         << dtSaHpiTextBufferT
+         << DATA( info.Description )
+         << VAR_END();
+    vars << name + ".DateTime"
+         << dtSaHpiTextBufferT
+         << DATA( info.DateTime )
+         << VAR_END();
+    vars << name + ".MajorVersion"
+         << dtSaHpiUint32T
+         << DATA( info.MajorVersion )
+         << VAR_END();
+    vars << name + ".MinorVersion"
+         << dtSaHpiUint32T
+         << DATA( info.MinorVersion )
+         << VAR_END();
+    vars << name + ".AuxVersion"
+         << dtSaHpiUint32T
+         << DATA( info.AuxVersion )
+         << VAR_END();
+}
+
+static void GetVars( const std::string& name, SaHpiFumiFirmwareInstanceInfoT& info, cVars& vars )
+{
+    vars << name + ".InstancePresent"
+         << dtSaHpiBoolT
+         << DATA( info.InstancePresent )
+         << VAR_END();
+    vars << IF( info.InstancePresent != SAHPI_FALSE )
+         << name + ".Identifier"
+         << dtSaHpiTextBufferT
+         << DATA( info.Identifier )
+         << VAR_END();
+    vars << IF( info.InstancePresent != SAHPI_FALSE )
+         << name + ".Description"
+         << dtSaHpiTextBufferT
+         << DATA( info.Description )
+         << VAR_END();
+    vars << IF( info.InstancePresent != SAHPI_FALSE )
+         << name + ".DateTime"
+         << dtSaHpiTextBufferT
+         << DATA( info.DateTime )
+         << VAR_END();
+    vars << IF( info.InstancePresent != SAHPI_FALSE )
+         << name + ".MajorVersion"
+         << dtSaHpiUint32T
+         << DATA( info.MajorVersion )
+         << VAR_END();
+    vars << IF( info.InstancePresent != SAHPI_FALSE )
+         << name + ".MinorVersion"
+         << dtSaHpiUint32T
+         << DATA( info.MinorVersion )
+         << VAR_END();
+    vars << IF( info.InstancePresent != SAHPI_FALSE )
+         << name + ".AuxVersion"
+         << dtSaHpiUint32T
+         << DATA( info.AuxVersion )
+         << VAR_END();
+}
+
+void GetVars( const std::string& name, SaHpiFumiComponentInfoT& info, cVars& vars )
+{
+    GetVars( name + ".MainFwInstance", info.MainFwInstance, vars );
+
+    vars << name + ".ComponentFlags"
+         << dtSaHpiUint32T
+         << DATA( info.ComponentFlags )
+         << VAR_END();
+}
+
+void GetVars( SaHpiFumiLogicalBankInfoT& info, cVars& vars )
+{
+    vars << "LogicalBankInfo.FirmwarePersistentLocationCount"
+         << dtSaHpiUint8T
+         << DATA( info.FirmwarePersistentLocationCount )
+         << VAR_END();
+    vars << "LogicalBankInfo.BankStateFlags"
+         << dtSaHpiFumiLogicalBankStateFlagsT
+         << DATA( info.BankStateFlags )
+         << VAR_END();
+
+    // Do not show pending/rollback fw info
+/*
+    GetVars( "LogicalBankInfo.PendingFwInstance", info.PendingFwInstance, vars );
+    GetVars( "LogicalBankInfo.RollbackFwInstance", info.RollbackFwInstance, vars );
+*/
+}
+
+void GetVars( const std::string& name, SaHpiFumiLogicalComponentInfoT& info, cVars& vars )
+{
+    // Do not show pending/rollback fw info
+/*
+    GetVars( name + ".PendingFwInstance", info.PendingFwInstance, vars );
+    GetVars( name + ".RollbackFwInstance", info.RollbackFwInstance, vars );
+*/
+
+    vars << name + ".ComponentFlags"
+         << dtSaHpiUint32T
+         << DATA( info.ComponentFlags )
+         << VAR_END();
+}
+
 
 }; // namespace Structs
 
