@@ -32,6 +32,7 @@ namespace Structs {
  * Helpers to get vars from common HPI structures
  *************************************************************/
 void GetVars( SaHpiRptEntryT& rpte, cVars& vars );
+void GetVars( SaHpiEventLogInfoT& info, cVars& vars );
 void GetVars( SaHpiLoadIdT& load_id, cVars& vars );
 void GetVars( SaHpiRdrT& rdr, cVars& vars );
 void GetVars( SaHpiCtrlStateT& state, cVars& vars );
@@ -39,6 +40,14 @@ void GetVars( const std::string& name, SaHpiSensorReadingT& r, cVars& vars );
 void GetVars( SaHpiSensorThresholdsT& ths, cVars& vars );
 void GetVars( SaHpiWatchdogT& wd, cVars& vars );
 void GetVars( SaHpiAnnouncementT& a, cVars& vars );
+void GetVars( SaHpiDimiTestT& info, cVars& vars );
+void GetVars( SaHpiFumiSpecInfoT& info, cVars& vars );
+void GetVars( SaHpiFumiServiceImpactDataT& data, cVars& vars );
+void GetVars( SaHpiFumiBankInfoT& info, cVars& vars );
+void GetVars( const std::string& name, SaHpiFumiSourceInfoT& info, bool uri_and_status, cVars& vars );
+void GetVars( const std::string& name, SaHpiFumiComponentInfoT& info, cVars& vars );
+void GetVars( SaHpiFumiLogicalBankInfoT& info, cVars& vars );
+void GetVars( const std::string& name, SaHpiFumiLogicalComponentInfoT& info, cVars& vars );
 
 
 }; // namespace Structs
