@@ -18,9 +18,11 @@
 #define __OH_UTILS_H
 
 /* Order is important */
+#include <SaHpiXtca.h>
 #include <SaHpiAtca.h>
 #include <announcement_utils.h>
 #include <el_utils.h>
+#include <event_utils.h>
 #include <sahpi_struct_utils.h>
 #include <epath_utils.h>
 #include <rpt_utils.h>
@@ -28,7 +30,9 @@
 #include <sahpi_event_encode.h>
 #include <sahpi_event_utils.h>
 #include <sahpi_time_utils.h>
+#include <sahpixtca_enum_utils.h>
 #include <sahpiatca_enum_utils.h>
 #include <uid_utils.h>
+#include <sahpi_gcrypt_utils.h>
 
 #endif
