@@ -14,7 +14,6 @@
  */
 
 #include <string.h>
-#include <sys/time.h>
 
 #include <oh_utils.h>
 #include <oh_error.h>
@@ -23,6 +22,7 @@ typedef struct {
         SaHpiRptEntryT rpt_entry;
         int owndata;
         void *data; /* private data for the owner of the RPTable */
+        SaHpiUint32T update_count; /* RDR Update counter */
         GSList *rdrlist; /* Contains RDRecords for sequence lookups */
         GHashTable *rdrtable; /* Contains RDRecords for fast RecordId lookups */
 } RPTEntry;
@@ -40,12 +40,11 @@ static RPTEntry *get_rptentry_by_rid(RPTable *table, SaHpiResourceIdT rid)
         RPTEntry *rptentry = NULL;
 
         if (!table) {
-                err("ERROR: Cannot work on a null table pointer.");
                 return NULL;
         }
 
         if (!(table->rptlist)) {
-                /*dbg("Info: RPT is empty.");*/
+                /*DBG("Info: RPT is empty.");*/
                 return NULL;
         }
 
@@ -64,12 +63,11 @@ static GSList *get_rptnode_by_rid(RPTable *table, SaHpiResourceIdT rid)
         GSList *rptnode = NULL;
 
         if (!table) {
-                err("ERROR: Cannot work on a null table pointer.");
                 return NULL;
         }
 
         if (!(table->rptlist)) {
-                /*dbg("Info: RPT is empty.");*/
+                /*DBG("Info: RPT is empty.");*/
                 return NULL;
         }
 
@@ -88,12 +86,11 @@ static RDRecord *get_rdrecord_by_id(RPTEntry *rptentry, SaHpiEntryIdT id)
         RDRecord *rdrecord = NULL;
 
         if (!rptentry) {
-                err("ERROR: Cannot lookup rdr inside null resource.");
                 return NULL;
         }
 
         if (!rptentry->rdrlist) {
-                /*dbg("Info: RDR repository is empty.");*/
+                /*DBG("Info: RDR repository is empty.");*/
                 return NULL;
         }
 
@@ -112,12 +109,11 @@ static GSList *get_rdrnode_by_id(RPTEntry *rptentry, SaHpiEntryIdT id)
         GSList *rdrnode = NULL;
 
         if (!rptentry) {
-                err("ERROR: Cannot lookup rdr inside null resource.");
                 return NULL;
         }
 
         if (!rptentry->rdrlist) {
-                /*dbg("Info: RPT is empty.");*/
+                /*DBG("Info: RPT is empty.");*/
                 return NULL;
         }
 
@@ -158,52 +154,11 @@ static int check_instrument_id(SaHpiRptEntryT *rptentry, SaHpiRdrT *rdr)
         return result;
 }
 
-static SaHpiInstrumentIdT get_rdr_type_num(SaHpiRdrT *rdr)
-{
-        SaHpiInstrumentIdT num = 0;
-
-        switch (rdr->RdrType) {
-                case SAHPI_CTRL_RDR:
-                        num = rdr->RdrTypeUnion.CtrlRec.Num;
-                        break;
-                case SAHPI_SENSOR_RDR:
-                        num = rdr->RdrTypeUnion.SensorRec.Num;
-                        break;
-                case SAHPI_INVENTORY_RDR:
-                        num = rdr->RdrTypeUnion.InventoryRec.IdrId;
-                        break;
-                case SAHPI_WATCHDOG_RDR:
-                        num = rdr->RdrTypeUnion.WatchdogRec.WatchdogNum;
-                        break;
-                case SAHPI_ANNUNCIATOR_RDR:
-                        num = rdr->RdrTypeUnion.AnnunciatorRec.AnnunciatorNum;
-                        break;
-		case SAHPI_DIMI_RDR:
-			num = rdr->RdrTypeUnion.DimiRec.DimiNum;
-			break;
-		case SAHPI_FUMI_RDR:
-			num = rdr->RdrTypeUnion.FumiRec.Num;
-			break;
-                default:
-                        num = 0;
-        }
-
-        return num;
-}
-
 static void update_rptable(RPTable *table) {
-        struct timeval tv;
-        SaHpiTimeT time;
-
         if (!table) {
-                err("ERROR: Cannot work on a null table pointer.");
                 return;
         }
-
-        gettimeofday(&tv, NULL);
-        time = (SaHpiTimeT) tv.tv_sec * 1000000000 + tv.tv_usec * 1000;
-
-        table->update_timestamp = time;
+        oh_gettimeofday(&table->update_timestamp);
         table->update_count++;
 }
 
@@ -230,6 +185,48 @@ SaHpiInstrumentIdT oh_get_rdr_num(SaHpiEntryIdT rdrid) {
         return rdrid & 0x0000ffff;
 }
 
+/**
+ * oh_get_instrument_id
+ * @rdr: RDR
+ *
+ * Helper function to derive the Instrument Id of the rdr
+ *
+ * Returns: an instrument id or zero
+ */
+SaHpiInstrumentIdT oh_get_instrument_id(const SaHpiRdrT *rdr)
+{
+        SaHpiInstrumentIdT num = 0;
+
+        switch (rdr->RdrType) {
+                case SAHPI_CTRL_RDR:
+                        num = rdr->RdrTypeUnion.CtrlRec.Num;
+                        break;
+                case SAHPI_SENSOR_RDR:
+                        num = rdr->RdrTypeUnion.SensorRec.Num;
+                        break;
+                case SAHPI_INVENTORY_RDR:
+                        num = rdr->RdrTypeUnion.InventoryRec.IdrId;
+                        break;
+                case SAHPI_WATCHDOG_RDR:
+                        num = rdr->RdrTypeUnion.WatchdogRec.WatchdogNum;
+                        break;
+                case SAHPI_ANNUNCIATOR_RDR:
+                        num = rdr->RdrTypeUnion.AnnunciatorRec.AnnunciatorNum;
+                        break;
+               case SAHPI_DIMI_RDR:
+                        num = rdr->RdrTypeUnion.DimiRec.DimiNum;
+                        break;
+                case SAHPI_FUMI_RDR:
+                        num = rdr->RdrTypeUnion.FumiRec.Num;
+                        break;
+                default:
+                        num = 0;
+        }
+
+        return num;
+}
+
+
 /**
  * General RPT calls
  **/
@@ -244,7 +241,6 @@ SaHpiInstrumentIdT oh_get_rdr_num(SaHpiEntryIdT rdrid) {
 SaErrorT oh_init_rpt(RPTable *table)
 {
         if (!table) {
-                err("ERROR: Cannot work on a null table pointer.");
                 return SA_ERR_HPI_INVALID_PARAMS;
         }
 
@@ -370,7 +366,6 @@ SaErrorT oh_get_rpt_info(RPTable *table,
                          SaHpiTimeT *update_timestamp)
 {
         if (!table || !update_count || !update_timestamp) {
-                err("ERROR: Invalid parameters.");
                 return SA_ERR_HPI_INVALID_PARAMS;
         }
 
@@ -412,19 +407,14 @@ SaErrorT oh_add_resource(RPTable *table, SaHpiRptEntryT *entry, void *data, int
         int update_info = 0;
 
         if (!table) {
-                err("ERROR: Cannot work on a null table pointer.");
                 return SA_ERR_HPI_INVALID_PARAMS;
         } else if (!entry) {
-                err("Failed to add. RPT entry is NULL.");
                 return SA_ERR_HPI_INVALID_PARAMS;
         } else if (entry->ResourceId == SAHPI_FIRST_ENTRY) {
-                err("Failed to add. RPT entry needs a resource id before being added");
                 return SA_ERR_HPI_INVALID_PARAMS;
         } else if (entry->ResourceId == SAHPI_UNSPECIFIED_RESOURCE_ID) {
-                err("Failed to add. RPT entry has an invalid/reserved id assigned. (SAHPI_UNSPECIFIED_RESOURCE_ID)");
                 return SA_ERR_HPI_INVALID_PARAMS;
         } else if (!oh_valid_ep(&(entry->ResourceEntity))) {
-                err("Failed to add RPT entry. Entity path does not contain root element.");
                 return SA_ERR_HPI_INVALID_PARAMS;
         }
 
@@ -433,9 +423,8 @@ SaErrorT oh_add_resource(RPTable *table, SaHpiRptEntryT *entry, void *data, int
         rptentry = get_rptentry_by_rid(table, entry->ResourceId);
         /* If not, create new RPTEntry */
         if (!rptentry) {
-                rptentry = (RPTEntry *)g_malloc0(sizeof(RPTEntry));
+                rptentry = g_new0(RPTEntry, 1);
                 if (!rptentry) {
-                        err("Not enough memory to add RPT entry.");
                         return SA_ERR_HPI_OUT_OF_MEMORY;
                 }
                 update_info = 1; /* Have a new changed entry */
@@ -485,7 +474,6 @@ SaErrorT oh_remove_resource(RPTable *table, SaHpiResourceIdT rid)
 
         rptentry = get_rptentry_by_rid(table, rid);
         if (!rptentry) {
-                err("Failed to remove RPT entry. No Resource found by that id");
                 return SA_ERR_HPI_NOT_PRESENT;
         } else {
                 SaHpiRdrT *tmp_rdr;
@@ -527,7 +515,7 @@ void *oh_get_resource_data(RPTable *table, SaHpiResourceIdT rid)
 
         rptentry = get_rptentry_by_rid(table, rid);
         if (!rptentry) {
-                /*dbg("Warning: RPT entry not found. Returning NULL.");*/
+                /*DBG("Warning: RPT entry not found. Returning NULL.");*/
                 return NULL;
         }
 
@@ -552,7 +540,7 @@ SaHpiRptEntryT *oh_get_resource_by_id(RPTable *table, SaHpiResourceIdT rid)
 
         rptentry = get_rptentry_by_rid(table, rid);
         if (!rptentry) {
-                /*dbg("Warning: RPT entry not found. Returning NULL.");*/
+                /*DBG("Warning: RPT entry not found. Returning NULL.");*/
                 return NULL;
         }
 
@@ -577,7 +565,6 @@ SaHpiRptEntryT *oh_get_resource_by_ep(RPTable *table, SaHpiEntityPathT *ep)
         SaHpiResourceIdT rid = 0;
 
         if (!table) {
-                err("ERROR: Cannot work on a null table pointer.");
                 return NULL;
         }
         /* Check the uid database first */
@@ -586,7 +573,7 @@ SaHpiRptEntryT *oh_get_resource_by_ep(RPTable *table, SaHpiEntityPathT *ep)
                 /* Found it in uid database */
                 return oh_get_resource_by_id(table, rid);
         } else {
-                dbg("Didn't find the EP in the Uid table so "
+                DBG("Didn't find the EP in the Uid table so "
                     "looking manually in the RPTable");
         }
 
@@ -598,7 +585,7 @@ SaHpiRptEntryT *oh_get_resource_by_ep(RPTable *table, SaHpiEntityPathT *ep)
         }
 
         if (!rptentry) {
-                /*dbg("Warning: RPT entry not found. Returning NULL.");*/
+                /*DBG("Warning: RPT entry not found. Returning NULL.");*/
                 return NULL;
         }
 
@@ -635,6 +622,35 @@ SaHpiRptEntryT *oh_get_resource_next(RPTable *table, SaHpiResourceIdT rid_prev)
         return rptentry ? &(rptentry->rpt_entry) : NULL;
 }
 
+/**
+ * oh_get_rdr_update_count
+ * @table: Pointer to the RPT for looking up the RPT entry.
+ * @rid: Resource id of the RPT entry to be looked up.
+ * @update_count: pointer of where to place the rdr update count
+ *
+ * Get a RDR Repository Update Counter for the resource using the resource id.
+ *
+ * Returns:
+ * Returns: SA_OK on success.
+ * Will return SA_ERR_HPI_INVALID_PARAMS if update_count is NULL.
+ * Will return SA_ERR_HPI_NOT_PRESENT if there is no resource
+ * with specified rid in RPT.
+ **/
+SaErrorT oh_get_rdr_update_count(RPTable *table,
+                                 SaHpiResourceIdT rid,
+                                 SaHpiUint32T *update_count)
+{
+    RPTEntry *rptentry = get_rptentry_by_rid(table, rid);
+    if ( !rptentry ) {
+        return SA_ERR_HPI_NOT_PRESENT;
+    }
+    if ( !update_count ) {
+        return SA_ERR_HPI_INVALID_PARAMS;
+    }
+    *update_count = rptentry->update_count;
+    return SA_OK;
+}
+
 /**
  * RDR interface functions
  */
@@ -666,35 +682,32 @@ SaErrorT oh_add_rdr(RPTable *table, SaHpiResourceIdT rid, SaHpiRdrT *rdr, void *
 {
         RPTEntry *rptentry;
         RDRecord *rdrecord;
-        SaHpiInstrumentIdT type_num;
+        SaHpiInstrumentIdT instr_id;
 
         if (!rdr) {
-                err("Failed to add. RDR is NULL.");
                 return SA_ERR_HPI_INVALID_PARAMS;
         }
 
         rptentry = get_rptentry_by_rid(table, rid);
         if (!rptentry){
-                err("Failed to add RDR. Parent RPT entry was not found in table.");
                 return SA_ERR_HPI_NOT_PRESENT;
         }
 
         if (check_instrument_id(&(rptentry->rpt_entry), rdr)) {
-                err("Invalid instrument id found in RDR.");
+                CRIT("Invalid instrument id found in RDR.");
                 return SA_ERR_HPI_INVALID_PARAMS;
         }
 
-        type_num = get_rdr_type_num(rdr);
+        instr_id = oh_get_instrument_id(rdr);
 
         /* Form correct RecordId. */
-        rdr->RecordId = oh_get_rdr_uid(rdr->RdrType, type_num);
+        rdr->RecordId = oh_get_rdr_uid(rdr->RdrType, instr_id);
         /* Check if record exists */
         rdrecord = get_rdrecord_by_id(rptentry, rdr->RecordId);
         /* If not, create new rdr */
         if (!rdrecord) {
-                rdrecord = (RDRecord *)g_malloc0(sizeof(RDRecord));
+                rdrecord = g_new0(RDRecord, 1);
                 if (!rdrecord) {
-                        err("Not enough memory to add RDR.");
                         return SA_ERR_HPI_OUT_OF_MEMORY;
                 }
                 /* Put new rdrecord in rdr repository */
@@ -715,6 +728,8 @@ SaErrorT oh_add_rdr(RPTable *table, SaHpiResourceIdT rid, SaHpiRdrT *rdr, void *
         rdrecord->owndata = owndata;
         rdrecord->rdr = *rdr;
 
+        ++rptentry->update_count;
+
         return SA_OK;
 }
 
@@ -743,13 +758,11 @@ SaErrorT oh_remove_rdr(RPTable *table, SaHpiResourceIdT rid, SaHpiEntryIdT rdrid
 
         rptentry = get_rptentry_by_rid(table, rid);
         if (!rptentry) {
-                err("Failed to remove RDR. Parent RPT entry was not found.");
                 return SA_ERR_HPI_NOT_PRESENT;
         }
 
         rdrecord = get_rdrecord_by_id(rptentry, rdrid);
         if (!rdrecord) {
-                err("Failed to remove RDR. Could not be found.");
                 return SA_ERR_HPI_NOT_PRESENT;
         } else {
                 rptentry->rdrlist = g_slist_remove(rptentry->rdrlist, (gpointer)rdrecord);
@@ -760,6 +773,7 @@ SaErrorT oh_remove_rdr(RPTable *table, SaHpiResourceIdT rid, SaHpiEntryIdT rdrid
                         g_hash_table_destroy(rptentry->rdrtable);
                         rptentry->rdrtable = NULL;
                 }
+                ++rptentry->update_count;
         }
 
         return SA_OK;
@@ -788,13 +802,12 @@ void *oh_get_rdr_data(RPTable *table, SaHpiResourceIdT rid, SaHpiEntryIdT rdrid)
 
         rptentry = get_rptentry_by_rid(table, rid);
         if (!rptentry) {
-                err("Warning: RPT entry not found. Cannot find RDR.");
                 return NULL; /* No resource found by that id */
         }
 
         rdrecord = get_rdrecord_by_id(rptentry, rdrid);
         if (!rdrecord) {
-                /*dbg("Warning: RDR not found. Returning NULL.");*/
+                /*DBG("Warning: RDR not found. Returning NULL.");*/
                 return NULL;
         }
 
@@ -823,13 +836,12 @@ SaHpiRdrT *oh_get_rdr_by_id(RPTable *table, SaHpiResourceIdT rid, SaHpiEntryIdT
 
         rptentry = get_rptentry_by_rid(table, rid);
         if (!rptentry) {
-                err("Warning: RPT entry not found. Cannot find RDR.");
                 return NULL; /* No resource found by that id */
         }
 
         rdrecord = get_rdrecord_by_id(rptentry, rdrid);
         if (!rdrecord) {
-                /*dbg("Warning: RDR not found. Returning NULL.");*/
+                /*DBG("Warning: RDR not found. Returning NULL.");*/
                 return NULL;
         }
 
@@ -860,7 +872,6 @@ SaHpiRdrT *oh_get_rdr_by_type(RPTable *table, SaHpiResourceIdT rid,
 
         rptentry = get_rptentry_by_rid(table, rid);
         if (!rptentry) {
-                err("Warning: RPT entry not found. Cannot find RDR.");
                 return NULL; /* No resource found by that id */
         }
         
@@ -868,7 +879,7 @@ SaHpiRdrT *oh_get_rdr_by_type(RPTable *table, SaHpiResourceIdT rid,
         rdr_uid = oh_get_rdr_uid(type, num);
         rdrecord = get_rdrecord_by_id(rptentry, rdr_uid);
         if (!rdrecord) {
-                /*dbg("Warning: RDR not found. Returning NULL.");*/
+                /*DBG("Warning: RDR not found. Returning NULL.");*/
                 return NULL;
         }
 
@@ -901,7 +912,6 @@ SaHpiRdrT *oh_get_rdr_next(RPTable *table, SaHpiResourceIdT rid, SaHpiEntryIdT r
 
         rptentry = get_rptentry_by_rid(table, rid);
         if (!rptentry) {
-                err("Warning: RPT entry not found. Cannot find RDR.");
                 return NULL; /* No resource found by that id */
         }
 
@@ -926,7 +936,6 @@ SaHpiRdrT *oh_get_rdr_by_type_first(RPTable *table, SaHpiResourceIdT rid,
 
         rptentry = get_rptentry_by_rid(table, rid);
         if (!rptentry) {
-                err("Warning: RPT entry not found. Cannot find RDR.");
                 return NULL; /* No resource found by that id */
         }
         
@@ -952,7 +961,6 @@ SaHpiRdrT *oh_get_rdr_by_type_next(RPTable *table, SaHpiResourceIdT rid,
 
         rptentry = get_rptentry_by_rid(table, rid);
         if (!rptentry) {
-                err("Warning: RPT entry not found. Cannot find RDR.");
                 return NULL; /* No resource found by that id */
         }
         
