@@ -20,7 +20,6 @@
 #include <string.h>
 
 #include <SaHpi.h>
-#include <openhpi.h>
 #include <oh_utils.h>
 #include <el_utils.h>
 
@@ -63,33 +62,33 @@ int main(int argc, char **argv)
 	/* modifies the timestamp basetime */
 	retc = oh_el_timeset(el, timestamp);
 	if (retc != SA_OK){
-		err("ERROR: timeset failed");
+		CRIT("timeset failed");
 		return 1;
 	} 
 
 	retc = oh_el_append(el, &event, NULL, NULL);
         if (retc != SA_OK) {
-        	err("ERROR: oh_el_append failed.");
+        	CRIT("oh_el_append failed.");
 	        return 1;
         }
        
         /* get el info */
         retc = oh_el_info(el, &info);
         if (retc != SA_OK) {
-                err("ERROR: oh_el_info failed.");
+                CRIT("oh_el_info failed.");
                 return 1;
         }
 									
 	/* Verifies timestamp basetime worked */
 	if (info.UpdateTimestamp < timestamp){
-		err("ERROR: Timestamp basetime failed");
+		CRIT("Timestamp basetime failed");
 		return 1;
 	}    
 
         /* close el without saving to file*/
         retc = oh_el_close(el);
         if (retc != SA_OK) {
-                err("ERROR: oh_el_close on el failed.");
+                CRIT("oh_el_close on el failed.");
                 return 1;
         }
 
