@@ -20,7 +20,6 @@
 #include <string.h>
 
 #include <SaHpi.h>
-#include <openhpi.h>
 #include <oh_utils.h>
 #include <el_utils.h>
 
@@ -76,7 +75,7 @@ int main(int argc, char **argv)
 		retc = oh_el_prepend(el, &event, NULL, &res1);
 		
 		if (retc != SA_OK) {
-			err("ERROR: oh_el_prepend failed.");
+			CRIT("oh_el_prepend failed.");
                		return 1;
         	}
 	
@@ -86,7 +85,7 @@ int main(int argc, char **argv)
         /* close el */
         retc = oh_el_close(el);
         if (retc != SA_OK) {
-                err("ERROR: oh_el_close on el failed.");
+                CRIT("oh_el_close on el failed.");
                 return 1;
         }
 
