@@ -20,7 +20,6 @@
 #include <string.h>
 
 #include <SaHpi.h>
-#include <openhpi.h>
 #include <oh_utils.h>
 #include <el_utils.h>
 
@@ -46,7 +45,7 @@ int main(int argc, char **argv)
 
 	retc = oh_el_clear(el);
         if (retc == SA_OK) {
-                err("ERROR: el clear failed.");
+                CRIT("el clear failed.");
                 return 1;
         }
 
