@@ -20,7 +20,6 @@
 #include <string.h>
 
 #include <SaHpi.h>
-#include <openhpi.h>
 #include <oh_utils.h>
 #include <el_utils.h>
 
@@ -48,14 +47,14 @@ int main(int argc, char **argv)
 
  	retc = oh_el_setgentimestampflag(el, flag);
         if (retc != SA_OK) {
-        	err("ERROR: oh_el_get failed.");
+        	CRIT("oh_el_get failed.");
         	return 1;
         }
 
 	/* close el */
         retc = oh_el_close(el);
         if (retc != SA_OK) {
-                err("ERROR: oh_el_close on el failed.");
+                CRIT("oh_el_close on el failed.");
                 return 1;
         }
 
