@@ -20,7 +20,6 @@
 #include <string.h>
 
 #include <SaHpi.h>
-#include <openhpi.h>
 #include <oh_utils.h>
 #include <el_utils.h>
 
@@ -50,7 +49,7 @@ int main(int argc, char **argv)
 
         retc = oh_el_info(el, &info);
         if (retc == SA_OK) {
-                err("ERROR: oh_el_info failed.");
+                CRIT("oh_el_info failed.");
                 return 1;
         }
 
