@@ -20,7 +20,6 @@
 #include <string.h>
 
 #include <SaHpi.h>
-#include <openhpi.h>
 #include <oh_utils.h>
 #include <el_utils.h>
 
@@ -48,14 +47,14 @@ int main(int argc, char **argv)
 
 	retc = oh_el_timeset(el, SAHPI_TIME_UNSPECIFIED);
 	if (retc == SA_OK){
-		err("ERROR: oh_el_timeset on el failed");
+		CRIT("oh_el_timeset on el failed");
 		return 1;
 	}
 
         /* close el without saving to file*/
         retc = oh_el_close(el);
         if (retc != SA_OK) {
-                err("ERROR: oh_el_close on el failed.");
+                CRIT("oh_el_close on el failed.");
                 return 1;
         }
 
