@@ -20,7 +20,6 @@
 #include <string.h>
 
 #include <SaHpi.h>
-#include <openhpi.h>
 #include <oh_utils.h>
 #include <el_utils.h>
 
@@ -49,7 +48,7 @@ int main(int argc, char **argv)
         /* save the EL to file */
         retc = oh_el_setgentimestampflag(el, flag);
         if (retc == SA_OK) {
-                err("ERROR: oh_el_setgentimestampflag failed.");
+                CRIT("oh_el_setgentimestampflag failed.");
                 return 1;
         }
  
