@@ -17,16 +17,16 @@
 
 #include <stdlib.h>
 #include <stdio.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <fcntl.h>
 #include <string.h>
 #include <unistd.h>
+#include <sys/types.h>
+#include <sys/stat.h>
 
 #include <glib.h>
 #include <config.h>
 #include <oh_utils.h>
 #include <oh_error.h>
+#include <sahpi_wrappers.h>
 
 #ifdef OH_DBG_MSGS
 #define dbg_uid_lock(format, ...) \
@@ -43,14 +43,14 @@
 #define uid_lock(uidmutex) \
         do { \
                 dbg_uid_lock("Locking UID mutex..."); \
-                g_static_mutex_lock(uidmutex); \
+                wrap_g_static_mutex_lock(uidmutex); \
                 dbg_uid_lock("OK. UID mutex locked."); \
         } while (0)
 
 #define uid_unlock(uidmutex) \
         do { \
                 dbg_uid_lock("Unlocking UID mutex..."); \
-                g_static_mutex_unlock(uidmutex); \
+                wrap_g_static_mutex_unlock(uidmutex); \
                 dbg_uid_lock("OK. UID mutex unlocked."); \
         } while (0)
 
@@ -61,16 +61,22 @@ typedef struct {
         SaHpiEntityPathT entity_path;
 } EP_XREF;
 
-static GStaticMutex oh_uid_lock = G_STATIC_MUTEX_INIT;
+#if GLIB_CHECK_VERSION (2, 32, 0)
+	static GMutex oh_uid_lock;
+#else
+	static GStaticMutex oh_uid_lock = G_STATIC_MUTEX_INIT;
+#endif
+
 static GHashTable *oh_ep_table;
 static GHashTable *oh_resource_id_table;
 static guint       resource_id;
+static char * oh_uid_map_file = 0;
 static int initialized = FALSE;
 
 
 /* use to build memory resident map table from file */
 static int uid_map_from_file(void);
-static int build_uid_map_data(int file);
+static int build_uid_map_data(FILE *fp);
 
 /* used by oh_uid_remove() */
 static void write_ep_xref(gpointer key, gpointer value, gpointer file);
@@ -134,22 +140,42 @@ gboolean oh_entity_path_equal(gconstpointer a, gconstpointer b)
  **/
 SaErrorT oh_uid_initialize(void)
 {
-        SaErrorT rval = SA_OK;
-
         uid_lock(&oh_uid_lock);
         if (!initialized) {
+                int cc;
+                const char * uid_map_file = 0;
+
                 /* initialize hash tables */
                 oh_ep_table = g_hash_table_new(oh_entity_path_hash, oh_entity_path_equal);
                 oh_resource_id_table = g_hash_table_new(g_int_hash, g_int_equal);
                 initialized = TRUE;
                 resource_id = 1;
 
+                /* determine if we can use map file */
+                uid_map_file = (char *)getenv("OPENHPI_UID_MAP");
+                if (uid_map_file == 0) {
+                        uid_map_file = OH_DEFAULT_UID_MAP;
+                }
+                if ((uid_map_file == 0) || (strlen(uid_map_file) == 0)) {
+                        WARN( "UID Map file will not be used." );
+                        WARN( "Resource Id will not be persistent." );
+                } else {
+                        oh_uid_map_file = g_strdup(uid_map_file);
+                        INFO( "Using UID Map file %s.", oh_uid_map_file );
+                }
+
                 /* initialize uid map */
-                rval = uid_map_from_file();
+                cc = uid_map_from_file();
+                if (cc != 0) {
+                        g_free(oh_uid_map_file);
+                        oh_uid_map_file = 0;
+                        WARN( "Disabling using UID Map file." );
+                        WARN( "Resource Id will not be persistent." );
+                }
         }
         uid_unlock(&oh_uid_lock);
 
-        return rval;
+        return 0;
 }
 
 SaHpiBoolT oh_uid_is_initialized()
@@ -180,9 +206,6 @@ SaHpiUint32T oh_uid_from_entity_path(SaHpiEntityPathT *ep)
 
         EP_XREF *ep_xref;
 
-        char *uid_map_file;
-        int file;
-
         SaHpiEntityPathT entitypath;
 
         if (!ep) return 0;
@@ -197,15 +220,15 @@ SaHpiUint32T oh_uid_from_entity_path(SaHpiEntityPathT *ep)
         /* previously assigned uid      */
         ep_xref = (EP_XREF *)g_hash_table_lookup (oh_ep_table, key);
         if (ep_xref) {
-                /*dbg("Entity Path already assigned uid. Use oh_uid_lookup().");*/
+                /*DBG("Entity Path already assigned uid. Use oh_uid_lookup().");*/
                 uid_unlock(&oh_uid_lock);
                 return ep_xref->resource_id;
         }
 
         /* allocate storage for EP cross reference data structure*/
-        ep_xref = (EP_XREF *)g_malloc0(sizeof(EP_XREF));
+        ep_xref = g_new0(EP_XREF, 1);
         if(!ep_xref) {
-                err("malloc failed");
+                CRIT("malloc failed");
                 uid_unlock(&oh_uid_lock);
                 return 0;
         }
@@ -228,28 +251,25 @@ SaHpiUint32T oh_uid_from_entity_path(SaHpiEntityPathT *ep)
         g_hash_table_insert(oh_resource_id_table, key, value);
 
         /* save newly created ep xref (iud/resource_id) to map file */
-        uid_map_file = (char *)getenv("OPENHPI_UID_MAP");
-        if (uid_map_file == NULL) {
-                uid_map_file = OH_DEFAULT_UID_MAP;
+        if (oh_uid_map_file) {
+                FILE * fp;
+                fp = fopen(oh_uid_map_file, "r+b");
+                if (fp) {
+                        fseek(fp, 0, SEEK_END);
+                        if (fwrite(ep_xref, sizeof(EP_XREF), 1, fp) == 1) {
+                                fseek(fp, 0, SEEK_SET);
+                                if (fwrite(&resource_id, sizeof(resource_id), 1, fp) != 1) {
+                			CRIT("write resource_id failed");
+                                        ruid = 0;
+                		}
+        		} else {
+        			CRIT("write ep_xref failed");
+                                ruid = 0;
+                        }
+                        fclose(fp);
+                }
         }
 
-        file = open(uid_map_file, O_WRONLY);
-        if (file >= 0) {
-                lseek(file, 0, SEEK_END);
-                if (write(file,ep_xref, sizeof(EP_XREF)) != sizeof(EP_XREF)) {
-			err("write ep_xref failed");
-			close(file);
-			return 0;
-		}
-                lseek(file, 0, SEEK_SET);
-                if (write(file, &resource_id, sizeof(resource_id)) != sizeof(resource_id)) {
-			err("write resource_id failed");
-			close(file);
-			return 0;
-		}
-        }
-        close(file);
-
         uid_unlock(&oh_uid_lock);
 
         return ruid;
@@ -280,24 +300,22 @@ SaErrorT oh_uid_remove(SaHpiUint32T uid)
         uid_lock(&oh_uid_lock);
         ep_xref = (EP_XREF *)g_hash_table_lookup (oh_resource_id_table, key);
         if(!ep_xref) {
-                err("error freeing oh_resource_id_table");
                 uid_unlock(&oh_uid_lock);
-                return SA_ERR_HPI_ERROR;
+                return SA_ERR_HPI_NOT_PRESENT;
         }
 
         /* check netry exist in oh_resource_id_table */
         key = (gpointer)&ep_xref->entity_path;
         ep_xref = (EP_XREF *)g_hash_table_lookup (oh_ep_table, key);
         if(!ep_xref) {
-                err("error freeing oh_resource_id_table");
                 uid_unlock(&oh_uid_lock);
-                return SA_ERR_HPI_ERROR;
+                return SA_ERR_HPI_NOT_PRESENT;
         }
 
         g_hash_table_remove(oh_resource_id_table, &ep_xref->resource_id);
         g_hash_table_remove(oh_ep_table, &ep_xref->entity_path);
 
-        free(ep_xref);
+        g_free(ep_xref);
 
         uid_unlock(&oh_uid_lock);
 
@@ -330,7 +348,6 @@ SaHpiUint32T oh_uid_lookup(SaHpiEntityPathT *ep)
         uid_lock(&oh_uid_lock);
         ep_xref = (EP_XREF *)g_hash_table_lookup (oh_ep_table, key);
         if(!ep_xref) {
-                err("error looking up EP to get uid");
                 uid_unlock(&oh_uid_lock);
                 return 0;
         }
@@ -362,9 +379,8 @@ SaErrorT oh_entity_path_lookup(SaHpiUint32T id, SaHpiEntityPathT *ep)
         uid_lock(&oh_uid_lock);
         ep_xref = (EP_XREF *)g_hash_table_lookup (oh_resource_id_table, key);
         if(!ep_xref) {
-                err("error looking up EP to get uid");
                 uid_unlock(&oh_uid_lock);
-                return SA_ERR_HPI_ERROR ;
+                return SA_ERR_HPI_NOT_PRESENT;
         }
 
         memcpy(ep, &ep_xref->entity_path, sizeof(SaHpiEntityPathT));
@@ -383,39 +399,33 @@ SaErrorT oh_entity_path_lookup(SaHpiUint32T id, SaHpiEntityPathT *ep)
  **/
 SaErrorT oh_uid_map_to_file(void)
 {
-        char *uid_map_file;
-        int file;
+        FILE *fp;
 
-        uid_map_file = (char *)getenv("OPENHPI_UID_MAP");
-
-        if (uid_map_file == NULL) {
-                uid_map_file = OH_DEFAULT_UID_MAP;
+        if (!oh_uid_map_file) {
+                return SA_OK;
         }
 
         uid_lock(&oh_uid_lock);
 
-        file = open(uid_map_file, O_WRONLY|O_CREAT|O_TRUNC, S_IRUSR|S_IWUSR|S_IRGRP);
-        if(file < 0) {
-                err("Configuration file '%s' could not be opened", uid_map_file);
+        fp = fopen(oh_uid_map_file, "wb");
+        if(!fp) {
+                CRIT("Configuration file '%s' could not be opened", oh_uid_map_file);
                 uid_unlock(&oh_uid_lock);
                 return SA_ERR_HPI_ERROR;
         }
 
         /* write resource id */
-        if (write(file, (void *)&resource_id, sizeof(resource_id)) != sizeof(resource_id)) {
-		err("write resource_id failed");
-		close(file);
+        if (fwrite((void *)&resource_id, sizeof(resource_id), 1, fp) != 1) {
+		CRIT("write resource_id failed");
+		fclose(fp);
+                uid_unlock(&oh_uid_lock);
 		return SA_ERR_HPI_ERROR;
 	}
 
         /* write all EP_XREF data records */
-        g_hash_table_foreach(oh_resource_id_table, write_ep_xref, &file);
+        g_hash_table_foreach(oh_resource_id_table, write_ep_xref, fp);
 
-        if(close(file) != 0) {
-                err("Couldn't close file '%s'.", uid_map_file);
-                uid_unlock(&oh_uid_lock);
-                return SA_ERR_HPI_ERROR;
-        }
+        fclose(fp);
 
         uid_unlock(&oh_uid_lock);
 
@@ -429,10 +439,10 @@ SaErrorT oh_uid_map_to_file(void)
  *
  * Return value: None (void).
  */
-static void write_ep_xref(gpointer key, gpointer value, gpointer file)
+static void write_ep_xref(gpointer key, gpointer value, gpointer fp)
 {
-        if (write(*(int *)file, value, sizeof(EP_XREF)) != sizeof(EP_XREF)) {
-		err("write EP_XREF failed");
+        if (fwrite(value, sizeof(EP_XREF), 1, (FILE *)fp) != 1) {
+		CRIT("write EP_XREF failed");
 	}
 }
 
@@ -446,34 +456,43 @@ static void write_ep_xref(gpointer key, gpointer value, gpointer file)
  */
 static gint uid_map_from_file()
 {
-        char *uid_map_file;
-        int file;
+        FILE *fp;
         int rval;
+#ifndef _WIN32
+	mode_t prev_umask;
+#endif
 
-         /* initialize uid map file */
-         uid_map_file = (char *)getenv("OPENHPI_UID_MAP");
-         if (uid_map_file == NULL) {
-                 uid_map_file = OH_DEFAULT_UID_MAP;
-         }
-         file = open(uid_map_file, O_RDONLY);
-         if(file < 0) {
+        if (!oh_uid_map_file) {
+                return 0;
+        }
+        fp = fopen(oh_uid_map_file, "rb");
+        if(!fp) {
                  /* create map file with resource id initial value */
-                 err("Configuration file '%s' does not exist, initializing", uid_map_file);
-                 file = open(uid_map_file,
-                             O_RDWR | O_CREAT | O_TRUNC,
-                             S_IRUSR | S_IWUSR | S_IRGRP);
-                 if(file < 0) {
-                         err("Could not initialize uid map file, %s", uid_map_file );
-                                         return -1;
+                 WARN("uid_map file '%s' could not be opened, initializing", oh_uid_map_file);
+#ifndef _WIN32
+		 prev_umask = umask(022);
+#endif
+                 fp = fopen(oh_uid_map_file, "wb");
+                 if(!fp) {
+                         CRIT("Could not initialize uid map file, %s", oh_uid_map_file );
+#ifndef _WIN32
+                         if (geteuid() != 0) 
+                              INFO("Use OPENHPI_UID_MAP env var to set uid_map file path");
+			 umask (prev_umask);
+#endif
+			 return -1;
                  }
+#ifndef _WIN32
+		 umask (prev_umask);
+#endif
                  /* write initial uid value */
-                 if( write(file,(void *)&resource_id, sizeof(resource_id)) < 0 ) {
-                         err("failed to write uid, on uid map file initialization");
-                         close(file);
+                 if(fwrite(&resource_id, sizeof(resource_id), 1, fp) != 1 ) {
+                         CRIT("failed to write uid, on uid map file initialization");
+                         fclose(fp);
                          return -1;
                  }
-                 if(close(file) != 0) {
-                         err("Couldn't close file '%s'.during uid map file initialization", uid_map_file);
+                 if(fclose(fp) != 0) {
+                         CRIT("Couldn't close file '%s'.during uid map file initialization", oh_uid_map_file);
                          return -1;
                  }
                  /* return from successful initialization, from newly created uid map file */
@@ -481,13 +500,14 @@ static gint uid_map_from_file()
          }
 
          /* read uid/resouce_id highest count from uid map file */
-         if (read(file,&resource_id, sizeof(resource_id)) != sizeof(resource_id)) {
-                 err("error setting uid from existing uid map file");
+         if (fread(&resource_id, sizeof(resource_id), 1, fp) != 1) {
+                 CRIT("error setting uid from existing uid map file");
+                fclose(fp);
                  return -1;
          }
 
-         rval = build_uid_map_data(file);
-         close(file);
+         rval = build_uid_map_data(fp);
+         fclose(fp);
 
          if (rval < 0)
                 return -1;
@@ -505,20 +525,17 @@ static gint uid_map_from_file()
  *
  * Return value: success 0, error -1.
  */
-static gint build_uid_map_data(int file)
+static gint build_uid_map_data(FILE *fp)
 {
-        int rval;
         EP_XREF *ep_xref;
         EP_XREF ep_xref1;
         gpointer value;
         gpointer key;
 
-        rval = read(file, &ep_xref1, sizeof(EP_XREF));
-
-        while ( (rval != EOF) && (rval == sizeof(EP_XREF)) ) {
+        while (fread(&ep_xref1, sizeof(EP_XREF), 1, fp) == 1) {
 
                 /* copy read record from ep_xref1 to malloc'd ep_xref */
-                ep_xref = (EP_XREF *)g_malloc0(sizeof(EP_XREF));
+                ep_xref = g_new0(EP_XREF, 1);
                 if (!ep_xref)
                         return -1;
                 memcpy(ep_xref, &ep_xref1, sizeof(EP_XREF));
@@ -532,14 +549,10 @@ static gint build_uid_map_data(int file)
                 /* resource id based key */
                 key = (gpointer)&ep_xref->resource_id;
                 g_hash_table_insert(oh_resource_id_table, key, value);
-
-                rval = read(file, &ep_xref1, sizeof(EP_XREF));
         }
 
-        /* TODO thought EOF would return -1, its not so check other way */
-        /* if (rval != EOF), rval of 0 seems to be EOF */
-        if ( (rval > 0)  && (rval < sizeof(EP_XREF)) ) {
-                err("error building ep xref from map file");
+        if ((feof(fp) == 0) || (ferror(fp) != 0)) {
+                CRIT("error building ep xref from map file");
                 return -1;
         }
         return 0;
